/*----------------------------------------------------------*/
/*  KNBCEDGD.PL - Edge Distance Case Knowledge              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(edgeDistance,
  [
    bridgeType                               :0.3,
    errorMemberType                          :0.7,
    attachMemberType                         :0.5,
    errorMemberLocation                      :0.7,
    errorMemberClass                         :0.3,
    attachMemberClass                        :0.3,
    errorMemberActualEdgeType                :0.8,
    attachMemberActualEdgeType               :0.4,
    holeDetailsType                          :0.8,
    holeDetailsNumberWithErrors              :0.5*continuous_feature_eval(50),
    holeDetailsNumberInGrouping              :0.5*continuous_feature_eval(100),
    holeDetailsActualBoltDiameter            :0.5*continuous_feature_eval(2),
    holeDetailsActualHoleDiameter            :0.5*continuous_feature_eval(2),
    holeDetailsActualLongHoleSpacing         :0.3*continuous_feature_eval(10),
    holeDetailsActualTransverseHoleSpacing   :0.3*continuous_feature_eval(10),
    holeDetailsSpecifiedBoltDiameter         :0.5*continuous_feature_eval(2),
    holeDetailsSpecifiedHoleDiameter         :0.5*continuous_feature_eval(2),
    holeDetailsSpecifiedLongHoleSpacing      :0.3*continuous_feature_eval(10),
    holeDetailsSpecifiedTransverseHoleSpacing:0.3*continuous_feature_eval(10),
    holeDetailsPartDrilledHole               :0.5,
    holeDetailsPartDrilledHoleDiameter       :0.2*continuous_feature_eval(2),
    holeDetailsPartDrilledHoleDepth          :0.5*continuous_feature_eval(2),
    holeDetailsPartDrilledHoleCoverage       :0.5*continuous_feature_eval(100),
    holeDetailsHoleBoringProcedure           :0.6,
    holeDistanceFromIntersectingMember       :0.3*continuous_feature_eval(20),
    holeDistanceFromErrorMember              :0.3*continuous_feature_eval(20),
    holeDistanceFromEdge                     :0.8*continuous_feature_eval(5),
    holeDistanceFromEnd                      :0.5*continuous_feature_eval(5)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(edgeDistance,
  [
    holeDetailsActualBoltDiameter,
    holeDetailsActualHoleDiameter,
    holeDetailsActualLongHoleSpacing,
    holeDetailsActualTransverseHoleSpacing,
    holeDetailsSpecifiedBoltDiameter,
    holeDetailsSpecifiedHoleDiameter,
    holeDetailsSpecifiedLongSpacing,
    holeDetailsSpecifiedTransverseSpacing,
    holeDetailsPartDrilledHoleDiameter,
    holeDetailsPartDrilledHoleDepth,
    holeDistanceFromIntersectingMember,
    holeDistanceFromErrorMember,
    holeDistanceFromEdge,
    holeDistanceFromEnd
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(edgeDistance_1,edgeDistance,`EDGD-C001`,`Edge Distance Case Solution`,[mg104],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :diaphragmBrace,
    attachMemberType                      :capBeam,
    errorMemberLocation                   :boltedConnection,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    errorMemberActualEdgeType             :flameCut,
    attachMemberActualEdgeType            :flameCut,
    holeDetailsType                       :circular,
    holeDetailsNumberWithErrors           :9,
    holeDetailsNumberInGrouping           :36,
    holeDetailsActualBoltDiameter         :0.875,
    holeDetailsActualHoleDiameter         :0.9375,
    holeDetailsActualLongHoleSpacing      :5,
    holeDetailsActualTransverseHoleSpacing:3,
    holeDetailsSpecifiedBoltDiameter      :0.875,
    holeDetailsSpecifiedHoleDiameter      :0.9375,
    holeDetailsSpecifiedLongSpacing       :5,
    holeDetailsSpecifiedTransverseSpacing :3,
    holeDetailsPartDrilled                :false,
    holeDetailsHoleBoringProcedure        :drilled,
    holeDistanceFromEdge                  :0.75,
    holeDistanceFromEnd                   :1.5
  ],
  `Diaphragm in cap beam has its connection plate misfit by 3/4 in. resulting in a lack of edge distance.
Eight additional bolts were drilled between the existing bolt lines in the plate.
The bolt holes were placed at centerline location between existing bolt lines both laterally and tangentially.`,
`Case #MG104:

Description of Error: Diaphragm located at extension dimension 28'-7 11/16 in cap beam has its top connection plate misfit by 3/4 inch. 
This misalignment results in lack of edge distance.
Solution Recommended: To add 8 additional holes to the connection to make up for shy edge distance as shown on sketch. 
The bolt holes were placed at centerline location between existing bolt lines both laterally and tangentially.`
).

% Solution 2
caseSolution(edgeDistance_2,edgeDistance,`EDGD-C002`,`Edge Distance Case Solution`,[],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :plateGirder,
    attachMemberType                      :splicePlate,
    errorMemberLocation                   :splice,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    errorMemberActualEdgeType             :flameCut,
    holeDetailsType                       :circular,
    holeDetailsNumberWithErrors           :2,
    holeDetailsNumberInGrouping           :8,
    holeDetailsActualBoltDiameter         :0.875,
    holeDetailsActualHoleDiameter         :0.9375,
    holeDetailsSpecifiedBoltDiameter      :0.875,
    holeDetailsSpecifiedHoleDiameter      :0.9375,
    holeDetailsPartDrilled                :false,
    holeDetailsHoleBoringProcedure        :drilled,
    holeDistanceFromEdge                  :1.3125
  ],
  `Two holes in the top flange do not have sufficient edge distance.
The flange was flame cut. By grinding off 1/16 in. the edge is now equivalent to a planed edge.
The planed edge allows a smaller edge distance. so now the flange meets the edge distance requirements.`,
`Case # MG113:

Description of Error: The top flange of a girder has two holes with 1 5/16 inch edge distance.
Solution Recommended: Grind the end of the flange to the equivalent of a planed edge, 
then 1 1/4 inch edge distance would be acceptable.`
).

% Solution 3
caseSolution(edgeDistance_3,edgeDistance,`EDGD-C003`,`Edge Distance Case Solution`,[],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :boxGirder,
    attachMemberType                      :splicePlate,
    errorMemberLocation                   :splice,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary
  ],
  `The top splice plate has an edge distance problem.
Extra holes were drilled to remedy the edge distance problem.`,
`Case # MG165:

Description of Error: The top splice plate on a box girder needs to have additional holes. 
This is caused by extra holes that were added to the corresponding top diaphragm plate inside the box due to an edge distance problem.
Solution Recommended: The top splice plate was revised to add extra holes to correspond with the top diaphragm plate holes.
`
).

% Solution 4
caseSolution(edgeDistance_4,edgeDistance,`EDGD-C004`,`Edge Distance Case Solution`,[],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :plateGirder,
    attachMemberType                      :plateGirder,
    errorMemberLocation                   :gussetPlate,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    holeDetailsType                       :longSlotted,
    holeDetailsNumberWithErrors           :6,
    holeDetailsNumberInGrouping           :6,
    holeDistanceFromEdge                  :2.5
  ],
  `The edge distance for the slot in the tie plate is insufficient to transmit the load.
Provide a tie plate 3/4 in. by 7 5/8 in. in lieu of 3/4 in. by 5 1/2 in.`,
`Case #TF205:

Description of Error: The edge distance for the slot in the tie plate is 2 1/2" at two locations only. 
This is insufficient to transmit the load.
Solution Recommended: Several options can be used to rectify the problem.
1. Provide A36 tie plate 1 1/8" x 5 1/2" in lieu of 3/4" x 5 1/2".
2. Provide A572 tie plate 1' x 5 1/2" in lieu of 3/4" x 5 1/2".
3. Provide A36 tie plate 3/4" x 7 5/8" in lieu of 3/4" x 5 1/2"
4. Provide an additional A36 tie plate 5/8" x 5 1/2".
No.3 is preferred.`
).

% Solution 5
caseSolution(edgeDistance_5,edgeDistance,`EDGD-C005`,`Edge Distance Case Solution`,[nc502],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :plateGirder,
    attachMemberType                      :splicePlate,
    errorMemberLocation                   :tensionFlange,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    errorMemberActualEdgeType             :flameCut,
    holeDetailsType                       :circular,
    holeDetailsActualBoltDiameter         :0.875,
    holeDetailsActualHoleDiameter         :0.9375,
    holeDetailsActualLongHoleSpacing      :3,
    holeDetailsActualTransverseHoleSpacing:4,
    holeDetailsSpecifiedBoltDiameter      :0.875,
    holeDetailsSpecifiedHoleDiameter      :0.9375,
    holeDetailsSpecifiedLongSpacing       :3,
    holeDetailsSpecifiedTransverseSpacing :4,
    holeDistanceFromEdge                  :1.25
  ],
  `Tension flange was cut narrow causing edge distance problems. The flange has a flame cut edge.
Remove 1/16 in. which would allow the edge to be planed.
The planed edge allows a smaller edge distance requirement which allows the member to meet the requirements.`,
`Case #NC502:

Description of Error: Specified flange width was 16" (see sketch). 
Actual flange width is 15 3/4". Edge distance member does not meet specifications.  
The type of edge on member is flame cut.
Solution Recommended: Check dimensions of member to see if removal of 1/16" would allow planed edge. 
Planed edge will allow smaller edge distance requirement. 
Check edge distance specifications with planed edge and reduction of 1/16". 
If edge distance with planed edge will not meet specifications 
then cut and replace member at acceptable location or replace entire member.`
).

% Solution 6
caseSolution(edgeDistance_6,edgeDistance,`EDGD-C006`,`Edge Distance Case Solution`,[mg119],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :diaphragmBrace,
    attachMemberType                      :plateGirder,
    errorMemberLocation                   :gussetPlate,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    holeDetailsType                       :circular,
    holeDetailsPartDrilled                :false,
    holeDistanceFromEdge                  :1.0625
  ],
  `The internal bracing diaphragms located where the girder connection plate bolt to the top flange
of the girder and the top flange of the box have insufficient edge distance.
Drill an extra set of bolt holes at 3 in. from the last two bolt holes that have insufficient end distance.`,
`Case #MG119:

Description of Error: In the box cap beam five internal bracing diaphragms located where the girder connection plate bolt to the top flange of the girder 
and the top flange of the box have insufficient edge distance. 
Three diaphragms have two bolts with 1 3/16" edge distance; 
1 has two bolts with 1 1/16" edge distance; and 1 diaphragm has two bolts with 1 5/16" edge distance.
Solution Recommended: Drill an extra set of bolt holes at 3" from the last two bolt holes 
that have insufficient end distance.`
).

