/*----------------------------------------------------------*/
/*  KNBCEDGL.PL - Edge Lamination Case Knowledge            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(edgeLamination,
  [
    bridgeType                    :0.3,
    errorMemberType               :0.6,
    attachMemberType              :0.3,
    errorMemberLocation           :0.7,
    errorMemberClass              :0.3,
    attachMemberClass             :0.3,
    laminationMappingDocumentation:0.7,
    laminationTestRequired        :0.6,
    laminationLengthOfDeformity   :0.5*continuous_feature_eval(200),
    laminationWidthOfDeformity    :0.5*continuous_feature_eval(100)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(edgeLamination,
  [
    laminationLengthOfDeformity,
    laminationWidthOfDeformity
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(edgeLamination_1,edgeLamination,`EDGL-C001`,`Edge Lamination Case Solution`,[mg116],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :capBeam,
    errorMemberLocation           :tensionFlange,
    errorMemberClass              :primary,
    laminationMappingDocumentation:complete,
    laminationLengthOfDeformity   :21
  ],
  `The cap beam top flange has laminations along its edge.
The lamination should be ground out, weld repaired, and UT tested.`,
`Case # MG116:

Description of Error: Cap beam top flange has two laminations along its edge. 
Fabricators have ground 3/8 inch deep in the edge of the flange and the 15" lamination was removed 
but the 21" lamination still shows indications.
Solution Recommended: Grind the 21" lamination the additional 1/8"  to remove the indications 
and repair these areas per approved fabrication correction procedure.`
).

% Solution 2
caseSolution(edgeLamination_2,edgeLamination,`EDGL-C002`,`Edge Lamination Case Solution`,[],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :plateGirder,
    errorMemberLocation           :tensionFlange,
    errorMemberClass              :primary,
    laminationLengthOfDeformity   :60
  ],
  `There is a lamellar tear along the end of the plate. Replace flange with new material.`,
`Case # TF192:

Description of Error: There is a lamellar tear in 1/2" x 120" flange. 
The tear is 1/2" deep along the end of the plate. 
The shape of the lamellar tear is triangular. 
The base of the triangle 6 5/8" along the end of the plate and the height of the triangle is approximately 5' along the flange edge.
Solution Recommended: Replace flange with new material. 
The fabricator elected to replace (as opposed to repair) and to enter discussion with the steel mill so no cost to DOT.
Other possible Solutions: Gouge out discontinuity 1" beyond its intersection with the surface and block off 
by welding with the shielded metal arc process in layers not to exceed 1/8" inch thickness.
`
).


% New Solution 3
caseSolution(edgeLamination_3,edgeLamination,`EDGL-C003`,`Edge Lamination Case Solution`,[jef006],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :flangePlate,
    attachMemberType              :bearingStiffener,
    errorMemberLocation           :compressionFlange,
    errorMemberClass              :primary,
    attachMemberClass             :primary,
    laminationLengthOfDeformity   :17.32,
    laminationWidthOfDeformity    :1.38

  ],
  ` A lamination was discovered at mid-thickness in the edge of a top flange plate after cutting.
Possible solutions could include: partial or complete flange replacement; 
designing an array of high strength fasteners to clamp flange together, 
(and/or provide composite connection to slab); or a combination of edge and slot welds to "connect" flange. 
Fabricator opted to remove and replace a 3500 mm long portion of the flange, starting from the abutment end. 
This required removing flange-to-web and stiffener-to-flange fillet welds approx. 600 mm 
beyond flange replacement to allow flange-web separation for butt welding and X-raying joint. 
To facilitate replacing flange-to-web weld, size of corner clips (snips) of stiffeners 
and connection plate at web-flange juncture were increased by 10 mm (horiz and vert) during weld removal. 
RT of butt weld and MT of replaced fillets are required for final checks.`,
`Case #JE-F006:
Description of Error: A lamination was discovered at mid-thickness in the edge of a top flange plate after cutting. 
Its apparent max depth was 35 mm, so it was repaired in accord with Section 3 of the Bridge Welding Code. 
After shafting (welding web to flange and installing stiffeners), the lamination reappeared on the opposite flange edge, 
indicating a full width separation. Although this is a compression flange, 
stud shear connectors will be attached for composite action, so horizontal shear in the flange will be substantial. 
Solution Recommended: Possible solutions could include: partial or complete flange replacement; 
designing an array of high strength fasteners to clamp flange together, (and/or provide composite connection to slab); 
or a combination of edge and slot welds to "connect" flange. 
Fabricator opted to remove and replace a 3500 mm long portion of the flange, starting from the abutment end. 
This required removing flange-to-web and stiffener-to-flange fillet welds approx. 600 mm beyond flange replacement 
to allow flange-web separation for butt welding and X-raying joint. To facilitate replacing flange-to-web weld, 
size of corner clips (snips) of stiffeners and connection plate at web-flange juncture were increased by 10 mm 
(horiz. and vert.) to 35 mm horiz. and 75 mm vert. during weld removal. 
RT of butt weld and MT of replaced fillets are required for final checks.
Remarks: This is a large radius curved structure, 
so cross frame connection plates' welds to flange carry live load stresses. 
Decreasing their lengths by 10 mm was not judged critical due to the large radius involved, 
and larger clips allowed better access for semi-auto SAW of flange to web. 
Requiring fully automatic SAW for the replacement flange-to-web weld would mandate complete removal 
and replacement of existing sound welds attaching connecting plates and bearing stiffeners to the web and bottom (tension) flange. 
This would produce higher residual stresses in the girder and require extensive hand labor to accomplish.`
).




