/*----------------------------------------------------------*/
/*  KNBCENDD.PL - End Distance Case Knowledge               */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(endDistance,
  [
    bridgeType                               :0.3,
    errorMemberType                          :0.7,
    attachMemberType                         :0.5,
    errorMemberLocation                      :0.7,
    errorMemberClass                         :0.3,
    attachMemberClass                        :0.3,
    errorMemberActualEdgeType                :0.8,
    attachMemberActualEdgeType               :0.4,
    holeDetailsType                          :0.8,
    holeDetailsNumberWithErrors              :0.5*continuous_feature_eval(50),
    holeDetailsNumberInGrouping              :0.5*continuous_feature_eval(100),
    holeDetailsActualBoltDiameter            :0.5*continuous_feature_eval(2),
    holeDetailsActualHoleDiameter            :0.5*continuous_feature_eval(2),
    holeDetailsActualLongHoleSpacing         :0.3*continuous_feature_eval(10),
    holeDetailsActualTransverseHoleSpacing   :0.3*continuous_feature_eval(10),
    holeDetailsSpecifiedBoltDiameter         :0.5*continuous_feature_eval(2),
    holeDetailsSpecifiedHoleDiameter         :0.5*continuous_feature_eval(2),
    holeDetailsSpecifiedLongHoleSpacing      :0.3*continuous_feature_eval(10),
    holeDetailsSpecifiedTransverseHoleSpacing:0.3*continuous_feature_eval(10),
    holeDetailsPartDrilledHole               :0.5,
    holeDetailsPartDrilledHoleDiameter       :0.2*continuous_feature_eval(2),
    holeDetailsPartDrilledHoleDepth          :0.5*continuous_feature_eval(2),
    holeDetailsPartDrilledHoleCoverage       :0.5*continuous_feature_eval(100),
    holeDetailsHoleBoringProcedure           :0.6,
    holeDistanceFromIntersectingMember       :0.3*continuous_feature_eval(20),
    holeDistanceFromErrorMember              :0.3*continuous_feature_eval(20),
    holeDistanceFromEdge                     :0.5*continuous_feature_eval(5),
    holeDistanceFromEnd                      :0.8*continuous_feature_eval(5)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(endDistance,
  [
    holeDetailsActualBoltDiameter,
    holeDetailsActualHoleDiameter,
    holeDetailsActualLongHoleSpacing,
    holeDetailsActualTransverseHoleSpacing,
    holeDetailsSpecifiedBoltDiameter,
    holeDetailsSpecifiedHoleDiameter,
    holeDetailsSpecifiedLongSpacing, 
    holeDetailsSpecifiedTransverseSpacing,
    holeDetailsPartDrilledHoleDiameter,
    holeDetailsPartDrilledHoleDepth,
    holeDistanceFromIntersectingMember,
    holeDistanceFromErrorMember,
    holeDistanceFromEdge,
    holeDistanceFromEnd
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(endDistance_1,endDistance,`ENDD-C001`,`End Distance Case Solution`,[mg103],success,
  [
    bridgeType                            :plateGirder,
    errorMemberType                       :plateGirder,
    attachMemberType                      :splicePlate,
    errorMemberLocation                   :splice,
    errorMemberClass                      :primary,
    attachMemberClass                     :primary,
    errorMemberActualEdgeType             :flameCut,
    attachMemberActualEdgeType            :flameCut,
    holeDetailsType                       :circular,
    holeDetailsActualBoltDiameter         :0.875,
    holeDetailsActualHoleDiameter         :0.9375,
    holeDetailsActualLongHoleSpacing      :3,
    holeDetailsSpecifiedBoltDiameter      :0.875,
    holeDetailsSpecifiedHoleDiameter      :0.9375,
    holeDetailsSpecifiedLongSpacing       :3,
    holeDetailsHoleBoringProcedure        :drilled,
    holeDistanceFromIntersectingMember    :3.25,
    holeDistanceFromEdge                  :2.75,
    holeDistanceFromEnd                   :1
  ],
  `The top flange hole pattern drilled for the splice plate was shifted resulting in too short of an end distance.
The splice was lengthened to allow an extra set of holes to be drilled in the splice plate and top flange.`,
`Case # MG103:

Description of Error: Girder top flange far end has the hole pattern drilled for the splice plate shifted by 1/2 inch which results in 1" end distance.
Solution Recommended: Lengthen the splice by 5" and add an extra set of bolts. 
Due to the location of the stiffener bars the gage on this extra set of holes will be 5 inches.`
).

% New Solution 2
caseSolution(endDistance_2,endDistance,`ENDD-C002`,`End Distance Case Solution`,[ddf007],success,
  [
    bridgeType                               :plateGirder,
    errorMemberType                          :flangePlate,
    attachMemberType                         :splicePlate,
    errorMemberLocation                      :tensionFlange,
    errorMemberClass                         :primary,
    attachMemberClass                        :primary,
    errorMemberActualEdgeType                :flameCut,
    attachMemberActualEdgeType               :flameCut,
    holeDetailsType                          :circular,
    holeDetailsNumberWithErrors              :30,
    holeDetailsNumberInGrouping              :30,
    holeDetailsActualBoltDiameter            :1,
    holeDetailsActualLongHoleSpacing         :3.5,
    holeDetailsSpecifiedBoltDiameter         :1,
    holeDetailsSpecifiedLongHoleSpacing      :3.5,
    holeDetailsPartDrilledHole               :false,
    holeDetailsHoleBoringProcedure           :drilled,
    holeDistanceFromEnd                      :1.1875
  ],
  `1-3/4" dimension to attain proper edge distance from end of flanges to hole was not maintained. 
Leave as is.`,
`Case #DD-F007:
Description of Error: 1-3/4" dimension to attain proper edge distance from end of flanges to hole was not maintained. 
Actual end distance is 1-3/16". Splice was designed to 100% of the smaller flange. 
Actual stress is below 50% of capacity and only needs designed to 75% per AASHTO. 
The bolt arrangement as is meets stress requirement for 75% of the capacity.
Solution Recommended: Leave as is. 
Other Possible solutions: a) Leave as is and add 4 more holes. Fill all holes with bolts. 
b) Add 4 more holes.  Make new plates which would not have holes drilled at 1-3/16". 
(This will cover the abandoned holes in the flange).`
). 