/*----------------------------------------------------------*/
/*  KNBCMALM.PL - Misaligned Member Case Knowledge          */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(misalignedMember,
  [
    bridgeType                             :0.3,
    errorMemberType                        :0.7,
    attachMemberType                       :0.5,
    errorMemberLocation                    :0.7,
    errorMemberClass                       :0.3,
    attachMemberClass                      :0.3,
    surfaceContactSpacing                  :0.7*continuous_feature_eval(5),
    surfacePercentContact                  :0.7*continuous_feature_eval(100),
    surfaceFillPlateThickness              :0.5*continuous_feature_eval(2),
    surfaceFillPlate                       :0.7,
    surfaceFullSurfaceContact              :0.7,
    surfaceHeatProcedure                   :0.7,
    mislocatedMemberDistanceCorrectLocation:0.5*continuous_feature_eval(20)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(misalignedMember,
  [
    surfaceContactSpacing,
    surfaceFillPlateThickness,
    mislocatedMemberDistanceCorrectLocation
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(misalignedMember_1,misalignedMember,`MALM-C001`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :capBeam,
    attachMemberType                       :splicePlate,
    errorMemberLocation                    :compressionFlange,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    surfaceContactSpacing                  :0.1875,
    surfacePercentContact                  :20,
    surfaceFillPlate                       :true,
    surfaceFullSurfaceContact              :false
  ],
  `Due to the limit in gap that occurs between faying surfaces the plate can be machined to allow full surface contact.
Modify fill plates to allow full contact of surface extending if necessary for machining.`,
`Case #

Description of Error: Due to the limit in gap that occurs between faying surfaces the plate can be machined to allow full surface contact.
Solution Recommended: Modify fill plates to allow full contact of surface extending if necessary for machining.
`
).

% Solution 2
caseSolution(misalignedMember_2,misalignedMember,`MALM-C002`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    attachMemberType                       :capBeam,
    errorMemberLocation                    :boltedConnection,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    surfaceContactSpacing                  :2,
    surfacePercentContact                  :0,
    surfaceFillPlate                       :false,
    surfaceFullSurfaceContact              :false
  ],
  `Full contact surface does not occur at error location. Member types may allow
use of heat procedure to allow correction of non-surface contact.
Use approved heat procedure to correct gap between surface contact.
CAUTION -  Make sure to apply and control heat process only near end of member.
Check changes in girder camber for design limits.
Heat should be applied as near as possible to end member.`,
`Case # 

Description of Error: Full contact surface does not occur at error location. 
Solution Recommended: Member types may allow use of heat procedure to allow correction of non-surface contact. 
Use approved heat procedure to correct gap between surface contact. 
Caution :  Make sure to apply and control heat process only near end of member. 
Check changes in girder camber for design limits. Heat should be applied as near as possible to end member.`
).

% Solution 3
caseSolution(misalignedMember_3,misalignedMember,`MALM-C003`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :diaphragmBrace,
    attachMemberType                       :plateGirder,
    errorMemberLocation                    :boltedConnection,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary
  ],
  `Full contact surface does not occur at error location. Member types may allow use
of heat procedure to allow correction of non-surface contact.
Use approved heat procedure to correct gap between surface contact.
CAUTION - Make sure to apply and control heat process only near end of member.
Check changes in girder camber for design limits.
Heat should be applied as near as possible to end of member.`,
`Case #

Description of Error: Full contact surface does not occur at error location.
Solution Recommended: Member types may allow use of heat procedure to allow correction of non-surface contact.
Use approved heat procedure to correct gap between surface contact. 
Caution: Make sure to apply and control heat process only near end of member. 
Check changes in girder camber for design limits. Heat should be applied as near as possible to end of member.`
).

% Solution 4
caseSolution(misalignedMember_4,misalignedMember,`MALM-C004`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    attachMemberType                       :fillerPlate,
    errorMemberLocation                    :bearing,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    surfaceContactSpacing                  :0.09375,
    surfacePercentContact                  :20,
    surfaceFillPlate                       :false,
    surfaceFullSurfaceContact              :false
  ],
  `Bearing plate and bottom flange of girder do not make full surface contact.
50% or more of contact area makes full contact.
Maximum gap is less than 1/4 in. Remove fillet welds per AWS D1.5-88 from both sides of bearing stiffener.
Move bottom flange down to achieve full surface contact between members.
One method is by jacking the bottom flange down making sure that the compression flange is not damaged.
Reweld bearing stiffener to bottom flange in accordance with AWS D1.5-88 procedures.`,
`Case #

Description of Error: Bearing plate and bottom flange of girder do not make full surface contact.
50% or more of contact area makes full contact.
Solution Recommended: Maximum gap is less than 1/4 in. 
Remove fillet welds per AWS D1.5-88 from both sides of bearing stiffener. 
Move bottom flange down to achieve full surface contact between members. 
One method is by jacking the bottom flange down making sure that the compression flange is not damaged. 
Reweld bearing stiffener to bottom flange in accordance with AWS D1.5-88 procedures.`
).

% Solution 5
caseSolution(misalignedMember_5,misalignedMember,`MALM-C005`,`Misaligned Member Case Solution`,[tf189],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    surfaceContactSpacing                  :0,
    surfacePercentContact                  :100,
    surfaceFillPlate                       :false,
    surfaceFullSurfaceContact              :true
  ],
  `The web plate is misaligned 1/2 in. centerline of top flange plate approximately 1 ft 10 1/2 in from left end.
Required holes in top flange have been drilled and were gaged from centerline of misaligned web.
This has caused these holes to be 1/2 in. off theoretical centerline therefore reducing edge distance on one side.
Air carbon arc gouge web to flange weld 2 ft. 6in. from left hand end and add 1" web cope hole.
Cut out top flange 2 ft. 6 in from left hand and splice new flange. Radiograph flange splice 100%
Web will be realigned and welded with 100 percent MT.  Holes will be drilled in new flange plate.`,
`Case # TF189:

Description of Error: Web plate is misaligned 1/2" off centerline of top flange plate approximately 1'-10 1/2" from left hand end. 
Required holes in top flange have been drilled and were gaged from centerline of mis-aligned web. 
This has caused these holes to be 1/2" off theoretical centerline, reducing edge distance from 1 1/2" to 1" on far side and increasing edge distance near side to 2".
Solution Recommended: Air carbon arc gouge web-to-flange weld 2'-6 from left hand end, 
and add 1" web cope hole. 
The cope hole is to allow 100% RT of flange weld. 
Cut out top flange 2'-6 from left hand end and splice new flange using approved weld procedure (see sketch) and RT splice 100%. 
Web will then be re-aligned and welded with 100% MT. Holes will then be drilled in new flange plate. 
All work to be witnessed by DOT.
`
).

% Solution 6
caseSolution(misalignedMember_6,misalignedMember,`MALM-C006`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    surfaceContactSpacing                  :0,
    surfacePercentContact                  :100,
    surfaceFullSurfaceContact              :true,
    mislocatedMemberDistanceCorrectLocation:0.375
  ],
  `The centerline of the web is 3/8 in. off center with centerline of flange.
This occurs within a length of approximately one foot working from girder end.
Grind and gouge web free.
Correct alignment and reweld.`,
`Case # TF225:

Description of Error: A girder has the flange to web welded X-end, bottom flange, 
with centerline of web 3/8 inch off center with centerline of flange. 
This occurs within a length of approximately one foot working from girder end.
Solution Recommended: Grind/gouge web free, correct alignment, and reweld. MT test 100%. 
If holes in flange plate are misaligned, replace affected flange plate if necessary with RT 100% of flange splice weld.`
).

% New Solution 7
caseSolution(misalignedMember_7,misalignedMember,`MALM-C007`,`Misaligned Member Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :diaphragmBrace,
    attachMemberType                       :plateGirder,
    errorMemberLocation                    :diaphragmBrace,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    mislocatedMemberDistanceCorrectLocation:0.75
  ],
  ` Existing superstructure is being replaced in stages to maintain traffic, 
and contractor had survey performed after first half of the deck was removed. 
This indicated revised beam lengths were needed and contractor advised fabricator 
to use new lengths along with an "average" skew for detailing and fabrication. 
When erection started, interior diaphragms between first two lines were off by 1 1/2", 
equating to an error in the skew of 0 degree, 45 minutes. 
Erector shifted second line1 " longitudinally, 
since interior diaphragms use 4 attachment bolts in horizontal lines at 3" spacing. 
However, by third line, shifting 1 " resulted in interference between beam ends 
and the abutment back wall.
Shifted first and third beams 3/4" toward pier, second and fourth beams 3/4" away from pier, 
allowing installation of the on-site diaphragms. 
Interior diaphragms could have all 4 bolts installed in the first and third bays, 
but in the second bay (between lines 2 and 3), 
only 3 of 4 bolts per location could be installed until additional holes were field drilled. 
Unused holes in the beam webs were filled with short bolts to avoid future inspection confusion. 
End diaphragms sit on seat angles with only two bolts through oversize holes in the bottom flange. 
The " shifts caused the end diaphragms to be slightly skewed to the abutment centerlines of bearing, 
but this was not structurally significant. Stage 2 beams were revised to avoid this problem, 
based on additional field survey verification and dimensional checks.`,
`Case #JE-F007:
Description of Error: Existing superstructure is being replaced in stages to maintain traffic, 
and contractor had survey performed after first half of the deck was removed. 
This indicated revised beam lengths were needed and contractor advised fabricator 
to use new lengths along with an "average" skew for detailing and fabrication. 
When erection started, interior diaphragms between first two lines were off by 1 1/2", 
equating to an error in the skew of 0 degree, 45 minutes. 
Erector shifted second line1 1/2" longitudinally, 
since interior diaphragms use 4 attachment bolts in horizontal lines at 3" spacing. 
However, by third line, shifting 1 1/2" resulted in interference between beam ends and the abutment back wall.
Solution Recommended: Shifted first and third beams 3/4" toward pier, second and fourth beams 3/4" away from pier, 
allowing installation of the on-site diaphragms. Interior diaphragms could have all 4 bolts installed in the first and third bays, 
but in the second bay (between lines 2 and 3), only 3 of 4 bolts per location could be installed until additional holes were field drilled. 
Unused holes in the beam webs were filled with short bolts to avoid future inspection confusion. 
End diaphragms sit on seat angles with only two bolts through oversize holes in the bottom flange. 
The " shifts caused the end diaphragms to be slightly skewed to the abutment centerlines of bearing, 
but this was not structurally significant. Stage 2 beams were revised to avoid this problem, 
based on additional field survey verification and dimensional checks.
Other Possible solutions: Making custom interior diaphragms, 
either by field welding/drilling and assembly, or by the fabricator redetailing 
and fabricating new asymmetric diaphragms with connections compensating for the 1 " offset. 
Either of these would have required additional planning, fabrication, cleaning and shop priming, 
possibly delaying construction of a week or more.
Remarks: Despite DOT 's standard note requiring the Contractor to field verify 
all pertinent dimensions for portions of existing structures incorporated into new construction, 
Contractors typically order fabricators to proceed based on record drawings (old design and shop plans) 
with minimal field checks. This is especially true when the Contractor's access is limited by traffic or other factors. 
Field problems routinely occur due to original construction errors, undocumented changes to the structure, 
substructure misalignment due to settlements, etc. between plans.`
). 