/*----------------------------------------------------------*/
/*  KNBCMATM.PL - Misattached Member Case Knowledge         */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(misattachedMember,
  [
    bridgeType                                   :0.3,
    errorMemberType                              :0.6,
    attachMemberType                             :0.5,
    errorMemberLocation                          :0.7,
    errorMemberClass                             :0.3,
    attachMemberClass                            :0.3,
    stiffenerType                                :0.7,
    stiffenerSpecifiedThickness                  :0.2*continuous_feature_eval(1),
    stiffenerSpecifiedWidth                      :0.2*continuous_feature_eval(10),
    stiffenerSpecifiedLength                     :0.2*continuous_feature_eval(1000),
    stiffenerSpecifiedWebThickness               :0.3*continuous_feature_eval(1.5),
    stiffenerSpecifiedClipDimensionsOnWeb        :0.3*continuous_feature_eval(10),
    stiffenerSpecifiedClipDimensionsOnFlange     :0.3*continuous_feature_eval(10),
    stiffenerSpecifiedSpacingBetween             :0.5*continuous_feature_eval(50),
    stiffenerSpecifiedDiaphragmAttachment        :0.5,
    stiffenerSpecifiedFlangeAttachment           :0.7,
    stiffenerSpecifiedTensionFlangeAttachmentType:0.7,
    stiffenerSpecifiedCompFlangeAttachmentType   :0.7,
    stiffenerActualTensionFlangeAttachmentType   :0.7,
    stiffenerActualCompFlangeAttachmentType      :0.7,
    stiffenerActualCategoryCFlange               :0.5,
    stiffenerActualTensionFlangeClipped          :0.3,
    stiffenerActualCompFlangeClipped             :0.3,
    stiffenerActualTensionFlangeAttached         :0.8,
    stiffenerActualCompFlangeAttached            :0.8
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(misattachedMember,
  [
    stiffenerSpecifiedThickness,
    stiffenerSpecifiedWidth,
    stiffenerSpecifiedLength,
    stiffenerSpecifiedWebThickness,
    stiffenerSpecifiedClipDimensionsOnWeb,
    stiffenerSpecifiedClipDimensionsOnFlange,
    stiffenerSpecifiedSpacingBetween
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(misattachedMember_1,misattachedMember,`MATM-C001`,`Misattached Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :tensionFlange,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedFlangeAttachment           :compressionFlange,
    stiffenerSpecifiedCompFlangeAttachmentType   :weld,
    stiffenerActualTensionFlangeAttachmentType   :weld,
    stiffenerActualCategoryCFlange               :true,
    stiffenerActualTensionFlangeAttached         :true,
    stiffenerActualCompFlangeAttached            :false
  ],
  `The intermediate stiffeners were welded to the tension flange instead of the compression flange.
Leave the tension flange welds and go ahead and weld stiffeners to the compression flange.
The tension flange welds need to be inspected using MT procedures.`,
`Case # FB162:

Description of Error: A girder has 8 stiffener bars welded to the tension flange. 
As detailed on Drawings, Section A should be welded with a 5/16" fillet on the top flange but was welded to the bottom flange; 
Section B shows a 5/16" fillet on the bottom flange but was welded on the top flange. 
Solution Recommended: Weld the stiffener bars to both flanges of girder. 
In addition, it is requested the stiffener to tension flange welds be inspected using MT procedures. 
Fatigue category of tension flange weld was checked by DOT and found acceptable for this case, 
so leave stiffener welded to tension flange.`
).

% Solution 2
caseSolution(misattachedMember_2,misattachedMember,`MATM-C002`,`Misattached Member Case Solution`,[dl170],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :compressionFlange,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    stiffenerType                                :intermediateStiffener,
    stiffenerSpecifiedDiaphragmAttachment        :true,
    stiffenerSpecifiedFlangeAttachment           :both,
    stiffenerSpecifiedTensionFlangeAttachmentType:boltedPlate,
    stiffenerSpecifiedCompFlangeAttachmentType   :weld,
    stiffenerActualTensionFlangeAttachmentType   :boltedPlate,
    stiffenerActualCompFlangeAttachmentType      :boltedPlate,
    stiffenerActualTensionFlangeAttached         :false,
    stiffenerActualCompFlangeAttached            :false
  ],
  `The stiffener was to be welded to the bottom flange.
However holes were drilled in the bottom flange for an auxiliary plate attachment.
Shorten the stiffener by 3/8 in. the thickness of the auxiliary plate.
Put an auxiliary plate at the bottom similar to the one at the top.`,
`Case # DL170:

Description of Error: The top flange is the tension flange in this area. 
Its connection was made properly. 
The stiffener was to be welded to the bottom flange but was not welded when it was noticed the driller had drilled holes in the top and bottom flange. 
The stiffener was not yet welded into the girder.
Solution Recommended: Shorten the stiffener by 3/8" (the thickness of the auxiliary plate). 
Put an auxiliary plate at the bottom, similar to the one at the top.`
).

% Solution 3
caseSolution(misattachedMember_3,misattachedMember,`MATM-C003`,`Misattached Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :tensionFlange,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :false,
    stiffenerSpecifiedFlangeAttachment           :compressionFlange,
    stiffenerSpecifiedCompFlangeAttachmentType   :weld,
    stiffenerActualTensionFlangeAttachmentType   :weld,
    stiffenerActualCompFlangeAttachmentType      :weld,
    stiffenerActualTensionFlangeAttached         :true,
    stiffenerActualCompFlangeAttached            :true
  ],
  `The intermediate stiffener was to be tight fit to bottom flange and was instead welded with
1/4 in. fillet weld on both sides.
The stiffener needs to be cut 1 in. short of the bottom flange.
The stiffener is to be ground smooth.
The piece of stiffener attached to the flange is to be removed and the flange ground smooth.`,
`Case # FB153:

Description of Error: An intermediate stiffener was to be tight fit to bottom flange. 
The shop welded the stiffener to the bottom flange with a both side 1/4" fillet. 
The fabricator then ground out as much weld as possible, but can not remove all of the weld metal. 
This is a fracture critical job.
Solution Recommended: The stiffener should be cut 1" short of the bottom flange. 
The bottom of the stiffener is to be ground smooth. 
The piece of stiffener attached to the flange is to be removed and the flange ground smooth.`
).

% Solution 4
caseSolution(misattachedMember_4,misattachedMember,`MATM-C004`,`Misattached Member Case Solution`,[ls137],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :bearingStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :compressionFlange,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    stiffenerType                                :bearing,
    stiffenerSpecifiedDiaphragmAttachment        :false,
    stiffenerSpecifiedFlangeAttachment           :tensionFlange,
    stiffenerSpecifiedTensionFlangeAttachmentType:weld,
    stiffenerActualCompFlangeAttachmentType      :weld,
    stiffenerActualCategoryCFlange               :true,
    stiffenerActualTensionFlangeAttached         :false,
    stiffenerActualCompFlangeAttached            :true
  ],
  `The stiffener was welded to the top flange instead of the bottom flange.
Leave the welds and weld the stiffener to the bottom flange.`,
`Case # LS137:
Description of Error: Bearing stiffeners at abutment were welded to the wrong flange. 
Solution Recommended: Leave incorrect stiffener welds as is and N.D. test (MT). 
Weld the stiffeners to correct flanges.
Fatigue category of incorrect welds was checked by DOT and found acceptable for this case so leave incorrect welds in place.`
).

% New Solution 5
caseSolution(misattachedMember_5,misattachedMember,`MATM-C005`,`Misattached Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :diaphragmBrace,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary
  ],
  ` The fabricator had approximately 10 welders take the DOT welding qualification test to weld on this project. 
The welder assigned to weld the diaphragm had failed the test.
Remove the welds and replace them by a certified welder.`,
`Case #BL-F003:
Description of Error: The fabricator had approximately 10 welders take the DOT welding qualification test to weld on this project. 
The welder assigned to weld the diaphragm had failed the test.
Solution Recommended: Remove the welds and replace them by a certified welder.
Other Possible solutions: Re-test the welder who made the original welds and accept the welds made on the job 
if he passed the second test.`
).
