/*----------------------------------------------------------*/
/*  KNBCMLCM.PL - Mislocated Member Case Knowledge          */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(mislocatedMember,
  [
    bridgeType                                   :0.3,
    errorMemberType                              :0.8,
    attachMemberType                             :0.5,
    errorMemberLocation                          :0.8,
    errorMemberClass                             :0.3,
    attachMemberClass                            :0.3,
    mislocatedMemberIntersection                 :0.9,
    mislocatedMemberInvertedPlacement            :0.8,
    mislocatedMemberDistanceCorrectLocation      :0.5,
    mislocatedMemberIntersectedItem              :0.5,
    stiffenerType                                :0.7,
    stiffenerSpecifiedThickness                  :0.2*continuous_feature_eval(1),
    stiffenerSpecifiedWidth                      :0.2*continuous_feature_eval(10),
    stiffenerSpecifiedLength                     :0.2*continuous_feature_eval(1000),
    stiffenerSpecifiedWebThickness               :0.4*continuous_feature_eval(1.5),
    stiffenerSpecifiedClipDimensionsOnWeb        :0.2*continuous_feature_eval(10),
    stiffenerSpecifiedClipDimensionsOnFlange     :0.2*continuous_feature_eval(10),
    stiffenerSpecifiedSpacingBetween             :0.5*continuous_feature_eval(50),
    stiffenerSpecifiedDiaphragmAttachment        :0.7,
    stiffenerSpecifiedFlangeAttachment           :0.2,
    stiffenerSpecifiedTensionFlangeAttachmentType:0.2,
    stiffenerSpecifiedCompFlangeAttachmentType   :0.2,
    stiffenerActualTensionFlangeAttachmentType   :0.5,
    stiffenerActualCompFlangeAttachmentType      :0.5,
    stiffenerActualCategoryCFlange               :0.7,
    stiffenerActualTensionFlangeClipped          :0.2,
    stiffenerActualCompFlangeClipped             :0.2,
    stiffenerActualTensionFlangeAttached         :0.3,
    stiffenerActualCompFlangeAttached            :0.3,
    stiffenerActualPlumbness                     :0.8*continuous_feature_eval(10),
    stiffenerActualMiddleOfSolePlate             :0.8
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(mislocatedMember,
  [
    mislocatedMemberDistanceCorrectLocation,
    stiffenerSpecifiedThickness,
    stiffenerSpecifiedWidth,
    stiffenerSpecifiedLength,
    stiffenerSpecifiedWebThickness,
    stiffenerSpecifiedClipDimensionsOnWeb,
    stiffenerSpecifiedClipDimensionsOnFlange,
    stiffenerSpecifiedSpacingBetween
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(mislocatedMember_1,mislocatedMember,`MLCM-C001`,`Mislocated Member Case Solution`,[dl169],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :splicePlate,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberIntersectedItem              :splicePlate,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :false,
    stiffenerActualTensionFlangeClipped          :false,
    stiffenerActualCompFlangeClipped             :false
  ],
  `A splice plate extended beyond the location of the stiffener.
The stiffener was shown to tight fit against both flanges.
The stiffener had already been welded into place.
Cut the stiffener off 3 in. from the flange to allow the splice plate to be placed in the proper location.`,
`Case #DL169:
Description of Error: A stiffener was shown to fit tight against both flanges. One inside splice plate extended beyond the location of the stiffener.
Solution Recommended: Cut the stiffener off 3" from the flange. 
This was acceptable since this was a plain stiffener rather than a diaphragm connection plate. 
Other possible solutions: the stiffener could have been moved far enough to miss the splice plate. 
This would have been the best solution had the error been noticed before the stiffener was in place. 
In actual case, shop did not realize there was a problem until they tried to clamp the splice plates in place for drilling.
`
).

% Solution 2
caseSolution(mislocatedMember_2,mislocatedMember,`MLCM-C002`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :false,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :12,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :true
  ],
  `Stiffeners were fitted and welded one foot from their specified location.
Leave stiffeners in place and weld new stiffeners at correct location.
Install bolts in holes of mislocated stiffeners.`,
`Case #MP146:
Description of Error: Near and far side stiffeners were fitted and welded at 22'11 13/16" from left hand end of girder, in lieu of 21'11 13/16". 
Solution Recommended: Weld new stiffeners at correct location, leave old stiffeners in place, install bolts in holes of mislocated stiffeners; blast and paint.
`
).

% Solution 3
caseSolution(mislocatedMember_3,mislocatedMember,`MLCM-C003`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :0.75,
    mislocatedMemberIntersectedItem              :hole,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :false,
    stiffenerActualTensionFlangeClipped          :false,
    stiffenerActualCompFlangeClipped             :false
  ],
  `Intermediate stiffener was mislocated and interferes with one of the bolts on the flange splice.
The top of the stiffener was to be tight fit.
Clip the top of the stiffener enough to clear the nut plus stick-thru by a 1/4 in.`,
`Case #MG115:
Description of Error: An intermediate stiffener that was to be located 5'-6 1/2" from the left end of the girder was shifted " to the right of its proper position which fouled one bolt of the flange splice.
Solution Recommended: Clip the top of the stiffener enough to clear the nut plus stick-thru by a 1/4". Probably clip 1 1/2".
`
).

% Solution 4
caseSolution(mislocatedMember_4,mislocatedMember,`MLCM-C004`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :false,
    mislocatedMemberInvertedPlacement            :true,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :true
  ],
  `The stiffener was put in upside down.
Another hole will be drilled in the stiffener and the top hole will be filled with a bolt.`,
`Case #MG164:
Description of Error: A stiffener was put in up side down. 
Solution Recommended: Another hole will be drilled in the stiffener and the top hole will be filled with a bolt.
`
).

% Solution 5
caseSolution(mislocatedMember_5,mislocatedMember,`MLCM-C005`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :plateGirder,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :compressionFlange,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :false,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :2,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :false
  ],
  `All studs were installed on a 5 1/2 in. gage instead of the specified 7 1/2 in. gage. It is alright to leave as is.`,
`Case #DL133:
Description of Error: All studs were installed on a 5 1/2" gage. Should have been a 7 1/2" gage. 
Solution Recommended: OK, to leave as is.
`
).

% Solution 6
caseSolution(mislocatedMember_6,mislocatedMember,`MLCM-C006`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :true,
    mislocatedMemberDistanceCorrectLocation      :0,
    mislocatedMemberIntersectedItem              :attachedMember,
    stiffenerType                                :intermediate,
    stiffenerSpecifiedDiaphragmAttachment        :true
  ],
  `A stiffener was connected upside down to the girder.
Therefore its bolt hole pattern does not match that of the floor beam.
The stiffener will be removed by means of air arc gouging exercising care not to gouge into web plate material.
The web plate shall be ground smooth after existing stiffener removal.
A new stiffener will be installed by a certified welder.`,
`Case #TF170:
Description of Error: Three fabricated girders have one connection stiffener each installed incorrectly ( upside down whereas the hole pattern no longer will match floor beam). 
Solution Recommended: New stiffeners will be fabricated and shipped loose to job site. 
The existing stiffeners will be removed as follows: using oxygen-acetylene torch, 
cut away existing stiffener leaving approximately two inch stub. 
This stub is then to be removed using air-arc carbon gouging down to the toe of the weld material exercising care not to gouge into parent material. 
The entire weld material and any stub material remaining will be removed by grinding so as to provide a smooth surface suitable for attaching the new stiffeners. 
New stiffeners will be attached by a certified welder using approved weld procedure. 
Preheat (prior to tacking) shall be required throughout the welding process. 
Field weld inspection will include magnetic particle testing. 
Other possible solutions: leave mislocated stiffener in place, coping stiffener to eliminate interference with other pieces as necessary. Field weld new stiffener in required position. 
Note dimensions in actual case did not allow use of this preferred solution.
`
).

% Solution 7
caseSolution(mislocatedMember_7,mislocatedMember,`MLCM-C007`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :20,
    mislocatedMemberIntersectedItem              :attachedMember,
    stiffenerType                                :intermediate
  ],
  `The girder was fabricated with stiffeners for another girder.
The three exterior web stiffeners need to be removed by arc air and grinding.
Partial removal of the web stiffeners at various locations will need to take place to make allowance for
erection of cross frames.
The remaining stiffeners will be left in place with new stiffeners welded in place at desired locations.`,
`Case #TF172:
Description of Error: The Girder was built with correct flanges and web, but with another girder's stiffener spacing. 
Solution Recommended: The change will require complete removal of the three exterior web stiffeners by arc and grinding, without damage to the web or flanges. 
Partial removal of the web stiffeners at 7'-9 9/16", 30'-9 9/16", and 53'-9 9/16" to make allowance for erection of cross frames. The remaining web stiffeners shall remain. 
Welding on new web stiffeners as shown on correct girder plans.
`
).

% Solution 8
caseSolution(mislocatedMember_8,mislocatedMember,`MLCM-C008`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :capBeam,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :false,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :5
  ],
  `A stiffener has been welded out of place.
Weld a new stiffener in the correct location.
Leave the mislocated stiffener in place as long as it does not interfere.`,
`Case #TF173:
Description of Error: On a steel box cap beam, an interior stiffener was welded out of place. 
The stiffener located 5" to the right of the plan location. 
It is intended to be directly opposite of a floor beam connection plate. 
Solution Recommended: Weld a new stiffener in the correct location. 
The mislocated stiffener could be left in place as long as it didn't interfere with the bolts of the top connection plate. 
Probably can't use automatic welder because new stiffener will be too close to existing stiffener.
`
).

% Solution 9
caseSolution(mislocatedMember_9,mislocatedMember,`MLCM-C009`,`Mislocated Member Case Solution`,[nc501],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :bearingStiffener,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :1,
    mislocatedMemberIntersectedItem              :attachedMember,
    stiffenerType                                :bearing,
    stiffenerActualPlumbness                     :1.3,
    stiffenerActualMiddleOfSolePlate             :true
  ],
  `Bearing stiffener welded in place out of plumb.
Kick equals 1 15/16 in. in lieu of 15/16 in.
The stiffener was left in place and a shim used to bolt cross frame to stiffener.`,
`Case #NC501:
Description of Error: Bearing stiffeners welded in place out of plumb. Kick is 1 15/16" in lieu of 15/16".
Solution Recommended: Since bottom location of stiffener above the sole plate is correct and out of plumbness was less than 5%,  
stiffener was left in place and a shim used to bolt cross frame to stiffener. 
Other possible solutions: Avoid removal unless absolutely needed so can avoid air arc gouging and grinding in the high stress bearing area. 
1) If bottom location of stiffener is within middle 50% of sole plate, leave stiffener as is and check plumbness. 
If out of plumb more than 5%, weld additional stiffeners to create a shear panel (space new stiffeners between 6" and 12" on center. 
New stiffeners half the thickness of bearing stiffeners). Check cross-frame connection clearance. 
2) If bottom location of stiffener is not within middle 50% of sole plate, add 2nd bearing stiffener.
`
).

% Solution 10
caseSolution(mislocatedMember_10,mislocatedMember,`MLCM-C010`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :splicePlate,
    attachMemberType                             :plateGirder,
    errorMemberLocation                          :splice,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberIntersectedItem              :attachedMember
  ],
  `The splice plate located on the low end of the floor beam interferes with the bottom flange of the floor beams.
Cut the bottom flange flush on the near side and the far side so that it no longer interferes with the floor beam.`,
`Case #TF177:
Description of Error: A splice plate located on the low end of the floor beam, interferes with the bottom flange of a floor beam.
Solution Recommended: Cut the bottom flange flush near side and far side (like the top flange) for a distance of 7".`
).

% New Solution 11
caseSolution(mislocatedMember_11,mislocatedMember,`MLCM-C011`,`Mislocated Member Case Solution`,[],success,
  [
    bridgeType                                   :plateGirder,
    errorMemberType                              :intermediateStiffener,
    attachMemberType                             :diaphragmBrace,
    errorMemberLocation                          :stiffenerAttachment,
    errorMemberClass                             :primary,
    attachMemberClass                            :primary,
    mislocatedMemberIntersection                 :true,
    mislocatedMemberInvertedPlacement            :false,
    mislocatedMemberDistanceCorrectLocation      :12,
    mislocatedMemberIntersectedItem              :hole,
    stiffenerType                                :intermediateStiffener 
   ],
  ` A connection stiffener for an interior cross frame was mislocated by one foot in the shop. 
It was not found until the field erection process.
Drill the web to accept a bolt-in stiffener at the correct location. 
Visual and bolt tension verification in the field is required for final checks.`,
`Case #LY-F002:
Description of Error: A connection stiffener for an interior cross frame was mislocated by one foot in the shop. 
It was not found until the field erection process.
Solution Recommended: Drill the web to accept a bolt-in stiffener at the correct location. 
Visual and bolt tension verification in the field is required for final checks.
Other Possible solutions: Remove the mislocated stiffener and field weld a new stiffener in the correct location. 
This would have required three coat paint removal and repainting.`
).
