/*----------------------------------------------------------*/
/*  KNBCMSPH.PL - Misshaped Hole Case Knowledge             */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(misshapedHole,
  [
    bridgeType                        :0.3,
    errorMemberType                   :0.6,
    attachMemberType                  :0.5,
    errorMemberLocation               :0.7,
    errorMemberClass                  :0.3,
    attachMemberClass                 :0.3,
    holeDetailsType                   :0.9,
    holeDetailsJointSlipCritical      :0.8,
    holeDetailsSpecifiedHoleDiameter  :0.5*continuous_feature_eval(2),
    holeDetailsActualDistanceElongated:0.7*continuous_feature_eval(2),
    holeDetailsSlotsAtCorrectSlope    :0.8
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(misshapedHole,
  [
    holeDetailsSpecifiedHoleDiameter,
    holeDetailsActualDistanceElongated
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(misshapedHole_1,misshapedHole,`MSPH-C001`,`Misshaped Hole Case Solution`,[fb150],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :plateGirder,
    errorMemberLocation               :tensionFlange,
    errorMemberClass                  :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false
  ],
  `There are egg shaped holes in the girder flanges.
Cut off existing flanges.
Add new plate using full penetration weld at flange and 5/16 in. weld at web.
100% RT at flange and 100% MT at web.`,
`Case #FB150:
Description of Error: There is an egg shaped holes in the girder flange.The hose is approximately 15/16 dia. by 1 1/8" slot. 
(Also see misshapedHole,MSPH-C008) 
Solution Recommended: Cut off existing flanges. Add new plate using full penetration weld at flange and 5/16 inch fillet weld at web.
100% RT at flange and 100% MT at web. 
`
).

% Solution 2
caseSolution(misshapedHole_2,misshapedHole,`MSPH-C002`,`Misshaped Hole Case Solution`,[],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :capBeam,
    attachMemberType                  :plateGirder,
    errorMemberLocation               :compressionFlange,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false,
    holeDetailsActualDistanceElongated:0.0625
  ],
  `The capBeam bottom flange holes where the bottom flange of span girders bolt has 36 holes elongated.
Leave the holes as fabricated and supply the field erector 36 hardened washers to be applied
both under the nut and head of the bolts.`,
`Case #JJ139:
Description of Error: Capbeam bottom flange holes where the bottom flange of span girders bolt to capbeam has 36 holes elongated by 1/16 inch.
Solution Recommended: Leave the holes as fabricated but supply the field erector 36 hardened washers to be applied both under the nut and head of the bolts. 
`
).

% Solution 3
caseSolution(misshapedHole_3,misshapedHole,`MSPH-C003`,`Misshaped Hole Case Solution`,[jj139],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :capBeam,
    attachMemberType                  :plateGirder,
    errorMemberLocation               :compressionFlange,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false
  ],
  `Capbeam bottom flange holes where girder bottom flange bolts to are elongated.
Furnish 1/2 in. plate washers to the erector to be used with the bolts.`,
`Case #JJ139:
Description of Error: Capbeam bottom flange where girder bottom flange bolts to capbeam has 32 holes that are elongated up to 3/8 inch. 
The corresponding bottom flange holes in the girder are not elongated.
Solution Recommended: Furnish plate washers which shall be 1/2 inch.
`
).

% Solution 4
caseSolution(misshapedHole_4,misshapedHole,`MSPH-C004`,`Misshaped Hole Case Solution`,[],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :splicePlate,
    attachMemberType                  :plateGirder,
    errorMemberLocation               :spliceConnection,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false,
    holeDetailsSpecifiedHoleDiameter  :0.9375,
    holeDetailsActualDistanceElongated:0.1875
  ],
  `There are several field splices that are fitting poorly.
When using drift pins to align splices the hole were elongated.
These holes are to be treated as short-slotted holes.
2% of the hole were allowed to be used as short-slotted holes.
However if the slot is in both outer plys then washers will be required under the head and nut of the bolt.`,
`Case #MG109:
Description of Error: There are several field splices that are fitting poorly. 
When using drift pins to align splices the hole were elongated. The elongation amounted to 3/16". 
These holes now were in the category of short slots (15/16" x 1 1/8")
Solution Recommended: 2% of the holes in a field splice were allowed to be short slots. 
However, if the slot is in both outer plys, then washers will be required under the head and nut of the bolt.
`
).

% Solution 5
caseSolution(misshapedHole_5,misshapedHole,`MSPH-C005`,`Misshaped Hole Case Solution`,[tf194],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :plateGirder,
    attachMemberType                  :splicePlate,
    errorMemberLocation               :web,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false,
    holeDetailsSpecifiedHoleDiameter  :0.9375,
    holeDetailsActualDistanceElongated:0.5
  ],
  `Several holes in the web were misshaped to become short or long slotted.
It is proposed to drill an extra set of holes down the center of the current pattern.
New splice plates need to be fabricated to match the new hole pattern.`,
`Case #TF194:
Description of Error: Several holes in the web were misshaped to become short or long slotted.
Solution Recommended: Add a center row of holes to the bolt hole pattern. In doing such, all bolts will be 7/8" diameter, 
this is a center ply only for slots, thus no special provisions are required for washers. 
The calculations indicate this approach allows the bolts to jointly develop a greater shear capacity than the original design. 
Calculations used allowable shear stress values of 15.5 ksi for standard hole, 13.5ksi short slot, 
and 9.0 ksi for long slot. 
`
).

% Solution 6
caseSolution(misshapedHole_6,misshapedHole,`MSPH-C006`,`Misshaped Hole Case Solution`,[tf195],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :plateGirder,
    attachMemberType                  :splicePlate,
    errorMemberLocation               :web,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false,
    holeDetailsSpecifiedHoleDiameter  :0.9375,
    holeDetailsActualDistanceElongated:0.328125
  ],
  `Several holes in the web were elongated at the splice connection.
Drill 1 3/16 in diameter holes for 1 1/8 in. bolts and use hardened washers on both sides.`,
`Case #TF195:
Description of Error: Several holes in the web were elongated at the splice connection. 
Solution Recommended: Drill 1 3/16 inch diameter holes for 1 1/8 inch bolts and use hardened washers on both sides.
Other Possible Solutions: Instead of using the uncommon bolt size of 1 1/8 inch as done in actual repair, 
consider use of I inch bolts in oversize holes and use hardened washers on both sides.
`
).

% Solution 7
caseSolution(misshapedHole_7,misshapedHole,`MSPH-C007`,`Misshaped Hole Case Solution`,[],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :plateGirder,
    errorMemberLocation               :compressionFlange,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :longSlotted,
    holeDetailsJointSlipCritical      :false,
    holeDetailsSlotsAtCorrectSlope    :false
  ],
  `The slots in sole plate at the roller joints are at the wrong slope.
Plug weld the slots and relocate them on the proper slope.`,
`Case #TF196:
Description of Error: The 2" X 15/16" slots in sole plate h211 at the roller joint are at a 1  in 6 slope in lieu of 1  in 12. 
Solution Recommended: Plug weld the slots and relocate them on the proper slope. 
`
).

% Solution 8
caseSolution(misshapedHole_8,misshapedHole,`MSPH-C008`,`Misshaped Hole Case Solution`,[tf214],success,
  [
    bridgeType                        :plateGirder,
    errorMemberType                   :plateGirder,
    attachMemberType                  :splicePlate,
    errorMemberLocation               :tensionFlange,
    errorMemberClass                  :primary,
    attachMemberClass                 :primary,
    holeDetailsType                   :circular,
    holeDetailsJointSlipCritical      :false,
    holeDetailsSpecifiedHoleDiameter  :0.9375,
    holeDetailsActualDistanceElongated:0.25
  ],
  `Egg-shaped holes occur on the flanges at a splice location. Cut off the existing flange.
Add new plate using full penetration weld at flange and fillet weld at web.
100 percent RT a flange and 100 percent MT at web.
Drill holes correctly.`,
`Case #TF214:
Description of Error: Egg-shaped holes occur on the flanges at a splice location. 
The holes are approximately 1 dia. ovals. 
(Also see misshapedHole, MSPH-C001)
Solution Recommended: Cut off the existing flange. 
Add new plate using full penetration weld at flange and fillet weld at web. 100 percent RT a flange and 100 percent MT at web. 
Drill holes correctly.
Other Possible Solutions: Drill all holes from the solid to 1 1/16" diameter holes for 1" diameter A325 holes if edge distance 
(AASHTO 1 3/4" edge distance for 1" bolts) had been present.
`
).

