/*----------------------------------------------------------*/
/*  KNBCMSZH.PL - Missized Hole Case Knowledge              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(missizedHole,
  [
    bridgeType                             :0.3,
    errorMemberType                        :0.5,
    attachMemberType                       :0.4,
    errorMemberLocation                    :0.6,
    errorMemberClass                       :0.3,
    attachMemberClass                      :0.3,
    holeDetailsType                        :0.7,
    holeDetailsNumberWithErrors            :0.4*continuous_feature_eval(50),
    holeDetailsNumberInGrouping            :0.4*continuous_feature_eval(100),
    holeDetailsActualBoltDiameter          :0.8*continuous_feature_eval(2),
    holeDetailsActualHoleDiameter          :0.8*continuous_feature_eval(2),
    holeDetailsSpecifiedBoltDiameter       :0.8*continuous_feature_eval(2),
    holeDetailsSpecifiedHoleDiameter       :0.8*continuous_feature_eval(2),
    holeDetailsEdgeEndDistanceSpecification:0.8
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(missizedHole,
  [
    holeDetailsActualBoltDiameter,
    holeDetailsActualHoleDiameter,
    holeDetailsSpecifiedBoltDiameter,
    holeDetailsSpecifiedHoleDiameter
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(missizedHole_1,missizedHole,`MSZH-C001`,`Missized Hole Case Solution`,[dl135],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    errorMemberLocation                    :bearing,
    errorMemberClass                       :primary,
    holeDetailsType                        :circular,
    holeDetailsNumberWithErrors            :2,
    holeDetailsNumberInGrouping            :3,
    holeDetailsActualBoltDiameter          :0.75,
    holeDetailsActualHoleDiameter          :0.8125,
    holeDetailsSpecifiedBoltDiameter       :0.875,
    holeDetailsSpecifiedHoleDiameter       :0.9375,
    holeDetailsEdgeEndDistanceSpecification:false
  ],
  `Bearings should have been drilled and tapped for 3/4 in. bolts instead of 7/8 in. OK to leave as is.
Make revised shop drawings showing larger bolts.`,
`Case #DL135:
Description of Error: Bearings should have been drilled and tapped for 3/4" dia. bolts were made for 7/8" dia. bolts instead.
Solution Recommended: OK to leave as is. Make revised drawings showing larger holes. 
Make shop sheet to return " bolts to stock and to order 7/8" bolts.
`
).

% Solution 2
caseSolution(missizedHole_2,missizedHole,`MSZH-C002`,`Missized Hole Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    attachMemberType                       :splicePlate,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    holeDetailsType                        :circular,
    holeDetailsActualHoleDiameter          :1,
    holeDetailsSpecifiedBoltDiameter       :0.875,
    holeDetailsSpecifiedHoleDiameter       :0.9375,
    holeDetailsEdgeEndDistanceSpecification:false
  ],
  `1 in. holes were drilled in the web at the field splice instead of 15/16 in. holes.
Enlarge the holes to 1 1/16 in. to allow 1 in. bolts.
The splice plates need to be refabricated as they do not have the required edge distance for 1 in. bolts.`,
`Case #NC500:
Description of Error: 1 in. holes were drilled in the web at the field splice instead of 15/16 in. holes.
Solution Recommended: Enlarge the holes to 1 1/16 inch and use 1 inch bolts. 
New splice plates are required to provide the 1 3/4" edge distance, to satisfy the requirement for edge distance for 1" bolts. 
The fill plates were a little shy for edge distance for 1" bolts, OK as is, new fill plates are not required.
Other Possible Solutions: Could have used 7/8" bolts with hardened washers, but 1" bolt solution was preferred due to the fact that then if the joint slipped and bolts went into bearing all the bolts would be brought to bear.
`
).

