/*----------------------------------------------------------*/
/*  KNBCSFRC.PL - Stress Fracture Case Knowledge            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(stressFracture,
  [
    bridgeType                       :0.3,
    errorMemberType                  :0.7,
    attachMemberType                 :0.7,
    errorMemberLocation              :0.8,
    errorMemberClass                 :0.5,
    attachMemberClass                :0.5,
    stressErrorMemberLevel           :0.8,
    stressAttachMemberLevel          :0.8,
    stressFatigueConcerns            :0.8,
    stressFractures                  :0.9,
    stressMaxGap                     :0.6*continuous_feature_eval(0.5),
    stressNumberOfFracturesAtLocation:0.6,
    stressAngleOfBend                :0.5*continuous_feature_eval(2)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(stressFracture,
  [
    stressMaxGap,
    stressAngleOfBend
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(stressFracture_1,stressFracture,`SFRC-C001`,`Stress Fracture Case Solution`,[mp143],success,
  [
    bridgeType                       :rolled,
    errorMemberType                  :diaphragmBrace,
    errorMemberLocation              :gussetPlate,
    errorMemberClass                 :primary,
    stressAttachMemberLevel          :unknown,
    stressFatigueConcerns            :low,
    stressFractures                  :true,
    stressMaxGap                     :0.25,
    stressNumberOfFracturesAtLocation:3,
    stressAngleOfBend                :90
  ],
  `Stress fractures occur at the corners of bent diaphragm plates.
The stress fractures were dye-penetrant examined.
All diaphragms with excess 1/4 in. gap were not used.
All diaphragms less than 1/4 in. gap were repaired by welding with FCAW approved welding procedure and ground smooth.`,
`Case #MP143:
Description of Error: Stress fractures occur at the corners of bent diaphragm plates.
Solution Recommended: All diaphragms with stress fractures will be subject to a dye penetrant examination on the entire of length of the bend. 
The dye penetrant examination will be in accordance with ASTM E165 and a written dye penetrant examination procedure. 
All diaphragms with excess 1/4" gap will not be used on this project. 
All diaphragms less than 1/4" gap will be repaired by welding with FCAW approved welding procedure and ground smooth.
`
).

% Solution 2
caseSolution(stressFracture_2,stressFracture,`SFRC-C002`,`Stress Fracture Case Solution`,[fb154],success,
  [
    bridgeType                       :plateGirder,
    errorMemberType                  :diaphragmBrace,
    attachMemberType                 :intermediateStiffener,
    errorMemberLocation              :web,
    errorMemberClass                 :primary,
    attachMemberClass                :primary,
    stressFractures                  :true,
    stressNumberOfFracturesAtLocation:2
  ],
  `Cracks occur in the vertical weld attaching the stiffeners to the web or else
in the vertical weld connecting the floorbeam to the stiffener.
Preheat.
Remove the cracked weld using air-arc carbon gouging.
Grind the gouged areas.
Inspect the gouged areas using magnetic particle testing.
Replace the removed weld metals by rewelding and then reinspect the crack area using
magnetic particle testing not before 24 hours after welding is complete.`,
`Case #FB154
Description of Error: Cracks occur in the vertical weld attaching the stiffeners to the web or else
in the vertical weld connecting the floorbeam to the stiffener.
Solution Recommended: Preheat. Remove the cracked weld using air-arc carbon gouging.
Grind the gouged areas. Inspect the gouged areas using magnetic particle testing. 
Replace the removed weld metals by rewelding, air cool to ambient temperature and then reinspect the crack area using magnetic particle testing not before 24 hours after welding is complete.
Additional Comments: This is not a fabrication error. 
This case arose during the retrofit of an existing bridge. 
The case is included here to provide an example of cracking. 
If a similar case is encountered, refer to NCHRP Report 
(National Cooperative Highway Research Program Report 336: DISTORTION-INDUCED FATIGUE CRACING IN STEEL BRIDGES ).
`
).

