/*----------------------------------------------------------*/
/*  KNBCSURL.PL - Surface Lamination Case Knowledge         */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(surfaceLamination,
  [
    bridgeType                    :0.3,
    errorMemberType               :0.6,
    attachMemberType              :0.3,
    errorMemberLocation           :0.7,
    errorMemberClass              :0.3,
    attachMemberClass             :0.3,
    laminationSurfaceType         :0.9,
    laminationMappingDocumentation:0.7,
    laminationTestRequired        :0.6,
    laminationLengthOfDeformity   :0.5*continuous_feature_eval(200),
    laminationWidthOfDeformity    :0.5*continuous_feature_eval(100)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(surfaceLamination,
  [
    laminationLengthOfDeformity,
    laminationWidthOfDeformity
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(surfaceLamination_1,surfaceLamination,`SURL-C001`,`Surface Lamination Case Solution`,[mg112],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :plateGirder,
    errorMemberLocation           :tensionFlange,
    errorMemberClass              :primary,
    laminationMappingDocumentation:complete,
    laminationLengthOfDeformity   :40.25
  ],
  `A lamination appears in the top flange of the girder.
This repair shall be made by preparing a cavity by means of grinding or air arc gouging to a depth of 1/4 to 3/8.
The ends of the cavity shall taper smoothly up to the plate surface at a slope not to exceed 1 to 1.
Where the cavity extends to the plate edge an edge run-off tab shall be used.
Preheat shall be used and temperature shall be maintained until repair is complete, and 
to the end of the minimum postheat period.
The repair weld shall be ground flush and base metal suspect area shall again be inspected by means of UT to
determine if any applicable change has occurred as a result of the sealing process.`,
`Case #MG112:
Description of Error: A lamination appears in the top flange of the girder. 
Solution Recommended: This repair shall be made by preparing a cavity by means of grinding or air arc gouging to a depth of  to 3/8 inch. 
The ends of the cavity shall taper smoothly up to the plate surface at a slope not to exceed 1:1. Where the cavity extends to the plate edge, 
an edge run-off tab shall be used. 
Preheat 250 -450 degree F shall be used and temperature shall be maintained until repair is complete. 
Welding electrode (FCM) purchased this contract shall be used. Shielded metal arc or submerged arc may be used. 
However, at least the first four layers of any repair shall be shielded metal arc welding using electrodes of 1/8 or 5/32" diameter. 
The maximum pass thickness shall be 1/8" for SMAW or 1/4" SAW. Welding parameters shall be as specified in the applicable WPS in the following table. 
SMAW - WPS 90-15 
SAW - WPS 90-890-990-1090-11
Following welding, postheat shall be employed and shall continue without interruption from the completion of
repair welding to the end of the minimum postheat period.
Postheat of the repair area shall be between 400 degree and 500 degree F for one hour per inch of repair weld thickness or
for two hours whichever is less.
The repair weld shall be ground flush and base metal suspect area shall again be inspected by means of UT to
determine if any applicable change has occurred as a result of the sealing process.
`
).


% Solution 2
caseSolution(surfaceLamination_2,surfaceLamination,`SURL-C002`,`Surface Lamination Case Solution`,[fb158],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :plateGirder,
    errorMemberLocation           :tensionFlange,
    errorMemberClass              :primary,
    laminationMappingDocumentation:complete,
    laminationLengthOfDeformity   :43,
    laminationWidthOfDeformity    :23.5
  ],
  `A lamination appears in the top flange of the girder.
This repair shall be made by preparing a cavity by means of grinding or air arc gouging to a depth of 1/4 to 3/8.
The ends of the cavity shall taper smoothly up to the plate surface at a slope not to exceed 1 to 1.
Where the cavity extends to the plate edge an edge run-off tab shall be used.
Preheat shall be used and temperature shall be maintained until repair is complete, and
to the end of the minimum postheat period.
The repair weld shall be ground flush and base metal suspect area shall again be inspected by means of UT to
determine if any applicable change has occurred as a result of the sealing process.`,
`Case #: FB158:
Description of Error: A lamination appears in the top flange of the girder.
Solution Recommended: This repair shall be made by preparing a cavity by means of grinding or air arc gouging to a depth of 1/4 to 3/8 inch. 
The ends of the cavity shall taper smoothly up to the plate surface at a slope not to exceed 1 to 1. 
Where the cavity extends to the plate edge, an edge run-off tab shall be used. 
Preheat 250-450 degree F shall be used and temperature shall be maintained until repair is complete. 
Welding electrode (FCM) purchased this contract shall be used. Shielded metal arc or submerged arc may be used. 
However at least the first four layers of any repair shall be shielded metal arc welding using electrodes of 1/8 or 5/32 diameter. 
The maximum pass thickness shall be 1/8 for SMAW or 1/4 SAW. Welding parameter shall be as specified in the applicable WPS in the following table. 
SMAW - WPS 90-15 
SAW - WPS 90-890-990-1090-11. 
Following welding,  postheat shall be employed and shall continue without interruption from the completion of repair welding to the end of the minimum postheat period. 
Postheat of the repair area shall be between 400 degree and 500 degree F for one hour per inch of repair weld thickness or for two hours whichever is less. 
The repair weld shall be ground flush and base metal suspect area shall again be inspected by means of UT to determine 
if any applicable change has occurred as a result of the sealing process.
`
).


% Solution 3
caseSolution(surfaceLamination_3,surfaceLamination,`SURL-C003`,`Surface Lamination Case Solution`,[nc510],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :plateGirder,
    errorMemberLocation           :compressionFlange,
    errorMemberClass              :primary,
    laminationSurfaceType         :surface,
    laminationMappingDocumentation:complete,
    laminationTestRequired        :ut,
    laminationLengthOfDeformity   :137,
    laminationWidthOfDeformity    :0.5
  ],
  `Laminations occur in the girder flanges.
Cut off the defective area and butt-weld new flange material to the plate.
The repair should be tested as required for metal soundness.
All repaired material to be used in top flanges compression regions.`,
`Case #: NC510:
Description of Error: Laminations occur in the girder flanges.
Solution Recommended: Cut off the defective area. 
UT test after cutting to assure all laminations are removed. Butt-weld new flange material to the plate. 
Butt welds shall be at the good end, if the end far thist from the laminations. All butt welds to be radiographed. 
All repaired material to be used in top flange compression regions. 
Plates marked B, C, D, and E constitutes top flange of the drop-in piece of span 2. 
Plate A constitutes top flange of an end span. 
Laminated area of Plate A should be placed at the free end (abutment) and not the field splice end of the girder piece.
`
).


% New Solution 4
caseSolution(surfaceLamination_4,surfaceLamination,`SURL-C004`,`Surface Lamination Case Solution`,[scf002],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :webPlate,
    attachMemberType              :flangePlate,
    errorMemberLocation           :web,
    errorMemberClass              :primary,
    attachMemberClass             :primary
  ],
  ` Lamination of 12 mm web plate as developed from the mill, 
discovered in process of fabrication after flange plates were attached.
Ultrasonically test for limits of lamination in web plate. 
Find end of lamination, drill hole and install bolt.`,
`Case #SC-F002:
Description of Error: Lamination of 12 mm web plate as developed from the mill, 
discovered in process of fabrication after flange plates were attached
Solution Recommended: Ultrasonically test for limits of lamination in web plate. 
Find end of lamination, drill hole and install bolt.
Other Possible solutions: Reject girder and make a new one, cut web out, weld in new web.`
).

% New Solution 5
caseSolution(surfaceLamination_5,surfaceLamination,`SURL-C005`,`Surface Lamination Case Solution`,[mbf002],success,
  [
    bridgeType                    :plateGirder,
    errorMemberType               :baseMetal,
    errorMemberLocation           :baseMetal,
    errorMemberClass              :primary,
    attachMemberClass             :primary,
    laminationTestRequired        :ut,
    laminationWidthOfDeformity    :0.25

  ],
  ` Laminar discontinuity in the base metal apparent on the surface of the base metal.
The recommended solutions are based on the description of the discontinuity: 
1) for any discontinuity 1 inch in length or less, no plate repair is required, 
and need not be explored. 
2) For any discontinuity over 1 inch in length and 1/8 inches maximum depth, 
no plate repair required, but the depth should be explored. 
3) For any discontinuity over 1 inch in length with depth over 1/8 inches but not greater 
than 1/4 inches, removal is required, but not need weld. 
4) For any discontinuity over 1 inch in length with depth over 1/4 inches but not grater than 1 inch, 
completely remove and weld are required. 
Aggregate length of the welding shall not exceed 20% of the length of the plate edge being repaired.
5) For any discontinuity over 1 inch in length with depth greater than 1 inch, see AWS 3.2.3.7.`,
`Case #MB-F002:
Description of Error: Laminar discontinuity in the base metal apparent on the surface of the base metal.
Solution Recommended: The recommended solutions are based on the description of the discontinuity: 
1) for any discontinuity 1 inch in length or less, no plate repair is required, 
and need not be explored. 
2) For any discontinuity over 1 inch in length and 1/8 inches maximum depth, 
no plate repair required, but the depth should be explored. 
3) For any discontinuity over 1 inch in length with depth over 1/8 inches but not greater than 1/4 inches, 
removal is required, but not need weld. 
4) For any discontinuity over 1 inch in length with depth over 1/4 inches but not grater than 1 inch, 
completely remove and weld are required. 
Aggregate length of the welding shall not exceed 20% of the length of the plate edge being repaired.
5) For any discontinuity over 1 inch in length with depth greater than 1 inch, see AWS 3.2.3.7.
If welding is required, use a single arc semi-automatic submerged arc weld(S.A.W.) after preparation. 
Magnetic particle inspection (M.T.) and/or ultrasonic inspection (U.T.) are require for the final checks.`
). 

