/*----------------------------------------------------------*/
/*  KNBCWHD.PL - Welding/Heating Distortion                 */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/

feature_weights(weldingHeatingDistortion,
  [
    bridgeType                                   :0.3,
    errorMemberType                              :0.6,
    attachMemberType                             :0.5,
    errorMemberLocation                          :0.7,
    errorMemberClass                             :0.3,
    attachMemberClass                            :0.3,
    designedTemperature               		 :0.6,
    actualTemperature                 		 :0.6,
    causeOfDistortion		                   :0.8,     
    typeOfDistortion          		       :0.8
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/




% New Solution 1
caseSolution(weldingHeatingDistortion_1,weldingHeatingDistortion,`WHD-C001`,`Welding Heating Distortion Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    errorMemberClass                       :primary,
    designedTemperature                :1150,
    actualTemperature                  :1400,
    causeOfDistortion            :overHeating,     
    typeOfDistortion             :overCamber
  ], 
  ` Over heating of flange and web were occurred while heat cambering. 
Maximum temperature of 1150 degree F allowed by contract. Temperature indicating crayon of 1200 degree F was used to determine excessive heat. 
Actual temperature estimated at 1400 degree F using color comparison chart.
Fabricator hired metallurgical engineer to assess potential damage. 
A New Age Industries Pin Brinell Portable Metal Hardness Tester was used. 
Converts to Rockwell R81 and R89: approximately 81 ksi and 89 ksi tensile strength. 
Metallurgist recommended acceptance of material. Hardness was in expected range. 
No further testing warranted.`,
`Case #RL-F001:
Description of Error: Over heating of flange and web were occurred while heat cambering. 
Maximum temperature of 1150 degree F allowed by contract. 
Temperature indicating crayon of 1200 degree F was used to determine excessive heat. 
Actual temperature estimated at 1400 degree F using color comparison chart.
Solution Recommended: Fabricator hired metallurgical engineer to assess potential damage. 
A New Age Industries Pin Brinell Portable Metal Hardness Tester was used. 
Converts to Rockwell R81 and R89: approximately 81 ksi and 89 ksi tensile strength. 
Metallurgist recommended acceptance of material. Hardness was in expected range. 
No further testing warranted. 
Remarks: Damage was likely avoided due to a relatively slow cooling rate through the transition temperature range. 
Recommend a gradual removal of heat-source to allow a slow cooling in similar situations.
Other Possible solutions: Had hardness been excessive a microscopic examination 
of the grain structure could have been used to determine condition of material.`
).

% New Solution 2
caseSolution(weldingHeatingDistortion_2,weldingHeatingDistortion,`WHD-C002`,`Welding Heating Distortion Case Solution`,[],success,
  [
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    attachMemberType                       :webPlate,
    errorMemberLocation                    :tensionFlange,
    errorMemberClass                       :fractureCritical,
    attachMemberClass                      :fractureCritical,
    causeOfDistortion                         :welding,    
    typeOfDistortion             :tilt
  ], 
 `Distortion from welding tension flange to web caused tilt (from square) in excess of 1-1/4" at flange web juncture. 
Fracture critical member. Tilt was excessive entire length of girder.
Fabricator proposed removing up to 50% depth of weld metal (full penetration), 
apply line heating to correct tilt to within " and reweld excavated area. 
Measure with framing square and tape measure at web/flange juncture 
and at edge of flange to determining offset are required for final checks.`,
`Case #VK-F001:
Description of Error: Distortion from welding tension flange to web caused tilt (from square) in excess of 1-1/4" at flange web juncture. 
Fracture critical member. Tilt was excessive entire length of girder.
Solution Recommended: Fabricator proposed removing up to 50% depth of weld metal (full penetration), 
apply line heating to correct tilt to within " and reweld excavated area. 
Measure with framing square and tape measure at web/flange juncture and at edge of flange 
to determining offset are required for final checks.
Other Possible solutions: Line heating without excavation of weld was attempted, 
but was insufficient to correct tilt.`
).

% New Solution 3
caseSolution(weldingHeatingDistortion_3,weldingHeatingDistortion,`WHD-C003`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    attachMemberType                       :bearingStiffener,
    errorMemberLocation                    :stiffenerAttachment,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :welding,     
    typeOfDistortion             :crack
  ],
  ` Pins welded to radiused base plates formed rocker type bearing assemblies. 
After subjecting parts to hot dipped galvanizing, 
cracking was noted at corners for a minimum of eight welded assemblies. 
Magnetic particle testing (MT) was utilized to determine extent of cracking. 
Excavate weld where cracking was detected, grind area smooth, 
preheat reweld and test MT method after cooling to ambient temperature.`,
`Case #VK-F002:
Description of Error: Pins welded to radiused base plates formed rocker type bearing assemblies. 
After subjecting parts to hot dipped galvanizing, cracking was noted at corners for a minimum of eight welded assemblies. 
Magnetic particle testing (MT) was utilized to determine extent of cracking. 
Solution Recommended: Excavate weld where cracking was detected, grind area smooth, 
preheat reweld and test MT method after cooling to ambient temperature. 
Remarks: Seal weld was not included on design drawings. 
Fabricator included it to avoid leakage from galvanizing. 
Other Possible solutions: It was determined that cracks originated from seal welded ends of assemblies. 
Ends were excavated, grooved and rewelded to and extending beyond the corners.`
).

% New Solution 4
caseSolution(weldingHeatingDistortion_4,weldingHeatingDistortion,`WHD-C004`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :webPlate,
    attachMemberType                       :flangePlate,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :welding,     
    typeOfDistortion             :buckling
  ],
  ` Web buckling (distortion) caused by flange to web welding. 
Depth of distortion measured with straight edge between panels.
Apply spot heating in distorted area on convex side to reduce buckling to within tolerance. 
Tape measure and straight edge determined that distortion was corrected to within required tolerance between panels 
(top and bottom flange and stiffeners).`,
`Case #VK-F003:
Description of Error: Web buckling (distortion) caused by flange to web welding. 
Depth of distortion measured with straight edge between panels.
Solution Recommended: Apply spot heating in distorted area on convex side to reduce buckling to within tolerance. 
Tape measure and straight edge determined that distortion was corrected 
to within required tolerance between panels (top and bottom flange and stiffeners).
Other Possible solutions: Add stiffener in affected area.`
).

% New Solution 5
caseSolution(weldingHeatingDistortion_5,weldingHeatingDistortion,`WHD-C005`,`Welding Heating Distortion Case Solution`,[dlf003],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :webPlate,
    attachMemberType                       :flangePlate,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :heating,
    typeOfDistortion             :buckling
  ],
  ` During heat application to correct for camber, Vee heat in web caused severe distortion.
Lay-out and mark grid pattern over affected area (2" grid) on convex side. 
Apply spot heat to each grid square. Each heat should be approximately 1 " diameter. 
Begin heats at outside perimeter and progress towards center. Apply jacking force during heating (optional).`,
`Case #DL-F003:
Description of Error: During heat application to correct for camber, Vee heat in web caused severe distortion.
Solution Recommended: Lay-out and mark grid pattern over affected area (2" grid) on convex side. 
Apply spot heat to each grid square. Each heat should be approximately 1 1/2" diameter. 
Begin heats at outside perimeter and progress towards center. Apply jacking force during heating (optional).
Remarks: Spot heats should be circular and diameter held to less than 3 times material thickness. 
A cutting torch affords better control than a " rose bud" or heating torch.
Other Possible solutions: None- prevention would be to avoid heating web. 
If web must be heated, than heat only at stiffener locations, or attach (tack weld) temporary stiffener 
to allow web heating and remove stiffener after heating is complete.`
).

% New Solution 6
caseSolution(weldingHeatingDistortion_6,weldingHeatingDistortion,`WHD-C006`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :rolledBeam,
    errorMemberClass                       :primary,
    designedTemperature                :1100,
    actualTemperature                  :1200,
    causeOfDistortion                         :overHeating
  ],
  ` Heating with oxy-fuel torch to camber, curve or straighten a member, but not monitoring the temperature with thermal crayons or electronic sensors. 
QA Inspector suspects material was overheated (over 1200 F/650 C for low alloy, 1100 F/ 600 C for Q & T) based on observation of bright red color during heating, 
local distortion/melting of base metal and mill scale, or temper colors on steel surface. 
Overheating may reduce ductility and toughness, initiate or propagate discontinuities, 
cause local distortion and high residual stresses, and adversely effect material properties of quenched and tempered steel.
Overheating may cause irreversible effects, so "repair" may not be possible without material replacement. 
Physical properties of heated areas must be assessed to determine if material is still acceptable for incorporation in structure. 
Possible indicators include hardness checks (Brinell, Knoop, Vickers or Rockwell) which can be down in-situ, 
or yield, ductility and Charpy V-notch tests which require removing material for specimens. 
Metallographic analysis can determine if microstructure has change, 
but this is very sophisticated and site-specific for this situation. 
Tests should be conducted by a qualified testing agency at the fabricator's expense. 
If hardness testing provides adequate assurance, the material bay then be accepted. 
Otherwise, either the material must be completely replaced or an adequate number of specimens extracted and tested to verify properties. 
It tests are acceptable, the fabricator must develop a method to replace the specimens.`,
`Case #JE-F001:
Description of Error: Heating with oxy-fuel torch to camber, curve or straighten a member, 
but not monitoring the temperature with thermal crayons or electronic sensors. 
QA Inspector suspects material was overheated (over 1200 F/650 C for low alloy, 1100 F/ 600 C for Q & T) based on observation of bright red color during heating, 
local distortion/melting of base metal and mill scale, or temper colors on steel surface. 
Overheating may reduce ductility and toughness, 
initiate or propagate discontinuities, cause local distortion and high residual stresses, 
and adversely effect material properties of quenched and tempered steel.
Solution Recommended: Overheating may cause irreversible effects, so "repair" may not be possible without material replacement. 
Physical properties of heated areas must be assessed to determine if material is still acceptable for incorporation in structure. 
Possible indicators include hardness checks (Brinell, Knoop, Vickers or Rockwell) which can be down in-situ, 
or yield, ductility and Charpy V-notch tests which require removing material for specimens. 
Metallographic analysis can determine if microstructure has change, 
but this is very sophisticated and site-specific for this situation. 
Tests should be conducted by a qualified testing agency at the fabricator's expense. 
If hardness testing provides adequate assurance, the material bay then be accepted. 
Otherwise, either the material must be completely replaced or an adequate number of specimens extracted and tested to verify properties. 
It tests are acceptable, the fabricator must develop a method to replace the specimens.
Other Possible solutions: Replace material: extensive NDE, including wet-particle MT, 
through thickness and surface wave UT, and hardness testing; stress relief of heated areas (difficult, 
and unwanted distortion possible); or adding reinforcing plates. 
Remarks: For most mild steeks )nominal yield  50 ksi / 345 mPa), heat not exceeding transition temperature (1600 F/870 C) 
and cooling in air without quenching probably results in minimal adverse changes to properties, 
However, must have some verification.`
).

% New Solution 7
caseSolution(weldingHeatingDistortion_7,weldingHeatingDistortion,`WHD-C007`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :plateGirder,
    errorMemberClass                       :primary,
    causeOfDistortion                         :lackOfPreheating
  ],
  ` Flange to web fillet welds made without adequately preheating flange and/or web per Section 4.2 (also 12.14 for FCM) 
of the D1.5 Bridge Welding Code to avoid potential problems from rapid cooling, moisture, etc. 
Temperature too low at juncture and/or within 3" /75 mm in all directions. 
Heavy flanges may have needed multiple torches or longer "soak" time for through thickness heating. 
eat directed at flange may not have transferred to web between tacks.
Varied by location and circumstances as follows: 1. No preheat, 
temperature below 32 F / 0 C: for welds on non-load carrying members such as diaphragms, 
close visual inspection and 100% MT- any questionable welds replaced. For welds on main load carrying members, replace welds. 
2. Inadequate preheat, but base metal above 32 F/0 C: for non-load carrying members, close visual inspection, 
MT 25% plus any anomalies observed -deficient welds replaced. 
For non-FCM main members, 100% VT plus MT- replace deficient or questionable welds. 
For FCM, replace welds in accord with Fracture Control Plan.`,
`Case #JE-F002:
Description of Error: Flange to web fillet welds made without adequately preheating flange and/or web per Section 4.2 (also 12.14 for FCM) of the D1.5 
Bridge Welding Code to avoid potential problems from rapid cooling, moisture, etc. 
Temperature too low at juncture and/or within 3" /75 mm in all directions. 
Heavy flanges may have needed multiple torches or longer "soak" time for through thickness heating. 
Heat directed at flange may not have transferred to web between tacks.
Solution Recommended: Varied by location and circumstances as follows: 
1. No preheat, temperature below 32 F / 0 C: for welds on non-load carrying members such as diaphragms, 
close visual inspection and 100% MT- any questionable welds replaced. 
For welds on main load carrying members, replace welds. 
2. Inadequate preheat, but base metal above 32 F/0 C: for non-load carrying members, 
close visual inspection, MT 25% plus any anomalies observed -deficient welds replaced. 
For non-FCM main members, 100% VT plus MT- replace deficient or questionable welds. 
For FCM, replace welds in accord with Fracture Control Plan. 
Remarks: Removing welds may be done if necessary, but this causes additional thermal cycles 
and residual stresses in base metal and may cause more defects than are removed. 
Being punitive to fabricator may be justified for repeated violations, 
but do not require actions that may be detrimental to the final product.
Other Possible solutions: Replace all welds; postheat welds plus NDE 
and destructive tests on mock-ups; qualification of parameters on mock-ups (NOT encouraged!); 
or sophisticated tests on diffusible hydrogen and residual stresses plus NDE.`
).

% New Solution 8
caseSolution(weldingHeatingDistortion_8,weldingHeatingDistortion,`WHD-C008`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :webPlate,
    attachMemberType                       :flangePlate,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :underSizeWeld
  ],
  ` Brackets made of web surrounded on 3 or 4 sides with fillet-welded flanges. 
Min fillet size prescribed by Table 2.2 of D1.5 Bridge Welding Code not satisfied: min=5/16", actual=11/32". 
Inside corners impede removal of undersize welds without damage to base metal. Time-critical project.
Just adding more weld wouldn't satisfy Code intent for minimum heat input on each pass to insure full fusion and good weld properties. 
Evaluated which welds sustained tensile/fatigue loads and had all weld throat sizes documented. 
For welds with significant fatigue and more than 1/32" undersize, required welds replacement. 
For welds in compression of low fatigue, required replacement of welds more than 1/16" undersize. 
Required 100% MT on undersize non-replaced and on replaced welds. 
Required future QC plan from shop to avoid recurrences.`,
`Case #JE-F004:
Description of Error: Brackets made of web surrounded on 3 or 4 sides with fillet-welded flanges. 
Min fillet size prescribed by Table 2.2 of D1.5 Bridge Welding Code not satisfied: min=5/16", actual=11/32". 
Inside corners impede removal of undersize welds without damage to base metal. Time-critical project.
Solution Recommended: Just adding more weld wouldn't satisfy Code intent 
for minimum heat input on each pass to insure full fusion and good weld properties. 
Evaluated which welds sustained tensile/fatigue loads and had all weld throat sizes documented. 
For welds with significant fatigue and more than 1/32" undersize, required welds replacement. 
For welds in compression of low fatigue, required replacement of welds more than 1/16" undersize. 
Required 100% MT on undersize non-replaced and on replaced welds. 
Required future QC plan from shop to avoid recurrences.
Remarks: Repairs took about 2 to 3 weeks, but prioritized sequence so field work not delayed.
Other Possible solutions: Remove all subsize welds, replace all brackets (delay project), 
large cover weld to incorporate small welds (high distortion, defects likely).`
).

% New Solution 9
caseSolution(weldingHeatingDistortion_9,weldingHeatingDistortion,`WHD-C009`,`Welding Heating Distortion Case Solution`,[],success,
[
    bridgeType                             :plateGirder,
    errorMemberType                        :webPlate,
    attachMemberType                       :flangePlate,
    errorMemberLocation                    :web,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :burnThru
  ],
  ` Machine malfunction of "dart" welder caused burn-thru in web plate directly underneath the vertical stiffener being welded.
Remove stiffener, prep and plug weld hole in web plate. R.T. and U.T. weld. 
Then relocate stiffener  toward interior of span by 150 mm, 
add two new stiffeners near side and far side to adjacent girder to accommodate the 150 mm. 
Relocation of the connection stiffener allowing proper fit up of cross-frame.`,
`Case #SC-F004:
Description of Error: Machine malfunction of "dart" welder caused burn-thru in web plate 
directly underneath the vertical stiffener being welded.
Solution Recommended: Remove stiffener, prep and plug weld hole in web plate. R.T. and U.T. weld. 
Then relocate stiffener  toward interior of span by 150 mm, 
add two new stiffeners near side and far side to adjacent girder to accommodate the 150 mm. 
Relocation of the connection stiffener allowing proper fit up of cross-frame.
Other Possible solutions: Place bolt in burn-thru hole in liew of plug welding in either case, 
relocation of conn. stiffener was necessary to avoid intersecting the bure-thru location.`
).

% New Solution 10
caseSolution(weldingHeatingDistortion_10,weldingHeatingDistortion,`WHD-C010`,`Welding Heating Distortion Case Solution`,[dlf002],success,
 [
    bridgeType                             :plateGirder,
    errorMemberType                        :flangePlate,
    errorMemberLocation                    :compressionFlange,
    errorMemberClass                       :primary,
    attachMemberClass                      :primary,
    causeOfDistortion                         :heating,
    typeOfDistortion             :tilt
  ],
  ` Flange tilt exceeds 1/4" or 1/25" of flange width: flange is "cupped" exceeding 1/4". Error is common on "light" gage (thickness) flanges, 
and also on full penetration web/flange welds.
For flange tilt: apply heat aiding entire girder length at the web/flange. 900 degree -1000 degree F max. heat on obtuse side. 
For "cupping": apply heat along entire flange on the face opposite the web/flange weld keeping width of heat appox. 1 " (Jacking force is optional). 
Final checks are required to verify flange tilt and cupping.`,
`Case #DL-F002:
Description of Error: Flange tilt exceeds 1/4" or 1/25" of flange width: flange is "cupped" exceeding 1/4". 
Error is common on "light" gage (thickness) flanges, and also on full penetration web/flange welds.
Solution Recommended: For flange tilt: apply heat aiding entire girder length at the web/flange. 
900 degree -1000 degree F max. heat on obtuse side. For "cupping": apply heat along entire flange 
on the face opposite the web/flange weld keeping width of heat appox. 1 1/2" (Jacking force is optional). 
Final checks are required to verify flange tilt and cupping.
Remarks: Very common problem. Heating method is always required at bearing locations where 0 degree flange tilt is allowed.`
).


