/*----------------------------------------------------------*/
/*  KNBREDGD.PL - Edge Distance Rule Knowledge              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic holeDistanceFromEdgeOrEnd/1.
:- dynamic ruleSolution/1.

% Rule: ED1.1
if holeDistanceFromEdge(HoleDistanceFromEnd)
  then holeDistanceFromEdgeOrEnd(HoleDistanceFromEnd).

% Rule: 1.1
if errorMemberClass(fractureCritical)
  then ruleSolution(edgeDistance_1).

% Rule: 1.2
if attachMemberClass(fractureCritical)
  then ruleSolution(edgeDistance_1).

% Rule: 2.1
if not rating(minEdgeEndDist)
  and errorMemberType(splicePlate)
  and errorMemberLocation(compressionFlange)
  then ruleSolution(edgeDistance_2).

% Rule: 2.2
if not rating(minEdgeEndDist)
  and errorMemberType(splicePlate)
  and errorMemberLocation(tensionFlange)
  then ruleSolution(edgeDistance_2).

% Rule: 3.1
if not rating(minEdgeEndDist)
  and errorMemberActualEdgeType(flameCut)
  and not errorMemberLocation(boltedConnection)
  then ruleSolution(edgeDistance_3).

% Rule: 4.1
if unitsType(english)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(boltedConnection)
  and holeDetailsActualTransverseHoleSpacing(HoleDetailsActualTransverseHoleSpacing)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and (0.5 * (((HoleDetailsActualTransverseHoleSpacing ^ 2) + (HoleDetailsActualLongHoleSpacing ^ 2)) ^ 0.5)) >= 1.5
  then ruleSolution(edgeDistance_4).

% Rule: 4.1m
if unitsType(metric)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(boltedConnection)
  and holeDetailsActualTransverseHoleSpacing(HoleDetailsActualTransverseHoleSpacing)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and (0.5 * (((HoleDetailsActualTransverseHoleSpacing ^ 2) + (HoleDetailsActualLongHoleSpacing ^ 2)) ^ 0.5)) >= 38
  then ruleSolution(edgeDistance_4).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/
% Solution 1
ruleSolution(edgeDistance_1,edgeDistance,`EDGD-R001`,`Edge Distance Rule Solution`,[],
`Edge distance of member does not meet specifications.

REPAIR:

Due to fact that member or attached member is classified as fracture critical member no repair ruleSolution is available,
replacement of member may be required. Check for typical repair ruleSolution by running program with input of members as
primary members instead of fracture critical.
`).

% Solution 2
ruleSolution(edgeDistance_2,edgeDistance,`EDGD-R002`,`Edge Distance Rule Solution`,[],
`Error has occurred which causes critical edge distance problem.

REPAIR:

Edge distance error has occurred in connection with splice plate. Splice plate may be extended to add additional set of bolts.
Check attached member for intersection at bolt locations. If intersection occurs, extend splice plate beyond the location of
intersection per specifications. Check maximum hole spacing limitations.
`).

% Solution 3
ruleSolution(edgeDistance_3,edgeDistance,`EDGD-R003`,`Edge Distance Rule Solution`,[],
`Edge distance of member does not meet specifications.

REPAIR:

The type of edge on member is flame cut. Check dimensions of member to see if removal of 1/16" (2mm) would allow planed edge.
Planed edge will allow smaller edge distance requirement. Check edge distance specifications with planed edge and reduction
of 1/16" (2mm). Rerun program for check.

If edge distance with planed edge will not meet specifications then cut and replace member at acceptable location or
replace entire member.
`).

% Solution 4
ruleSolution(edgeDistance_4,edgeDistance,`EDGD-R004`,`Edge Distance Rule Solution`,[],
`Edge distance of member does not meet specifications at bolted connection.

REPAIR:

Current hole spacing distance will allow addition of bolt line between existing bolt lines. Additional bolt line should
be placed at centerline location between existing bolt lines (laterally and tangentially). More detailed analysis should
be performed. If allowable bore additional bolt line. Leave existing bolt lines in place and bolt as per specifications.
`).

