/*----------------------------------------------------------*/
/*  KNBRENDD.PL - End Distance Rule Knowledge               */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic holeDistanceFromEdgeOrEnd/1.
:- dynamic ruleSolution/1.

% Rule: ED1.1
if holeDistanceFromEnd(HoleDistanceFromEdge)
  then holeDistanceFromEdgeOrEnd(HoleDistanceFromEdge).

% Rule: 1.1
if errorMemberClass(fractureCritical)
  then ruleSolution(endDistance_1).

% Rule: 1.2
if attachMemberClass(fractureCritical)
  then ruleSolution(endDistance_1).

% Rule: 2.1
if unitsType(english)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing + 1.5 < HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_2).

% Rule: 2.1
if unitsType(metric)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing + 38 < HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_2).

% Rule: 3.1
if unitsType(english)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing - 1.5 > HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_3).

% Rule: 3.1m
if unitsType(metric)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing - 38 > HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_3).

% Rule: 4.1
if unitsType(english)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing + 1.5 >= HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_4).

% Rule: 4.1m
if unitsType(metric)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing + 38 >= HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_4).

% Rule: 4.2
if unitsType(english)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing - 1.5 =< HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_4).

% Rule: 4.2m
if unitsType(metric)
  and not rating(minEdgeEndDist)
  and errorMemberLocation(splice)
  and holeDetailsActualLongHoleSpacing(HoleDetailsActualLongHoleSpacing)
  and holeDistanceFromIntersectingMember(HoleDistanceFromIntersectingMember)
  and HoleDetailsActualLongHoleSpacing - 38 =< HoleDistanceFromIntersectingMember
  then ruleSolution(endDistance_4).

% Rule: 5.1
if not rating(minEdgeEndDist)
  and not errorMemberLocation(splice)
  then ruleSolution(endDistance_5).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(endDistance_1,endDistance,`ENDD-R001`,`End Distance Rule Solution`,[],
`Members with errors occurring are classified as fracture critical members.

REPAIR:

Due to member classification, no specified type of repair is listed. Member may need to be replaced.
Run program designating members as primary to find standard repair procedure.
`).

% Solution 2
ruleSolution(endDistance_2,endDistance,`ENDD-R002`,`End Distance Rule Solution`,[],
`End distance of member does not meet specifications.

REPAIR:

End distance at splice location does not meet end distance specifications. Splice plate may be lengthened by
distance of normal bolt spacing. Add additional set of bolts. Closest intersecting member will still allow
placement of additional bolt line. Fill all existing bolt holes with bolts.
`).

% Solution 3
ruleSolution(endDistance_3,endDistance,`ENDD-R003`,`End Distance Rule Solution`,[],
`End distance of member does not meet specifications.

REPAIR:

End distance at splice location does not meet end distance specifications. Splice plate may be lengthened by
distance of normal bolt spacing. Add additional set of bolts. Intersecting member will occur between last
specified line of bolts and new additional set. Spacing requirement will still allow placement of additional
set of bolts at normal spacing specifications. Fill all existing bolt holes with bolts.
`).

% Solution 4
ruleSolution(endDistance_4,endDistance,`ENDD-R004`,`End Distance Rule Solution`,[],
`End distance of member does not meet specifications.

REPAIR:

End distance at splice location does not meet end distance specifications. Due to distance to intersecting member
from last specified bolt line the addition of new bolt line must be place beyond normal hole spacing dimensions.
Place new bolt line 1 1/2" (38mm) beyond intersection of member. Check that maximum spacing specifications are not
exceeded. Fill all existing bolt holes with bolts.
`).

% Solution 5
ruleSolution(endDistance_5,endDistance,`ENDD-R005`,`End Distance Rule Solution`,[],
`End distance of member does not meet specifications.

REPAIR:

End distance does not meet specifications. Add additional bolt in bolt line if possible. Check hole spacing and
edge/end distance specifications. If additional bolt is not possible cut and replace member at appropriate location
or replace complete member.
`).

