/*----------------------------------------------------------*/
/*  KNBRINTL.PL - Internal Lamination Rule Knowledge        */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if errorMemberType(flangePlate)
  and stressErrorMemberType(tension)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(internalLamination_1).

% Rule: 1.2
if errorMemberType(webPlate)
  and stressErrorMemberType(unknown)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(internalLamination_1).

% Rule: 2.1
if errorMemberType(flangePlate)
  and stressErrorMemberType(compression)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(internalLamination_2).

% Rule: 2.2
if errorMemberType(webPlate)
  and stressErrorMemberType(unknown)
  and stressErrorMemberLevel(low)
  then ruleSolution(internalLamination_2).

% Rule: 3.1
if errorMemberType(splicePlate)
  and stressErrorMemberType(unknown)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(internalLamination_3).

% Rule: 3.2
if errorMemberType(fillerPlate)
  and stressErrorMemberType(unknown)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(internalLamination_3).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(internalLamination_1,internalLamination,`EDGL-R001`,`Internal Lamination Rule Solution`,[],
`This plate is in a high stress region/tension region and is a primary member.

REPAIR:

Replace the plate with a new one. No welding can be allowed in such a plate.
`).

% Solution 2
ruleSolution(internalLamination_2,internalLamination,`EDGL-R002`,`Internal Lamination Rule Solution`,[],
`This repair procedure should be followed very carefully.

REPAIR:

1. Prepare a cavity by means of grinding or air arc gouging to the depth of 1/4" to 3/8".
   The cavity ends should taper smoothly to the plate surface at a slope not exceeding 1:1.
2. Where the cavity extends to the plate edge, an edge run-off tab should be used.
3. Preheat 250-450 degree F shall be used and temperature shall be maintained until repair is complete.
4. Welding electrode (FCM) may be used.
   Shielding metal arc or submerged arc may be used.
5. First four layers of any repair shall be SMAW using electrodes of 1/8" or 5/32" diameter.
   Maximum pass thickness for SMAW is 1/8" or SAW is 1/4".
6. Welding parameters will be as specified in WPS for SMAW or SAW.
7. Post heat shall be employed and continued without interruption from the completion of repair welding to
   the end of the minimum postheat period.
   Post heat of the repair area shall be between 400 degree F to 500 degree F for 1 hour/inch of repair weld
   thickness or for two hours, whichever is less.
8. Repair weld shall be ground flush and base metal suspect area shall again be inspected by means of UT to
   determine if any applicable change has occurred as a result of the sealing process.
9. The UT results should be forwarded to consultant and state officials.
`).

% Solution 3
ruleSolution(internalLamination_3,internalLamination,`EDGL-R003`,`Internal Lamination Rule Solution`,[],
`In this case the plate is a secondary member and does not involve much of material and labor.

REPAIR:

Replace the plate with the correct hole configuration.
`).

