/*----------------------------------------------------------*/
/*  KNBRMALM.PL - Misaligned Member Rule Knowledge          */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic rating/1.
:- dynamic ruleSolution/1.

% Rule: S1.1
if errorMemberType(plateGirder)
  then rating(structure_1).

% Rule: S1.2
if errorMemberType(boxGirder)
  then rating(structure_1).

% Rule: S1.3
if errorMemberType(capBeam)
  then rating(structure_1).

% Rule: S1.4
if attachMemberType(plateGirder)
  then rating(structure_1).

% Rule: S1.5
if attachMemberType(boxGirder)
  then rating(structure_1).

% Rule: S1.6
if attachMemberType(capBeam)
  then rating(structure_1).

% Rule: S2.1
if errorMemberType(splicePlate)
  then rating(structure_2).

% Rule: S2.2
if errorMemberType(bearingStiffener)
  then rating(structure_2).

% Rule: S2.3
if errorMemberType(intermediateStiffener)
  then rating(structure_2).

% Rule: S2.4
if errorMemberType(fillerPlate)
  then rating(structure_2).

% Rule: S2.5
if errorMemberType(diaphragmBrace)
  then rating(structure_2).

% Rule: 1.1
if errorMemberClass(fractureCritical)
  then ruleSolution(misalignedMember_1).

% Rule: 1.2
if attachMemberClass(fractureCritical)
  then ruleSolution(misalignedMember_1).

% Rule: 2.1
if unitsType(english)
  and rating(structure_1)
  and surfaceFullSurfaceContact(false)
  and attachMemberType(splicePlate)
  and errorMemberLocation(compressionFlange)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 0.25
  and surfaceFillPlate(true)
  and surfaceFillPlateThickness(SurfaceFillPlateThickness)
  and SurfaceFillPlateThickness >= (2 * SurfaceContactSpacing)
  then ruleSolution(misalignedMember_2).

% Rule: 2.1m
if unitsType(metric)
  and rating(structure_1)
  and surfaceFullSurfaceContact(false)
  and attachMemberType(splicePlate)
  and errorMemberLocation(compressionFlange)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 6
  and surfaceFillPlate(true)
  and surfaceFillPlateThickness(SurfaceFillPlateThickness)
  and SurfaceFillPlateThickness >= (2 * SurfaceContactSpacing)
  then ruleSolution(misalignedMember_2).

% Rule: 3.1
if unitsType(english)
  and surfaceFullSurfaceContact(false)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing > 0.25
  and surfaceHeatProcedure(false)
  then ruleSolution(misalignedMember_3).

% Rule: 3.1m
if unitsType(metric)
  and surfaceFullSurfaceContact(false)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing > 6
  and surfaceHeatProcedure(false)
  then ruleSolution(misalignedMember_3).

% Rule: 4.1
if unitsType(english)
  and surfaceFullSurfaceContact(false)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 0.25
  and surfacePercentContact(SurfacePercentContact)
  and SurfacePercentContact > 50
  and errorMemberLocation(bearing)
  then ruleSolution(misalignedMember_4).

% Rule: 4.1m
if unitsType(metric)
  and surfaceFullSurfaceContact(false)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 6
  and surfacePercentContact(SurfacePercentContact)
  and SurfacePercentContact > 50
  and errorMemberLocation(bearing)
  then ruleSolution(misalignedMember_4).

% Rule: 5.1
if unitsType(english)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 0.25
  and surfacePercentContact(SurfacePercentContact)
  and SurfacePercentContact < 50
  and errorMemberLocation(bearing)
  then ruleSolution(misalignedMember_5).

% Rule: 5.1m
if unitsType(metric)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 6
  and surfacePercentContact(SurfacePercentContact)
  and SurfacePercentContact < 50
  and errorMemberLocation(bearing)
  then ruleSolution(misalignedMember_5).

% Rule: 6.1
if unitsType(english)
  and surfaceFullSurfaceContact(false)
  and errorMemberType(plateGirder)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 2.5
  and surfaceHeatProcedure(true)
  then ruleSolution(misalignedMember_6).

% Rule: 6.1m
if unitsType(metric)
  and surfaceFullSurfaceContact(false)
  and errorMemberType(plateGirder)
  and rating(structure_1)
  and surfaceContactSpacing(SurfaceContactSpacing)
  and SurfaceContactSpacing =< 63
  and surfaceHeatProcedure(true)
  then ruleSolution(misalignedMember_6).

% Rule: 7.1
if rating(Structure_2)
  and errorMemberLocation(boltedConnection)
  then ruleSolution(misalignedMember_7).

% Rule: 8.1
if unitsType(english)
  and errorMemberType(plateGirder)
  and errorMemberLocation(web)
  and mislocatedMemberIntersection(true)
  and mislocatedMemberDistanceCorrectLocation(MislocatedMemberDistanceCorrectLocation)
  and MislocatedMemberDistanceCorrectLocation > 0.25
  then ruleSolution(misalignedMember_8).

% Rule: 8.1m
if unitsType(metric)
  and errorMemberType(plateGirder)
  and errorMemberLocation(web)
  and mislocatedMemberIntersection(true)
  and mislocatedMemberDistanceCorrectLocation(MislocatedMemberDistanceCorrectLocation)
  and MislocatedMemberDistanceCorrectLocation > 6
  then ruleSolution(misalignedMember_8).

% Rule: 8.2
if unitsType(english)
  and errorMemberType(plateGirder)
  and errorMemberLocation(web)
  and mislocatedMemberDistanceCorrectLocation(MislocatedMemberDistanceCorrectLocation)
  and MislocatedMemberDistanceCorrectLocation > 0.25
  then ruleSolution(misalignedMember_8).

% Rule: 8.2m
if unitsType(metric)
  and errorMemberType(plateGirder)
  and errorMemberLocation(web)
  and mislocatedMemberDistanceCorrectLocation(MislocatedMemberDistanceCorrectLocation)
  and MislocatedMemberDistanceCorrectLocation > 6
  then ruleSolution(misalignedMember_8).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(misalignedMember_1,misalignedMember,`MALM-R001`,`Misaligned Member Rule Solution`,[],
`Member with error or attached member is a fracture critical member.

REPAIR:

Additional design checks may be necessary due to fracture critical members.
A general repair procedure can be determined by listing member as primary instead of fracture critical.
`).

% Solution 2
ruleSolution(misalignedMember_2,misalignedMember,`MALM-R002`,`Misaligned Member Rule Solution`,[],
`Full contact surface does not occur at error location.

REPAIR:

Due to the limit in gap that occurs between faying surfaces, the fill plate can be machined to allow full surface contact.
Modify fill plate to allow full contact of surfaces, extending if necessary for machining.
`).

% Solution 3
ruleSolution(misalignedMember_3,misalignedMember,`MALM-R003`,`Misaligned Member Rule Solution`,[],
`Full contact surface does not occur at error location.

REPAIR:

Due to the size of gap that occurs between faying surfaces, the fill plate cannot be modified to allow full surface contact.
Remove member past error. Replace member with full penetration butt weld.
`).

% Solution 4
ruleSolution(misalignedMember_4,misalignedMember,`MALM-R004`,`Misaligned Member Rule Solution`,[],
`Bearing plate and bottom flange of girder do not make full surface contact.
50 % or more of contact area makes full contact. Maximum gap is less than 1/4" (6mm).

REPAIR:

Remove fillet welds per AWS D1.5-88 from both sides of bearing stiffener. Move bottom flange down to achieve full surface
contact between members. One method is by jacking the bottom flange down, making sure that the compression flange is not damaged.
Reweld bearing stiffener to bottom flange in accordance with AWS D1.5-88 procedures.
`).

% Solution 5
ruleSolution(misalignedMember_5,misalignedMember,`MALM-R005`,`Misaligned Member Rule Solution`,[],
`Bearing plate and bottom flange of girder do not make full surface contact.
Less than 50 % of contact area makes full contact.

REPAIR:

Check bearing plate for warpage. If warpage occurs, replace bearing plate. Also check bottom flange for warpage.
If gap is too large and bearing plate is OK, then remove bottom flange beyond area  with warpage or replace bottom flange.
`).

% Solution 6
ruleSolution(misalignedMember_6,misalignedMember,`MALM-R006`,`Misaligned Member Rule Solution`,[],
`Full contact surface does not occur at error location. Member types may allow use of heat procedure to allow
correction of non-surface contact.

REPAIR:

Use approved heat procedure to correct gap between surface contact.

CAUTION: Make sure to apply and control heat process only near end of member. Check changes in girder camber for design limits.
Heat should be applied as near as possible to end of member.
`).

% Solution 7
ruleSolution(misalignedMember_7,misalignedMember,`MALM-R007`,`Misaligned Member Rule Solution`,[],
`Misalignment of member has occurred at a bolted connection.

REPAIR:

Member with error is considered secondary member. Due to member type, the recommended repair is to replace individual member
piece at bolted connection. If replacement of individual piece at connection is not possible, then full replacement of member
is recommended.
`).

% Solution 8
ruleSolution(misalignedMember_8,misalignedMember,`MALM-R008`,`Misaligned Member Rule Solution`,[],
`Misalignment of member has occurred at web connection.

REPAIR:

Check with design engineer.

Possible ruleSolution is to air carbon arc gouge web-to-flange weld past misalignment location, cut out flange and splice
new flange using approved procedure. Radiograph testing required on weld. Realign web and weld with approved procedure.
MT testing required.
`).

