/*----------------------------------------------------------*/
/*  KNBRMLCH.PL - Mislocated Hole Rule Knowledge            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic rating/1.
:- dynamic ruleSolution/1.

% Rule: DA1
if errorMemberType(intermediateStiffener)
  and attachMemberType(diaphragmBrace)
  and errorMemberLocation(boltedConnection)
  then rating(diaphAttach).

% Rule: DA2
if errorMemberType(bearingStiffener)
  and attachMemberType(diaphragmBrace)
  and errorMemberLocation(boltedConnection)
  then rating(diaphAttach).

% Rule: 1.1
if errorMemberClass(fractureCritical)
  then ruleSolution(mislocatedHole_1).

% Rule: 1.2
if attachMemberClass(fractureCritical)
  then ruleSolution(mislocatedHole_1).

% Rule: 2.1
if holeDetailsType(circular)
  and errorMemberLocation(compressionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 8
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors =< (0.35 * HoleDetailsNumberInGrouping)
  then ruleSolution(mislocatedHole_2).

% Rule: 2.2
if holeDetailsType(circular)
  and errorMemberLocation(tensionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 8
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors =< (0.35 * HoleDetailsNumberInGrouping)
  then ruleSolution(mislocatedHole_2).

% Rule: 3.1
if unitsType(english)
  and rating(diaphAttach)
  and holeDetailsType(circular)
  and holeDetailsHoleBoringProcedure(drilled)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 0.5
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 1
  then ruleSolution(mislocatedHole_3).

% Rule: 3.1m
if unitsType(metric)
  and rating(diaphAttach)
  and holeDetailsType(circular)
  and holeDetailsHoleBoringProcedure(drilled)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 12
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 1
  then ruleSolution(mislocatedHole_3).

% Rule: 4.1
if unitsType(english)
  and rating(diaphAttach)
  and holeDetailsType(circular)
  and holeDetailsHoleBoringProcedure(drilled)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 0.5
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 1
  then ruleSolution(mislocatedHole_4).

% Rule: 4.1m
if unitsType(metric)
  and rating(diaphAttach)
  and holeDetailsType(circular)
  and holeDetailsHoleBoringProcedure(drilled)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 12
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 1
  then ruleSolution(mislocatedHole_4).

% Rule: 5.1
if rating(diaphAttach)
  and holeDetailsType(circular)
  and holeDetailsHoleBoringProcedure(drilled)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =:= 1
  then ruleSolution(mislocatedHole_5).

% Rule: 6.1
if mislocatedHoleIncorrectFlange(true)
  and errorMemberLocation(compressionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 6
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleIntersectionNewPosition(false)
  then ruleSolution(mislocatedHole_6).

% Rule: 6.2
if mislocatedHoleIncorrectFlange(true)
  and errorMemberLocation(tensionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 6
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleIntersectionNewPosition(false)
  then ruleSolution(mislocatedHole_6).

% Rule: 6.3
if errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(false)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 10
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleIntersectionNewPosition(false)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  then ruleSolution(mislocatedHole_6).

% Rule: 7.1
if errorMemberLocation(tensionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 2
  and mislocatedHoleEdgeEndDistanceSpecification(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleIntersectionNewPosition(false)
  then ruleSolution(mislocatedHole_7).

% Rule: 7.2
if errorMemberLocation(compressionFlange)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 2
  and mislocatedHoleEdgeEndDistanceSpecification(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleIntersectionNewPosition(false)
  then ruleSolution(mislocatedHole_7).

% Rule: 7.3
if errorMemberLocation(web)
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors / HoleDetailsNumberInGrouping =< 0.35
  and mislocatedHoleEdgeEndDistanceSpecification(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_7).

% Rule: 8.1
if unitsType(english)
  and errorMemberLocation(splice)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 0.625
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  then ruleSolution(mislocatedHole_8).

% Rule: 8.1m
if unitsType(metric)
  and errorMemberLocation(splice)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 16
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  then ruleSolution(mislocatedHole_8).

% Rule: 9.1
if mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleAdditionalRowHolesDrilled(true)
  then ruleSolution(mislocatedHole_9).

% Rule: 10.1
if errorMemberLocation(web)
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors / HoleDetailsNumberInGrouping =< 0.35
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_10).

% Rule: 11.1
if errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(false)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_11).

% Rule: 11.2
if errorMemberLocation(splice)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_11).

% Rule: 12.1
if errorMemberLocation(boltedConnection)
  and attachMemberType(bearingStiffener)
  then ruleSolution(mislocatedHole_12).

% Rule: 13.1
if errorMemberLocation(boltedConnection)
  and attachMemberType(intermediateStiffener)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors =< 2
  then ruleSolution(mislocatedHole_13).

% Rule: 14.1
if errorMemberLocation(boltedConnection)
  and attachMemberType(intermediateStiffener)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and HoleDetailsNumberWithErrors > 2
  then ruleSolution(mislocatedHole_14).

% Rule: 15.1
if errorMemberLocation(boltedConnection)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors / HoleDetailsNumberInGrouping =< 0.35
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_15).

% Rule: 15.2
if errorMemberLocation(splice)
  and holeDetailsNumberWithErrors(HoleDetailsNumberWithErrors)
  and holeDetailsNumberInGrouping(HoleDetailsNumberInGrouping)
  and HoleDetailsNumberWithErrors / HoleDetailsNumberInGrouping =< 0.35
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and mislocatedHoleIntersectionCurrentPosition(false)
  then ruleSolution(mislocatedHole_15).

% Rule: 16.1
if unitsType(english)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 0.5
  then ruleSolution(mislocatedHole_16).

% Rule: 16.1m
if unitsType(metric)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 13
  then ruleSolution(mislocatedHole_16).

% Rule: 17.1
if unitsType(english)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 0.5
  and MislocatedHoleDistanceCorrectLocation =< 4
  then ruleSolution(mislocatedHole_17).

% Rule: 17.1m
if unitsType(metric)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 13
  and MislocatedHoleDistanceCorrectLocation =< 100
  then ruleSolution(mislocatedHole_17).

% Rule: 18.1
if unitsType(english)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 4
  then ruleSolution(mislocatedHole_18).

% Rule: 18.1m
if unitsType(metric)
  and errorMemberLocation(web)
  and mislocatedHoleReinforcingSteelHole(true)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 100
  then ruleSolution(mislocatedHole_18).

% Rule: 19.1
if mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleInterfereWithSpecifiedPattern(false)
  and mislocatedHoleReinforcingSteelHole(false)
  then ruleSolution(mislocatedHole_19).

% Rule: 20.1
if unitsType(english)
  and errorMemberLocation(gussetPlate)
  and holeDetailsType(circular)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 0.5
  then ruleSolution(mislocatedHole_20).

% Rule: 20.1m
if unitsType(metric)
  and errorMemberLocation(gussetPlate)
  and holeDetailsType(circular)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation =< 12
  then ruleSolution(mislocatedHole_20).
 
% Rule: 21.1
if unitsType(english)
  and errorMemberLocation(gussetPlate)
  and holeDetailsType(circular)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 0.5
  then ruleSolution(mislocatedHole_21).

% Rule: 21.1m
if unitsType(metric)
  and errorMemberLocation(gussetPlate)
  and holeDetailsType(circular)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation > 12
  then ruleSolution(mislocatedHole_21).


/* !!!! These rules need a sub-rule for rating(holeSlotted) which is not defined !!!!

% Rule: 22.1
if unitsType(english)
  and errorMemberLocation(boltedConnection)
  and rating(holeSlotted)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation < 0.5
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  then ruleSolution(mislocatedHole_22).

% Rule: 22.1m
if unitsType(metric)
  and errorMemberLocation(boltedConnection)
  and rating(holeSlotted)
  and mislocatedHoleDistanceCorrectLocation(MislocatedHoleDistanceCorrectLocation)
  and MislocatedHoleDistanceCorrectLocation < 12
  and mislocatedHoleIntersectionCurrentPosition(false)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  then ruleSolution(mislocatedHole_22).
*/

% Rule: 23.1
if errorMemberLocation(stiffenerAttachment)
  and mislocatedHoleEdgeEndDistanceSpecification(true)
  and mislocatedHoleSpecifiedHolePatternCorrect(true)
  then ruleSolution(mislocatedHole_23).

% Rule: 24.1
if errorMemberLocation(stiffenerAttachment)
  and mislocatedHoleIntersectionCurrentPosition(true)
  and mislocatedHoleInterfereWithSpecifiedPattern(true)
  then ruleSolution(mislocatedHole_24).

% Rule: 25.1
if errorMemberLocation(compressionFlange)
  and attachMemberType(kConnection)
  and mislocatedHoleIntersectionCurrentPosition(true)
  and mislocatedHoleInterfereWithSpecifiedPattern(true)
  and mislocatedHoleAdditionalRowHolesDrilled(false)
  then ruleSolution(mislocatedHole_25).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/
% Solution 1
ruleSolution(mislocatedHole_1,mislocatedHole,`MLCH-R001`,`Mislocated Hole Rule Solution`,[],
`Member with mislocated holes or attached member is 
classified as fracture critical.

REPAIR:

Due to classification of member no repair procedure is recommended. 
Replacement of member may be necessary.

To check standard repair procedure, rerun program designating members as 
primary.
`).

% Solution 2
ruleSolution(mislocatedHole_2,mislocatedHole,`MLCH-R002`,`Mislocated Hole Rule Solution`,[],
`Mislocated holes have occurred in flange.

REPAIR:

No repair procedure is recommended. 
Replacement of member may be necessary.
`).

% Solution 3
ruleSolution(mislocatedHole_3,mislocatedHole,`MLCH-R003`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred on diaphragm connection of 
stiffener.

Distance mislocated holes are off from specified location is small.

Check hole spacing to see if slotting of holes is allowable. If so, slot 
holes for attachment. 

Slotting of holes is allowable transverse to line of stress. Slotting 
may only occur on one connecting member.
Attachment member may not have slotted holes.
`).

% Solution 4
ruleSolution(mislocatedHole_4,mislocatedHole,`MLCH-R004`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred on diaphragm to stiffener 
connection.

Distance mislocated holes are off from specified location is large.

Slotting of holes will interfere with hole spacing requirements.

Replace member with new member with correct hole pattern.
-This may be either stiffener or diaphragm/brace connection plate.
`).

% Solution 5
ruleSolution(mislocatedHole_5,mislocatedHole,`MLCH-R005`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocated holes occur at diaphragm to stiffener connection. The 
majority of mislocated hole(s) match specified hole pattern.

Leave existing hole(s) in place. Drill any additional holes to match 
connection. Fill any mislocated hole with bolt and
double washer. If connection plate will cover mislocated hole(s) it is 
not necessary to fill with bolts.
`).

% Solution 6
ruleSolution(mislocatedHole_6,mislocatedHole,`MLCH-R006`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.

Bolt mislocated holes with High Strength bolts and double washers.

Drill holes in flange at correct location as specified.
`).

% Solution 7
ruleSolution(mislocatedHole_7,mislocatedHole,`MLCH-R007`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.

Custom fabricate new splice plates to match as built conditions. New 
splice plate will require additional
set of holes due to lack of Edge/End distance.
`).

% Solution 8
ruleSolution(mislocatedHole_8,mislocatedHole,`MLCH-R008`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.

Leave existing hole in main member. Make new splice plate to match 
existing hole pattern.
`).

% Solution 9
ruleSolution(mislocatedHole_9,mislocatedHole,`MLCH-R009`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.

Leave existing splice in specified location. Two possible solutions 
exist.

1)  Extend splice plate to cover mislocated holes and drill to match. 
2)  Place bolts and double washer in additional holes and leave splice 
plate as designed.
`).

% Solution 10
ruleSolution(mislocatedHole_10,mislocatedHole,`MLCH-R010`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.

Custom fabricate new splice plates to match as built conditions.
`).

% Solution 11
ruleSolution(mislocatedHole_11,mislocatedHole,`MLCH-R011`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.
The mislocated hole(s) match specified hole pattern.

Leave existing hole(s) in place and extend splice or connection plate to 
cover existing hole(s).
Drill splice or connection plate with template from existing hole 
pattern. 

Extend plate to necessary dimensions to meet specified end/edge distance 
specifications.
`).

% Solution 12
ruleSolution(mislocatedHole_12,mislocatedHole,`MLCH-R012`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does occur at current location 
or new placement location. 

Interference occurs with bearing stiffener. Clip stiffener to allow bolt 
access.
`).

% Solution 13
ruleSolution(mislocatedHole_13,mislocatedHole,`MLCH-R013`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does occur at current location 
or new placement location. 

Interference occurs with intermediate stiffener. Clip stiffener to allow 
bolt access.
`).

% Solution 14
ruleSolution(mislocatedHole_14,mislocatedHole,`MLCH-R014`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does occur at current location 
or new placement location. 

Interference occurs with intermediate stiffener. The number of holes 
that intersect the member is too great. 

Move intermediate stiffener to new location to allow for access of 
bolts.
`).

% Solution 15
ruleSolution(mislocatedHole_15,mislocatedHole,`MLCH-R015`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.
The mislocated hole(s) do not interfere with specified placement of hole 
pattern. 

Leave existing hole(s) in place. If not covered with connection 
material(such as clip angles) then bolt with double washers.

If hole spacing with mislocated hole limits bolting and splice or bolted 
plate will cover mislocated hole on both side,
then mislocated hole does not need to have bolt placed in it.
`).

% Solution 16
ruleSolution(mislocatedHole_16,mislocatedHole,`MLCH-R016`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred at abutment end of member. Holes are 
used for passing through reinforcing steel.

Distance mislocated holes are off from specified location is small 
enough to allow for slotting of holes.

Extend holes toward specified location to make into slotted holes.
`).

% Solution 17
ruleSolution(mislocatedHole_17,mislocatedHole,`MLCH-R017`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred at abutment end of member. Holes are 
used for passing through reinforcing steel.

Distance mislocated holes are off from specified location is large.

Leave hole(s) in place and adjust reinforcing steel in field.
`).

% Solution 18
ruleSolution(mislocatedHole_18,mislocatedHole,`MLCH-R018`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred at abutment end of member. Holes are 
used for passing through reinforcing steel.

Distance mislocated holes are off from specified location is too large.

Place bolts and double washer into mislocated holes. Bore new holes in 
specified location.
`).

% Solution 19
ruleSolution(mislocatedHole_19,mislocatedHole,`MLCH-R019`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.
The mislocated hole(s) do not interfere with specified placement of hole 
pattern. 

Leave existing hole(s) in place and bolt with double washers.

Bore specified holes in correct location with specified procedure.
`).

% Solution 20
ruleSolution(mislocatedHole_20,mislocatedHole,`MLCH-R020`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred on gusset plate connection.

Distance mislocated holes are off from specified location is small.

Check hole spacing to see if slotting of holes is allowable. If so, slot 
holes for attachment.

Slotting of holes is allowable transverse to line of stress. Slotting 
may only occur on one connecting member.
Attachment member may not have slotted holes.
`).

% Solution 21
ruleSolution(mislocatedHole_21,mislocatedHole,`MLCH-R021`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocation of hole(s) has occurred on gusset plate connection.

Distance mislocated holes are off from specified location is large.
Slotting of holes may interfere with hole spacing requirements.

REPAIR:
Two options may be available for repair.
1) Slotting of mislocated hole(s) may be possible with additional holes 
added to grouping for strength.

2) Replace member with new member with correct hole pattern.
`).

% Solution 22
ruleSolution(mislocatedHole_22,mislocatedHole,`MLCH-R022`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Intersection of existing member or holes does not occur at current 
location or new placement location.
The mislocated hole(s) are slotted holes in connection plate.

Existing hole(s) match specified pattern. The distance of mislocation is 
minimal.
Check with designer for additional slotting of holes to meet specified 
pattern location.
`).

% Solution 23
ruleSolution(mislocatedHole_23,mislocatedHole,`MLCH-R023`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Mislocated hole(s) occurs at attachment of stiffener. 

If distance of mislocation is minimal (less than 6" or 150mm) it may be 
possible to leave mislocated hole(s)
in current location and attach stiffener at this location. Check with 
designer.

If distance is too large - fill holes with bolts and double washer. Bore 
new holes in specified location.
`).

% Solution 24
ruleSolution(mislocatedHoles_24,mislocatedHole,`MLCH-R024`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) occurs at attachment of stiffener. 

Intersection occurs at mislocation. Specified hole pattern will 
interfere with mislocated holes.

REPAIR:

Check with designer for appropriate repair. Stiffener may be relocated 
to match existing holes - check location
of intersection and item intersected.
`).

% Solution 25
ruleSolution(mislocatedHole_25,mislocatedHole,`MLCH-R025`,`Mislocated Hole Rule Solution`,[],
`Mislocated hole(s) has occurred.

REPAIR:

Clearance between the grid deck panels has been provided to allow for 
erection tolerance.
This tolerance shall be maintained during fabrication to allow for 
numerous uses of the bridge in the future.
Reject the beams with the replacement beams fabricated to specification 
tolerances.
`).

