/*----------------------------------------------------------*/
/*  KNBRMSPH.PL - Misshaped Hole Rule Knowledge             */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if holeDetailsJointSlipCritical(true)
  then ruleSolution(misshapedHole_1).

% Rule: 2.1
if holeDetailsJointSlipCritical(false)
  and (holeDetailsType(eggShaped)
  or holeDetailsType(irregularShaped))
  then ruleSolution(misshapedHole_2).

% Rule: 3.1
if unitsType(english)
  and holeDetailsJointSlipCritical(false)
  and holeDetailsType(longSlotted)
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter > 1
  then ruleSolution(misshapedHole_3).

% Rule: 3.1m
if unitsType(metric)
  and holeDetailsJointSlipCritical(false)
  and holeDetailsType(longSlotted)
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter > 25
  then ruleSolution(misshapedHole_3).

% Rule: 4.1
if unitsType(english)
  and holeDetailsJointSlipCritical(false)
  and holeDetailsType(longSlotted)
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter =< 1
  then ruleSolution(misshapedHole_4).

% Rule: 4.1m
if unitsType(metric)
  and holeDetailsJointSlipCritical(false)
  and holeDetailsType(longSlotted)
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter =< 25
  then ruleSolution(misshapedHole_4).

% Rule: 5.1
if unitsType(english)
  and holeDetailsJointSlipCritical(false)
  and (holeDetailsType(oversize)
  or holeDetailsType(shortSlotted))
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter > 1
  then ruleSolution(misshapedHole_5).

% Rule: 5.1m
if unitsType(metric)
  and holeDetailsJointSlipCritical(false)
  and (holeDetailsType(oversize)
  or holeDetailsType(shortSlotted))
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter > 25
  then ruleSolution(misshapedHole_5).

% Rule: 6.1
if unitsType(english)
  and holeDetailsJointSlipCritical(false)
  and (holeDetailsType(shortSlotted)
  or holeDetailsType(oversize))
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter =< 1
  then ruleSolution(misshapedHole_6).

% Rule: 6.1m
if unitsType(metric)
  and holeDetailsJointSlipCritical(false)
  and (holeDetailsType(shortSlotted)
  or holeDetailsType(oversize))
  and holeDetailsSpecifiedHoleDiameter(HoleDetailsSpecifiedHoleDiameter)
  and HoleDetailsSpecifiedHoleDiameter =< 25
  then ruleSolution(misshapedHole_6).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(misshapedHole_1,misshapedHole,`MSPH-R001`,`Misshaped Hole Rule Solution`,[],
`Since this is a slip critical member joint the procedure pertaining to AASHTO section 10.24.2.2 Div. I should be used,
which states as follows:

REPAIR:

They have to conform to the design requirements given in AASHTO sections 10.32.3.2.1 or 10.57.3.1 Div. I for oversized,
shot slot, and long slot holes.
`).

% Solution 2
ruleSolution(misshapedHole_2,misshapedHole,`MSPH-R002`,`Misshaped Hole Rule Solution`,[],
`The plate is not fit for use as is therefore the repair procedure is as follows.

REPAIR:

1. Cut off existing flange.
2. Add new plate using full pen weld at flange or fillet weld in web.
3. Do a 100% RT at flange.
4. Do a 100% MT at web.
`).

% Solution 3
ruleSolution(misshapedHole_3,misshapedHole,`MSPH-R003`,`Misshaped Hole Rule Solution`,[],
`This repair procedure is from AASHTO section 10.24.3.7 Div. I :

REPAIR:

A single hardened washer conforming to ASTM F436, but with 5/16" (8 mm) minimum thickness shall be used in lieu of
washers or bars of structural grade material.
Multiple hardened washers with combined thickness equal to or greater than 5/16" (8 mm) do not satisfy the requirement.
`).

% Solution 4
ruleSolution(misshapedHole_4,misshapedHole,`MSPH-R004`,`Misshaped Hole Rule Solution`,[],
`This repair procedure is from AASHTO section 10.24.3.7 Div. I :

REPAIR:

A plate washer or continuous bar of at least 5/16" (8 mm) thickness with standard holes shall be provided.
These washers or bars shall have a size sufficient to completely cover the slot after installation and shall
be of structural grade material, but need not be hardened.
`).

% Solution 5
ruleSolution(misshapedHole_5,misshapedHole,`MSPH-R005`,`Misshaped Hole Rule Solution`,[],
`This repair procedure is from AASHTO section 10.24.3.6 Div.I :

REPAIR:

Hardened washer may be used conforming to ASTM F436.
Minimum thickness of 5/16" (8 mm) shall be used under both the head and the nut in lieu of standard thickness hardened washers.
Multiple hardened washers with combined thickness equal to or greater than 5/16" (8 mm) do not satisfy the requirement.
`).

% Solution 6
ruleSolution(misshapedHole_6,misshapedHole,`MSPH-R006`,`Misshaped Hole Rule Solution`,[],
`This repair procedure is from AASHTO section 10.24.3.5 Div. I :

REPAIR:

Hardened washers conforming to ASTM F436 shall be used in the outer ply.
`).

