/*----------------------------------------------------------*/
/*  KNBRNAGS.PL - Nicks & Gouges Rule Knowledge             */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if unitsType(english)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth =< 0.1875
  then ruleSolution(nicksGouges_1).

% Rule: 1.1m
if unitsType(metric)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth =< 5
  then ruleSolution(nicksGouges_1).

% Rule: 2.1
if unitsType(english)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth > 0.1875
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and NickGougeDepth =< 0.3 * ErrorMemberActualThickness
  then ruleSolution(nicksGouges_2).

% Rule: 2.1m
if unitsType(metric)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth > 5
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and NickGougeDepth =< 0.3 * ErrorMemberActualThickness
  then ruleSolution(nicksGouges_2).

% Rule: 2.2
if unitsType(english)
  and errorMemberType(webPlate)
  and nickGougeType(edge)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and ErrorMemberActualThickness =< 0.625
  then ruleSolution(nicksGouges_2).

% Rule: 2.2m
if unitsType(metric)
  and errorMemberType(webPlate)
  and nickGougeType(edge)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and ErrorMemberActualThickness =< 16
  then ruleSolution(nicksGouges_2).

% Rule: 3.1
if unitsType(english)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth > 0.1875
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and NickGougeDepth > 0.3 * ErrorMemberActualThickness
  then ruleSolution(nicksGouges_3).

% Rule: 3.1m
if unitsType(metric)
  and (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(surface)
  and nickGougeDepth(NickGougeDepth)
  and NickGougeDepth > 5
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and NickGougeDepth > 0.3 * ErrorMemberActualThickness
  then ruleSolution(nicksGouges_3).

% Rule: 4.1
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(tension)
  and stressErrorMemberLevel(high)
  then ruleSolution(nicksGouges_4).

% Rule: 5.1
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(tension)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  then ruleSolution(nicksGouges_5).

% Rule: 5.2
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(compression)
  and stressErrorMemberLevel(high)
  then ruleSolution(nicksGouges_5).

% Rule: 5.3
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(compression)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualLength(ErrorMemberActualLength)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and ErrorMemberActualLength > ErrorMemberDesignLength
  and errorMemberActualWidth(ErrorMemberActualWidth)
  and errorMemberDesignWidth(ErrorMemberDesignWidth)
  and ErrorMemberActualWidth > ErrorMemberDesignWidth
  then ruleSolution(nicksGouges_5).

% Rule: 5.4
if errorMemberType(splicePlate)
  and nickGougeType(edge)
  and nickGougeGrindEdgeEndDistance(true)
  then ruleSolution(nicksGouges_5).

% Rule: 6.1
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(compression)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualLength(ErrorMemberActualLength)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and ErrorMemberActualLength > ErrorMemberDesignLength
  and errorMemberActualWidth(ErrorMemberActualWidth)
  and errorMemberDesignWidth(ErrorMemberDesignWidth)
  and ErrorMemberActualWidth =< ErrorMemberDesignWidth
  then ruleSolution(nicksGouges_6).

% Rule: 6.2
if errorMemberType(flangePlate)
  and nickGougeType(edge)
  and stressErrorMemberType(compression)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualLength(ErrorMemberActualLength)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and ErrorMemberActualLength =:= ErrorMemberDesignLength
  then ruleSolution(nicksGouges_6).

% Rule: 6.3
if unitsType(english)
  and errorMemberType(webPlate)
  and nickGougeType(edge)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and ErrorMemberActualThickness > 0.625
  then ruleSolution(nicksGouges_6).

% Rule: 6.3m
if unitsType(metric)
  and errorMemberType(webPlate)
  and nickGougeType(edge)
  and (stressErrorMemberLevel(low)
  or stressErrorMemberLevel(medium))
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and ErrorMemberActualThickness > 16
  then ruleSolution(nicksGouges_6).

% Rule: 7.1
if (errorMemberType(flangePlate)
  or errorMemberType(webPlate))
  and nickGougeType(cope)
  then ruleSolution(nicksGouges_7).

% Rule: 8.1
if (errorMemberType(flangePlate)
  or errorMemberType(webPlate)
  or errorMemberType(splicePlate))
  and nickGougeType(hole)
  then ruleSolution(nicksGouges_8).

% Rule: 9.1
if errorMemberType(splicePlate)
  and nickGougeType(edge)
  and nickGougeGrindEdgeEndDistance(false)
  then ruleSolution(nicksGouges_9).

% Rule: 10.1
if errorMemberType(webPlate)
  and nickGougeType(edge)
  and stressErrorMemberLevel(high)
  then ruleSolution(nicksGouges_10).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(nicksGouges_1,nicksGouges,`NAGS-R001`,`Nicks & Gouges Rule Solution`,[],
`Since the gouge is shallow, the gouge may be repaired by simply grinding out the gouge.
According to AASHTO 3.2.2 the net section after grinding should remain 98% or greater of the actual net cross sectional area.
`).

% Solution 2
ruleSolution(nicksGouges_2,nicksGouges,`NAGS-R002`,`Nicks & Gouges Rule Solution`,[],
`Grind out the gouge as to remove all defects.
Examine the repair cavity by magnetic particle or dye penetrant inspection to insure the defect has been completely removed.
Fill in the repair cavity with weld material.
The process used for welding shall be either Shielded Metal Arc or Submerged Arc depending upon shop preference and defect size.
Weld metal shall project at least 1/16" above the rolled surface and the projecting metal removed by grinding and/or chipping
to make it flush with the surrounding surface and to produce a workmanlike finish.
Finished and ground repair shall be visually, MT and UT inspected for defects per AWS/AASHTO D1.5 3.2.2.3
`).

% Solution 3
ruleSolution(nicksGouges_3,nicksGouges,`NAGS-R003`,`Nicks & Gouges Rule Solution`,[],
`Replace the portion with a new plate, as the gouge is very deep.
`).

% Solution 4
ruleSolution(nicksGouges_4,nicksGouges,`NAGS-R004`,`Nicks & Gouges Rule Solution`,[],
`Replace the plate, as it is in a high stress region.
`).

% Solution 5
ruleSolution(nicksGouges_5,nicksGouges,`NAGS-R005`,`Nicks & Gouges Rule Solution`,[],
`Grind the plate gouge so as to have no trace of it.
`).

% Solution 6
ruleSolution(nicksGouges_6,nicksGouges,`NAGS-R006`,`Nicks & Gouges Rule Solution`,[],
`Cut slightly beyond the section.
Reverse the section by 180 degrees and butt weld the new edges.
Trim off the gouge material.
`).

% Solution 7
ruleSolution(nicksGouges_7,nicksGouges,`NAGS-R007`,`Nicks & Gouges Rule Solution`,[],
`REPAIR:

1. Grind 60 degree bevel, 1/4" deep on web repair area.
2. Attach run off bars by tacking in weld grove (do not tack to parent material).
3. Preheat and weld first side as per WPS.
4. Back gouge second side to sound weld meter.
5. Weld second side as per WPS.
6. Remove run off bars by air-arc gouge and grind 1" radius per shop drawing.
7. RT weld repair areas as per contract specifications.
`).

% Solution 8
ruleSolution(nicksGouges_8,nicksGouges,`NAGS-R008`,`Nicks & Gouges Rule Solution`,[],
`Ream the hole so as to remove the gouge.
Check for edge distance problem using the tolerance module.
`).

% Solution 9
ruleSolution(nicksGouges_9,nicksGouges,`NAGS-R009`,`Nicks & Gouges Rule Solution`,[],
`Replace the plate as it does not satisfy the edge distance requirement.
`).

% Solution 10
ruleSolution(nicksGouges_10,nicksGouges,`NAGS-R010`,`Nicks & Gouges Rule Solution`,[],
`Replace the plate, as it is in a high stress region.

Another option is to look at the possibility of removing the damaged area using a "web slug".
After welding the "web slug" in place, grind all welds flush.
Torch cut the "web slug" about 1/4" above the top of the web plate.
Remove balance of the "web slug" to flush with the top of web plate by grinding.
Then 100% RT examine.
`).

