/*----------------------------------------------------------*/
/*  KNBRPDRH.PL - Partially Drilled Hole Rule Knowledge     */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if unitsType(english)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth =< 0.1875
  then ruleSolution(partiallyDrilledHole_1).

% Rule: 1.1m
if unitsType(metric)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth =< 5
  then ruleSolution(partiallyDrilledHole_1).

% Rule: 2.1
if unitsType(english)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth > 0.1875
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and HoleDetailsPartDrilledHoleDepth =< 0.3 * ErrorMemberActualThickness
  then ruleSolution(partiallyDrilledHole_2).

% Rule: 2.1m
if unitsType(metric)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth > 5
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and HoleDetailsPartDrilledHoleDepth =< 0.3 * ErrorMemberActualThickness
  then ruleSolution(partiallyDrilledHole_2).

% Rule: 3.1
if unitsType(english)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth > 0.1875
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and HoleDetailsPartDrilledHoleDepth > 0.3 * ErrorMemberActualThickness
  then ruleSolution(partiallyDrilledHole_3).

% Rule: 3.1m
if unitsType(metric)
  and holeDetailsPartDrilledHoleDepth(HoleDetailsPartDrilledHoleDepth)
  and HoleDetailsPartDrilledHoleDepth > 5
  and errorMemberActualThickness(ErrorMemberActualThickness)
  and HoleDetailsPartDrilledHoleDepth > 0.3 * ErrorMemberActualThickness
  then ruleSolution(partiallyDrilledHole_3).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(partiallyDrilledHole_1,partiallyDrilledHole,`PDRH-R001`,`Partially Drilled Hole Rule Solution`,[],
`This hole is not too deep, therefore the repair should conform to the fabrication repair procedure 2.0
of Pitt-Des Moines pertaining to grinding of plate or any other corresponding procedure used by other fabricators.
According to AASHTO 3.2.2 the thickness after grinding should remain 98% or greater of the actual net cross sectional area.
`).

% Solution 2
ruleSolution(partiallyDrilledHole_2,partiallyDrilledHole,`PDRH-R002`,`Partially Drilled Hole Rule Solution`,[],
`This hole is slightly deep and requires to be weld repaired.
Grind out the partially drilled hole as to remove all defects.
Examine the repair cavity by magnetic particle or dye penetrant inspection to insure the defect has been completely removed.
Fill in the repair cavity with weld material.
The process used for welding shall be either Shielded Metal Arc or Submerged Arc depending upon shop preference and defect size.
Weld metal shall project at least 1/16" above the rolled surface and the projecting metal removed by grinding and/or
chipping to make it flush with the surrounding surface and to produce a workmanlike finish.
Finished and ground repair shall be visually, MT and UT inspected for defects per AWS/AASHTO D1.5 3.2.2.3.
`).

% Solution 3
ruleSolution(partiallyDrilledHole_3,partiallyDrilledHole,`PDRH-R003`,`Partially Drilled Hole Rule Solution`,[],
`The depth of the hole is substantial and plate should be replaced.
`).

