/*----------------------------------------------------------*/
/*  KNBRSFRC.PL - Stress Fracture Rule Knowledge            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if unitsType(english)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap =< 0.25
  and stressErrorMemberLevel(medium)
  and errorMemberType(diaphragmBrace)
  then ruleSolution(stressFracture_1).

% Rule: 1.1m
if unitsType(metric)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap =< 6
  and stressErrorMemberLevel(medium)
  and errorMemberType(diaphragmBrace)
  then ruleSolution(stressFracture_1).

% Rule: 1.2
if unitsType(english)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap =< 0.25
  and stressErrorMemberLevel(low)
  and errorMemberType(diaphragmBrace)
  then ruleSolution(stressFracture_1).

% Rule: 1.2m
if unitsType(metric)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap =< 6
  and stressErrorMemberLevel(low)
  and errorMemberType(diaphragmBrace)
  then ruleSolution(stressFracture_1).

% Rule: 2.1
if unitsType(english)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap > 0.25
  then ruleSolution(stressFracture_2).

% Rule: 2.1m
if unitsType(metric)
  and stressFractures(true)
  and stressMaxGap(StressMaxGap)
  and StressMaxGap > 6
  then ruleSolution(stressFracture_2).

% Rule: 3.1
if stressFractures(true)
  and stressFatigueConcerns(high)
  then ruleSolution(stressFracture_3).

% Rule: 4.1
if stressFractures(true)
  and stressErrorMemberLevel(high)
  then ruleSolution(stressFracture_4).

% Rule: 5.1
if stressFractures(true)
  and stressErrorMemberLevel(unknown)
  then ruleSolution(stressFracture_5).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(stressFracture_1,stressFracture,`SFRC-R001`,`Stress Fracture Rule Solution`,[],
`Stress fractures have occurred during fabrication.

REPAIR:

All members with stress fractures will be subjected to a Dye Penetrant examination on the entire length of the bend.
The Dye Penetrant examination will be in accordance with ASTM E165 and a written Dye Penetrant examination procedure.
All members with less than 1/4" (6mm) gap will be repaired by welding with FCAW-1R2 approved welding procedure.
Remove to sound metal 1" (25mm) past defect. Weld and grind smooth.
`).

% Solution 2
ruleSolution(stressFracture_2,stressFracture,`SFRC-R002`,`Stress Fracture Rule Solution`,[],
`Stress fractures have occurred during fabrication.

REPAIR:

All members with stress fractures will be subjected to a Dye Penetrant examination on the entire length of the bend.
The Dye Penetrant examination will be in accordance with ASTM E165 and a written Dye Penetrant examination procedure.
All members with greater than 1/4" (6mm) gap will be not be used. Replace member with new piece.
Make sure that all bending of material is against the grain of the material.
`).

% Solution 3
ruleSolution(stressFracture_3,stressFracture,`SFRC-R003`,`Stress Fracture Rule Solution`,[],
`Stress fractures have occurred during fabrication.

REPAIR:

All members with stress fractures will be subjected to a Dye Penetrant examination on the entire length of the bend.
The Dye Penetrant examination will be in accordance with ASTM E165 and a written Dye Penetrant examination procedure.
Fatigue concerns for this member are high. Due to fatigue concerns the member should be replaced with a new piece.
`).

% Solution 4
ruleSolution(stressFracture_4,stressFracture,`SFRC-R004`,`Stress Fracture Rule Solution`,[],
`Stress fractures have occurred during fabrication.

REPAIR:

All members with stress fractures will be subjected to a Dye Penetrant examination on the entire length of the bend.
The Dye Penetrant examination will be in accordance with ASTM E165 and a written Dye Penetrant examination procedure.
The stress in this member is high. Due to high stress concerns the member should be replaced with a new piece.
`).

% Solution 5
ruleSolution(stressFracture_5,stressFracture,`SFRC-R005`,`Stress Fracture Rule Solution`,[],
`Stress fractures have occurred during fabrication.

REPAIR:

All members with stress fractures will be subjected to a Dye Penetrant examination on the entire length of the bend.
The Dye Penetrant examination will be in accordance with ASTM E165 and a written Dye Penetrant examination procedure.
The stress in this member is unknown. This information is necessary for the repair procedure to be determined.
`).

