/*----------------------------------------------------------*/
/*  KNBCMCTM.PL - Miscut Member Case Knowledge              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(miscutMember,
  [
    bridgeType                          :0.3,
    errorMemberType                     :0.8,
    attachMemberType                    :0.5,
    errorMemberLocation                 :0.7,
    errorMemberClass                    :0.3,
    attachMemberClass                   :0.3,
    errorMemberDesignLength             :0.5*continuous_feature_eval(2000),
    errorMemberDesignWidth              :0.6*continuous_feature_eval(20),
    errorMemberDesignThickness          :0.6*continuous_feature_eval(3),
    errorMemberActualLength             :0.6*continuous_feature_eval(2000),
    errorMemberActualWidth              :0.6*continuous_feature_eval(20),
    errorMemberActualThickness          :0.6*continuous_feature_eval(3),
    attachMemberDesignLength            :0.3*continuous_feature_eval(2000),
    attachMemberDesignWidth             :0.3*continuous_feature_eval(20),
    attachMemberDesignThickness         :0.3*continuous_feature_eval(3),
    attachMemberActualLength            :0.3*continuous_feature_eval(2000),
    attachMemberActualWidth             :0.3*continuous_feature_eval(20),
    attachMemberActualThickness         :0.3*continuous_feature_eval(3),
    stressErrorMemberLevel              :0.9,
    stressAttachMemberLevel             :0.7,
    miscutMemberErrorOccursAt           :0.7,
    miscutMemberSpecifiedClipped        :0.6,
    miscutMemberActualClipped           :0.6,
    miscutMemberClippedDimensionsCorrect:0.6,
    miscutMemberActualSweep             :0.5*continuous_feature_eval(10),
    miscutMemberSpecifiedSweep          :0.5*continuous_feature_eval(10)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(miscutMember,
  [
    errorMemberDesignLength,
    errorMemberDesignWidth,
    errorMemberDesignThickness,
    errorMemberActualLength,
    errorMemberActualWidth,
    errorMemberActualThickness,
    attachMemberDesignLength,
    attachMemberDesignWidth,
    attachMemberDesignThickness,
    attachMemberActualLength,
    attachMemberActualWidth,
    attachMemberActualThickness,
    miscutMemberActualSweep,
    miscutMemberSpecifiedSweep
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(miscutMember_1,miscutMember,`MCTM-C001`,`Miscut Member Case Solution`,[dl134],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :intermediateStiffener,
    attachMemberType                    :plateGirder,
    errorMemberLocation                 :stiffenerAttachment,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignLength             :30,
    errorMemberActualLength             :30,
    miscutMemberSpecifiedClipped        :true,
    miscutMemberActualClipped           :true,
    miscutMemberClippedDimensionsCorrect:no
  ],
  `The difference in the clipped dimensions is minimal.
Leave the stiffeners as they are.`,
`Case # DL134:
Description of Error: Clips on stiffeners (1/2" x 6" x30") were fabricated as 1"x 2" which should be 3/4" x 2 1/2".
Solution Recommended: OK to leave as is. The difference in the clipped dimensions is minimal.`
).

% Solution 2
caseSolution(miscutMember_2,miscutMember,`MCTM-C002`,`Miscut Member Case Solution`,[],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :tensionFlange,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :711,
    errorMemberActualLength             :645
  ],
  `The bottom flanges were purchased too short.
Add a flange butt weld splice to make up the shortage.
The butt weld splice shall be radiographed 100%.`,
`Case # MG107:
Description of Error: Due to a purchasing error, the slab plate for girder bottom flanges was purchased 53'-9 in length but 59'-3 is needed for the three girders.
Solution Recommended: Add a flange butt weld splice at 7'6" from the right end to make up the shortage. 
M270 Grade 50 CVN material from this contract will be used for the repair, 
The butt weld splice shall be radiographed 100%.
Other Possible Solutions: If the bottom flange is in compression, less than 100% RT should be required.`
).

% Solution 3
caseSolution(miscutMember_3,miscutMember,`MCTM-C003`,`Miscut Member Case Solution`,[fb160],success,
  [
    bridgeType                          :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    miscutMemberActualSweep             :4,
    miscutMemberSpecifiedSweep          :9.8375
  ],
  `The flanges could not be burned to the proper sweep.
Heat curve the flanges to meet the sweep requirements by following the  appropriate DOT Special Provisions Section`,
`Case # FB160:
Description of Error: Due to purchasing error, girder top and bottom flange plates could not be burned with the detailed 9 15/16" of sweep but only 4" of sweep. 
Solution Recommended: Add the remaining 5 15/16" of sweep by the heat curving method following the procedure outlined 
in the appropriate Special Provisions Section for heat curved rolled beams and welded plate girders. 
Fabricator will locate the heats working from center line of girder and heating at 5' increments of the length of the girder. 
Maximum temperature of 1100  F. Top flange and bottom flange to be heated at same time with two rose buds per flange (one rose bud on each side of flange). 
Additional heat may be needed. Heating to be done in horizontal position, 
blocked at both ends with middle unsupported (1' gap between girder and center blocking).`
).

% Solution 4
caseSolution(miscutMember_4,miscutMember,`MCTM-C004`,`Miscut Member Case Solution`,[fb151],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :web,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :732,
    errorMemberActualLength             :731
  ],
  `The web of a plate girder was cut short.
The girder can be cut off to be square and the connecting girder can be extended to make up for the trim.`,
`Case # FB151:
Description of Error: The web on a girder was miscut by 1" at the top flange.
Solution Recommended: Girder can have its end cut off to be square. 
The connecting girder can be lengthened 1" to make up for the trim.
Other Possible Solutions: If this was at the abutment end of a girder, leave it as is.`
).

% Solution 5
caseSolution(miscutMember_5,miscutMember,`MCTM-C005`,`Miscut Member Case Solution`,[dl132],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    miscutMemberErrorOccursAt           :end
  ],
  `Flange was to be stripped on far side only.
It was stripped on the near side. Strip the far side.
Weld tabs that were cutoff on to the near side.
Check the weld with magnetic particle testing.`,
`Case # DL132:
Description of Error: Top flange was to be stripped far side only. 
It was stripped on the near side by mistake.
Solution Recommended: Strip the far side. 
Weld the tabs that were cut off on the near side. Check the weld with magnetic particle testing.
Other Possible Solutions: Strip the far side and leave both sides of the flange stripped if adequate to transfer load (check blocks shear).
`
).

% Solution 6
caseSolution(miscutMember_6,miscutMember,`MCTM-C006`,`Miscut Member Case Solution`,[dl131],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    miscutMemberErrorOccursAt           :end,
    miscutMemberSpecifiedClipped        :true,
    miscutMemberActualClipped           :true,
    miscutMemberClippedDimensionsCorrect:false
  ],
  `The flange was clipped on both sides when it was only to be clipped on one side.
It is alright to leave the member as is.`,
`Case # DL131:
Description of Error: Top flange was to be clipped on the far side to miss abutment wall. 
It was clipped on both sides.
Solution Recommended: OK to leave as is.`
).

% Solution 7
caseSolution(miscutMember_7,miscutMember,`MCTM-C007`,`Miscut Member Case Solution`,[dl129],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    miscutMemberErrorOccursAt           :end,
    miscutMemberSpecifiedClipped        :false,
    miscutMemberActualClipped           :true
  ],
  `Only top flange was to be clipped but both the top and bottom flange were clipped.
For the bottom plate cut off the plate 6 in. beyond last splice hole.
Weld a new flange plate on.
The splice should then be x-rayed.`,
`Case # 129:
Description of Error: Top flange was to be clipped. The shop clipped both the top and bottom flanges.
Solution Recommended: Cut off plate 6" beyond last splice hole. Weld a new flange plate on. Get the splice X-rayed.`
).

% Solution 8
caseSolution(miscutMember_8,miscutMember,`MCTM-C008`,`Miscut Member Case Solution`,[dl127],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :525.75,
    errorMemberActualLength             :520
  ],
  `The flange splice was off.
The thicker plate was cut too short and the thinner plate was cut to long.
Cut off thicker flange and return it to stock.
Cut a new flange from stock to proper length.
Make a new W2 weld and have it x-rayed.
Cut excess length off of thinner plate.`,
`Case # DL127:
Description of Error: The shop welded top flange splice was off by 5 3/4". 
The thicker plate was too short and thinner plate was too long.
Solution Recommended: Cut off thicker flange and return it to stock. 
Cut a new flange from stock to the proper length. Make a new W2 weld. Get it x-rayed. 
Cut excess length off of thinner plate.
Other Possible Solutions: Designer can check design stresses at location to see if flange can be left as is.`
).

% Solution 9
caseSolution(miscutMember_9,miscutMember,`MCTM-C009`,`Miscut Member Case Solution`,[dl122],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :tensionFlange,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :381,
    errorMemberActualLength             :360,
    miscutMemberErrorOccursAt           :end
  ],
  `The flange consisted of two plates, a narrow one and a wide one spliced together.
The wide plate was too short and the narrow plate was too long.
Cut off the narrow plate to the correct dimensions and splice a piece of wide plate on
to the wide end and have the splice x-rayed.`,
`Case # DL122:
Description of Error: Bottom flange was made up of 2 plates spliced together in the shop. 
The narrow piece ended up 21" too long, the wide piece 21" too short. 
The flange had been spliced together and tacked to the web.  
Solution Recommended: Remove flange from web. Cut 21" off narrow end. Splice a 21" piece on to the wide end. 
Send revised drawings. Have the splice x-rayed.`
).

% Solution 10
caseSolution(miscutMember_10,miscutMember,`MCTM-C010`,`Miscut Member Case Solution`,[],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :intermediateStiffeners,
    attachMemberType                    :plateGirder,
    errorMemberLocation                 :stiffenerAttachment,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignLength             :21,
    errorMemberActualLength             :20.6875
  ],
  `The stiffeners were cut too short.
Build up the stiffeners with weld material and ultrasonic test.`,
`Case # MG114:
Description of Error: The milling machine had milled the stiffeners, 
that are below the 1 3/8" x 6 1/2" girder flange plate, the wrong direction. 
Twelve diaphragms were made and installed before the error was noticed. 
The up slope stiffener will be 5/32" long and the down slope stiffener will be 5/16" short. 
Solution Recommended: Trim the long stiffeners to the proper slope. 
Build up the short stiffeners with weld grind and ultrasonic test.
Other Possible Solutions: If this was discovered before the stiffeners were installed, make new ones.`
).

% Solution 11
caseSolution(miscutMember_11,miscutMember,`MCTM-C011`,`Miscut Member Case Solution`,[mg108],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :capBeam,
    attachMemberType                    :plateGirder,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignWidth              :36,
    errorMemberActualWidth              :35.625
  ],
  `The top flange for a steel capbeam was cut too narrow.
The flange was supposed to overhang the web.
Since the flange was cut too narrow to allow the overhang align the flange with the edge of the web.
The edge that aligns with the edge will have a single bevel full penetration weld with a backing bar.`,
`Case # MG108:
Description of Error: When flame cutting one top flange plate for a steel cap beam, 
the cutting machine was incorrectly set causing the plate to be cut 3/8" narrow.  
The flange is supposed to overhang the web by 3/8". 
Solution Recommended: Align the edge of the flange plate with the web on one side of the box which will give a 3/8" overhang on the other side. 
The edge that aligns will have a single bevel full penetration weld with a backing bar.`
).

% Solution 12
caseSolution(miscutMember_12,miscutMember,`MCTM-C012`,`Miscut Member Case Solution`,[],success,
  [
    bridgeType                          :rolled,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :527.75,
    errorMemberActualLength             :527
  ],
  `The rolled beam was cut short and rejected for out of tolerance specifications on center of holes to edge of beam.`,
`Case # MP114
Description of Error: The rolled beam was cut short. Also was out of tolerance on edge distance. 
Solution Recommended: Rolled beam was rejected for out of tolerance specifications on center of holes to edge of beam.`
).

% Solution 13
caseSolution(miscutMember_13,miscutMember,`MCTM-C013`,`Miscut Member Case Solution`,[tf176],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :bearingStiffener,
    attachMemberType                    :plateGirder,
    errorMemberLocation                 :bearing,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignLength             :70,
    errorMemberDesignWidth              :20,
    errorMemberActualLength             :69.8125,
    errorMemberActualWidth              :20,
    miscutMemberErrorOccursAt           :end
  ],
  `A bearing stiffener does not have the required tight fit at stiffener to flange.
There is a gap of 3/16 in. that occurs at about midway on the stiffener to the outer edge of the stiffener.
Either increase the current fillet weld size of stiffener to flange weld 
or (avoid full penetration weld if possible) use a full penetration weld of stiffener to flange.`,
`Case # TF176:
Description of Error: Blank bearing stiffener installed on girder does not have the required "tight fit" at stiffener to flange. 
The gap starts approximately 8" from girder centerline and extends toward stiffener outer edge with maximum 3/16" gap at girder flange edge.
Solution Recommended: Either increase the current 3/8 fillet weld size to 1/2 inch 
or (avoid full penetration weld if possible) use a full penetration weld of stiffener to flange whichever is acceptable to DOT.`
).

% Solution 14
caseSolution(miscutMember_14,miscutMember,`MCTM-C014`,`Miscut Member Case Solution`,[tf183],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    attachMemberType                    :splicePlate,
    errorMemberLocation                 :spliceConnection,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignLength             :282,
    errorMemberActualLength             :289.5,
    miscutMemberErrorOccursAt           :end
  ],
  `Girder has been fabricated with the shop welded splice shifted away from X-end.
The thicker of the two flanges being spliced is longer than called out by design.
The resulting shop welded splice subsequently falls in the bolt hole pattern for floor beam.
Corrective action calls for grinding the thicker flange to match the thinner flange
thickness for approximately 4 1/2 in thus allowing the floor beam to fit properly.`,
`Case # TF183:
Description of Error: A girder has been fabricated with the shop welded splice shifted away from X-end. 
(The thicker of the two flanges being spliced is longer than called out by design). 
The resulting shop welded splice subsequently falls in the bolt hole pattern for floor beam at extension dimension 24'-3 ". 
Solution Recommended: Corrective action calls for grinding the thicker flange 
to match the thinner flange thickness for approximately 4 1/2inches thus allowing the floor beam to fit properly.`
).

% Solution 15
caseSolution(miscutMember_15,miscutMember,`MCTM-C015`,`Miscut Member Case Solution`,[tf220],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :tensionFlange,
    errorMemberClass                    :primary,
    errorMemberDesignWidth              :20,
    errorMemberActualWidth              :16,
    miscutMemberErrorOccursAt           :end,
    miscutMemberSpecifiedClipped        :false,
    miscutMemberActualClipped           :true
  ],
  `The fabricator mistakenly cut each end of the bottom flange at a 2 ft. radius.
Weld the cutoff pieces back onto the flange.`,
`Case # TF220:
Description of Error: The top and bottom flange paltes of the girder are 20" wide. 
The top flange has a 2'-0" radius on each end to transition to a 16" wide flange at the field splices. 
The 20" bottom flange splices to a 20" flange to each end of the girder. 
The fabricator mistakenly cut each end of the bottom flange at a 2'0" radius. 
Solution Recommended: Weld the cutoff pieces back onto the flange. Welds should be ground smooth and N.D. tested.`
).

% Solution 16
caseSolution(miscutMember_16,miscutMember,`MCTM-C016`,`Miscut Member Case Solution`,[],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :tensionFlange,
    errorMemberClass                    :primary,
    miscutMemberErrorOccursAt           :end,
    miscutMemberSpecifiedClipped        :false,
    miscutMemberActualClipped           :true
  ],
  `The bottom flange was incorrectly cut to the same taper as the top flange.
Corrective action will be to reattach same pieces by full penetration welding using
AWS Prequalified Joint and DOT approved weld procedures. Finished weld will be 100% UT inspected.`,
`Case # TF222:
Description of Error: Girder bottom flange was incorrectly cut to the same taper as top flange.
Solution Recommended: Corrective action will be to reattach same pieces by full penetration welding 
using AWS Prequalified Joint and DOT approved weld procedures. Finish weld will be 100% UT inspected. 
Drawings will be revised to reflect the "as built" condition.`
).

% Solution 17
caseSolution(miscutMember_17,miscutMember,`MCTM-C017`,`Miscut Member Case Solution`,[],success,
  [
    errorMemberType                     :plateGirder,
    errorMemberLocation                 :tensionFlange,
    errorMemberClass                    :primary,
    errorMemberDesignLength             :186,
    errorMemberActualLength             :150,
    miscutMemberErrorOccursAt           :end
  ],
  `The flange of a girder was miscut.
The configuration can be obtained by the addition of a shop welded flange splice at 5 ft. from x-end.`,
`Case # TF223:
Description of Error: Due to a numerically controlled equipment program error flange a girder has been miscut.
Solution Recommended: The correct configuration can be obtained by the addition of a shop welded flange splice 
at 5'-0" from X-end splice to be located between stiffeners at extension dimension 3'-9 3/4 and 7'-1 3/4. 
Drawings revised to show "as built"condition.`
).

% Solution 18
caseSolution(miscutMember_18,miscutMember,`MCTM-C018`,`Miscut Member Case Solution`,[tf224],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    attachMemberType                    :splicePlate,
    errorMemberLocation                 :compressionFlange,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    miscutMemberErrorOccursAt           :end,
    miscutMemberSpecifiedClipped        :true,
    miscutMemberActualClipped           :true,
    miscutMemberClippedDimensionsCorrect:false
  ],
  `The girder has its top flange incorrectly clipped.
As a result the edge distance for one of the holes in the flange is not adequate.
Move the hole nearest the clipped edge.
Fabricate splice plates to match the new hole pattern.`,
`Case # TF224:
Description of Error: One girder has the corners clipped incorrectly. 
The centerline of girder to edge of clip is called out by design to be 6 inches. 
As fabricated, this dimension has been cut to 5 1/8 inch (1'-0 3/8 inch along length of taper cut). 
Review of "As Built" indicates by relocating hole 1/4 inch (neither splice plate nor flange are drilled at this writing); 
an 1 1/2 inch edge distance and 3 inch optimum between holes can be maintained.
 In any event, the edge distance will be maintained knowing 2 5/8 inch minimum center to center of hole can still be maintained.
Solution Recommended: Relocate hole 1/4 - 3/8 inch allowing the clip (taper cut) to remain as fabricated. 
Drawing revised to reflect "as built" condition.`
).

% Solution 19
caseSolution(miscutMember_19,miscutMember,`MCTM-C019`,`Miscut Member Case Solution`,[],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :rocker,
    attachMemberType                    :plateGirder,
    errorMemberLocation                 :bearing,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignLength             :9,
    errorMemberDesignThickness          :1.125,
    errorMemberActualLength             :8.25,
    errorMemberActualThickness          :1.25,
    miscutMemberErrorOccursAt           :end
  ],
  `The rocker for the pier has been cut short 3/4 in.
The rocker plates have not been milled yet. Provide a thicker sole plate or base plate and use rockers.
The rocker plate would be remilled on a 8 1/4 in. radius instead of the 9 in. radius as specified.`,
`Case # NC508:
Description of Error: The rockers for two piers have been fabricated incorrectly. 
The 1 1/8" thick vertical bearing plates were cut " short. The rocker plates have not been milled yet.
Solution Recommended: Provide a thicker sole plate or base plate and use the rockers. 
The rocker plates would be milled on a 8 " radius instead of the 9" radius. 
DOT checked the movement capacity for the 8 ' radius before approval of the rockers.`
).

% Solution 20
caseSolution(miscutMember_20,miscutMember,`MCTM-C020`,`Miscut Member Case Solution`,[nc512],success,
  [
    bridgeType                          :plateGirder,
    errorMemberType                     :plateGirder,
    attachMemberType                    :splicePlate,
    errorMemberLocation                 :web,
    errorMemberClass                    :primary,
    attachMemberClass                   :primary,
    errorMemberDesignWidth              :71.875,
    errorMemberActualWidth              :71.75,
    miscutMemberErrorOccursAt           :end
  ],
  `The web plate for the girder has been cut narrow at the field splice area.
Use a fill plate at field splice to accommodate the web depth under run.`,
`Case # NC512:
Description of Error: The web plate for one girder (marked girder D in sketches) has been cut narrow. 
The as fabricated web depth is 1/4" narrow at field splice #3, 1/8" narrow at pier #2, and 1/16" narrow at field splice #4. 
The girder is fabricated and is in the laydown area for the drilling of the field splices.
Solution Recommended: Provide 1/8" fill plates at field splice to accommodate the web depth under run.`
).

