/*----------------------------------------------------------*/
/*  KNBCMLCH.PL - Mislocated Hole Case Knowledge            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/

feature_weights(mislocatedHole,
  [ bridgeType                                 :0.2,
    errorMemberType                            :0.8,
    attachMemberType                           :0.5,
    errorMemberLocation                        :0.7,
    errorMemberClass                           :0.3,
    attachMemberClass                          :0.3,
    holeDetailsType                            :0.5,
    holeDetailsNumberWithErrors                :0.5*continuous_feature_eval(50),
    holeDetailsNumberInGrouping                :0.5*continuous_feature_eval(100),
    holeDetailsActualBoltDiameter              :0.3*continuous_feature_eval(2),
    holeDetailsActualHoleDiameter              :0.3*continuous_feature_eval(2),
    holeDetailsActualLongHoleSpacing           :0.5*continuous_feature_eval(10),
    holeDetailsActualTransverseHoleSpacing     :0.5*continuous_feature_eval(10),
    holeDetailsSpecifiedBoltDiameter           :0.3*continuous_feature_eval(2),
    holeDetailsSpecifiedHoleDiameter           :0.3*continuous_feature_eval(2),
    holeDetailsSpecifiedLongHoleSpacing        :0.5*continuous_feature_eval(10),
    holeDetailsSpecifiedTransverseHoleSpacing  :0.5*continuous_feature_eval(10),
    holeDetailsPartDrilledHole                 :0.6,
    holeDetailsPartDrilledHoleDiameter         :0.3*continuous_feature_eval(2),
    holeDetailsPartDrilledHoleDepth            :0.6*continuous_feature_eval(3),
    holeDetailsPartDrilledHoleCoverage         :0.7*continuous_feature_eval(100),
    holeDetailsHoleBoringProcedure             :0.2,
    holeDistanceFromIntersectingMember         :0.6*continuous_feature_eval(20),
    holeDistanceFromErrorMember                :0.6*continuous_feature_eval(20),
    holeDistanceFromEdge                       :0.7*continuous_feature_eval(5),
    holeDistanceFromEnd                        :0.7*continuous_feature_eval(5),
    mislocatedHoleDistanceCorrectLocation      :0.5*continuous_feature_eval(20),
    mislocatedHoleIncorrectFlange              :0.8,
    mislocatedHoleReinforcingSteelHole         :0.9,
    mislocatedHoleAdditionalRowHolesDrilled    :0.7,
    mislocatedHoleEdgeEndDistanceSpecification :0.7,
    mislocatedHoleIntersectionCurrentPosition  :0.8,
    mislocatedHoleSpecifiedHolePatternCorrect  :0.7,
    mislocatedHoleInterfereWithSpecifiedPattern:0.8,
    mislocatedHoleIntersectionNewPosition      :0.7
 ]
).

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/

feature_units(mislocatedHole,
  [ holeDetailsActualBoltDiameter,
    holeDetailsActualHoleDiameter,
    holeDetailsActualLongHoleSpacing,
    holeDetailsActualTransverseHoleSpacing,
    holeDetailsSpecifiedBoltDiameter,
    holeDetailsSpecifiedHoleDiameter,
    holeDetailsSpecifiedLongSpacing,
    holeDetailsSpecifiedTransverseSpacing,
    holeDetailsPartDrilledHoleDiameter,
    holeDetailsPartDrilledHoleDepth,
    holeDistanceFromIntersectingMember,
    holeDistanceFromErrorMember,
    holeDistanceFromEdge,
    holeDistanceFromEnd,
    mislocatedHoleDistanceCorrectLocation
]
).

:-multifile caseSolution/9.

/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(mislocatedHole_1,mislocatedHole,`MLCH-C001`,`Mislocated Hole Case Solution`,[jj148],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :web,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :4,
    holeDetailsNumberInGrouping                :38,
    holeDetailsActualLongHoleSpacing           :3,
    holeDetailsActualTransverseHoleSpacing     :1,
    holeDetailsSpecifiedLongSpacing            :3,
    holeDetailsSpecifiedTransverseSpacing      :0,
    holeDetailsHoleBoringProcedure             :drilled,
    mislocatedHoleDistanceCorrectLocation      :1,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :false,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false
  ],
  `Intersection of existing member or holes does not occur at current location or new placement location.
Custom fabricate new splice plates to match as built conditions.`,
  `Case # JJ148:
Description of Error: The 11/16 dia. web lay down holes on a girder have been laid out and drilled. 
Four holes are mislocated.
Solution Recommended: To leave the holes in this location and custom fabricate new splice plates to match existing girder web holes.`
).

% Solution 2

caseSolution(mislocatedHole_2,mislocatedHole,`MLCH-C002`,`Mislocated Hole Case Solution`,[dl167],success,
  [ bridgeType                                 :rolled,
    attachMemberType                           :diaphragmBrace,
    errorMemberLocation                        :web,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsNumberWithErrors                :1,
    holeDetailsNumberInGrouping                :9,
    holeDetailsHoleBoringProcedure             :punched,
    mislocatedHoleDistanceCorrectLocation      :1.5,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false
  ],
  `It is OK to leave the hole as is as long as the erroneous hole is covered.
There will be diaphragms connection plates on both sides covering the erroneous hole.`,
  `Case #DL167:
Description of Error: 8 holes in the beam are used to attach a diaphragm. 
An extra hole was inadvertently punched at the center line of the bottom hole group.
Solution Recommended: Ok, to leave error as is. 
This is an interior beam, so there will be diaphragms on both sides covering the erroneous hole.`
).

% Solution 3

caseSolution(mislocatedHole_3,mislocatedHole,`MLCH-C003`,`Mislocated Hole Case Solution`,[fb155],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :capBeam,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :web,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :16,
    holeDetailsNumberInGrouping                :16,
    holeDetailsHoleBoringProcedure             :drilled,
    mislocatedHoleDistanceCorrectLocation      :30.5,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false
  ],
  `Intersection of existing member or holes does not occur at current location or new placement location.
The mislocated holes do not interfere with specified placement of hole pattern.
Leave existing holes in place and bolt with double washers.`,
  `Case #FB155:
Description of Error: A cap beam  had a hole pattern mislocated and drilled in the near side web. 
The hole pattern intended for extension dimension 33'-4 5/8" was mislocated and drilled 
at extension dimension 35'-11 1/8".
Solution Recommended: To fill these holes with A325 bolts.`
).

% Solution 4

caseSolution(mislocatedHole_4,mislocatedHole,`MLCH-C004`,`Mislocated Hole Case Solution`,[mg117],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    attachMemberType                           :intermediateStiffener,
    errorMemberLocation                        :boltedConnection,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :1,
    holeDetailsNumberInGrouping                :14,
    mislocatedHoleDistanceCorrectLocation      :1.1875,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :true,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Intersection of the hole and stiffener occurs at the current location.
Interference occurs with the intermediate stiffener.Clip the stiffener to allow bolt access.`,
  `Case # MG117:
Description of Error: Due to misalignment of columns in the field, 
fabricator has shifted the hole pattern for the bearing assembly at one end of  a cap beam by 1-3/16 inches. 
The results of this shifting of holes 
are 1 hole falls next to a stiffener and will interfere with the installation of the bolt. 
The fabricator requested authorization to clip the stiffener to allow bolt access.
Solution Recommended: To clip the stiffener to allow bolt access.`
).

% Solution 5
caseSolution(mislocatedHole_5,mislocatedHole,`MLCH-C005`,`Mislocated Hole Case Solution`,[mg102],success,
  [ bridgeType                                 :boxGirder,
    errorMemberType                            :boxGirder,
    attachMemberType                           :boxGirder,
    errorMemberLocation                        :compressionFlange,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :1,
    holeDetailsNumberInGrouping                :7,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :true,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :true,
    mislocatedHoleSpecifiedHolePatternCorrect  :false,
    mislocatedHoleInterfereWithSpecifiedPattern:true],
  `The hole intersects with the connection.Plug weld the hole and NDT test.`,
  `Case #MG102:
Description of Error: The 7/8" diameter hole shown on the diagram was drilled and plug welded 
without any permission at the shop and was discovered by chance during field radiography. 
The six 1 1/4" holes were also drilled wrong but were evaluated, 
repaired and NDT tested before acceptance of the girder. 
(see case 'MLCH-C013' for following error on same member) 
Solution Recommended: This is a two-part problem.
1)Since conditions allowed filling and NDT testing of the 1 1/4" diameter holes, 
the same technical fix should be possible on the 7/8" hole.
2)Since the fabricator did not bring the 7/8" hole to the attention of the owner,the fabricator's QC is called into question. For this reason,
repair of this defect will be decided on by design department and the consulting engineers handing the project.`
).

% Solution 6

caseSolution(mislocatedHole_6,mislocatedHole,`MLCH-C006`,`Mislocated Hole Case Solution`,[mg110],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :tensionFlange,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :1,
    holeDetailsNumberInGrouping                :24,
    holeDetailsActualBoltDiameter              :0.875,
    holeDetailsActualHoleDiameter              :0.9375,
    holeDetailsSpecifiedBoltDiameter           :0.875,
    holeDetailsSpecifiedHoleDiameter           :0.9375,
    holeDetailsPartDrilled                     :true,
    holeDetailsPartDrilledHoleDiameter         :0.9375,
    holeDetailsPartDrilledHoleDepth            :0.25,
    holeDetailsPartDrilledHoleCoverage         :80,
    holeDetailsHoleBoringProcedure             :drilled,
    mislocatedHoleDistanceCorrectLocation      :0.15625,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Since the splice and fill plates at this location have round holes.
It is alright to use this girder as it is fabricated.`,
  `Case #MG110:
Description of Error: Girder bottom flange right end has a partially drilled hole mislocated by 5/32 of an inch. 
The splice and fill plates at this splice will have round holes.
Solution Recommended: To use this girder as fabricated.`
).

% Solution 7

caseSolution(mislocatedHole_7,mislocatedHole,`MLCH-C007`,`Mislocated Hole Case Solution`,[dl168],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    errorMemberLocation                        :web,
    errorMemberClass                           :primary,
    holeDetailsNumberWithErrors                :5,
    holeDetailsNumberInGrouping                :5,
    holeDetailsHoleBoringProcedure             :drilled,
    mislocatedHoleDistanceCorrectLocation      :0.5,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :true,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Mislocation of holes has occurred at abutment end of member.Holes are used for passing through reinforcing steel.
Distance mislocated holes are off from specified location is small enough to allow for slotting holes.
Extend holes toward specified location to make into slotted holes`,
  `Case #DL168:
Description of Error: Holes drilled near the end of the girder were drilled 1/2" off. 
These holes are for reinforcing steel to pass through at an end abutment.
Solution Recommended: Extend holes toward end of girder, making it a slot.`
).

% Solution 8

caseSolution(mislocatedHole_8,mislocatedHole,`MLCH-C008`,`Mislocated Hole Case Solution`,[dl124],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    errorMemberLocation                        :web,
    errorMemberClass                           :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :4,
    holeDetailsNumberInGrouping                :4,
    mislocatedHoleDistanceCorrectLocation      :3.25,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :true,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Mislocation of holes has occurred at abutment end of member.
Holes are used for passing through reinforcing steel.
Distance mislocated holes are off from specified location is large.
Leave holes in place and adjust reinforcing steel in field.`,
  `Case #DL124:
Description of Error: Dimensions X and Y were reversed when putting in holes and slots.
This made them all 3 1/4" too low.
Solution Recommended: Ok to leave as is. Reinforcing steel to be adjusted in the field.`
).

% Solution 9

caseSolution(mislocatedHole_9,mislocatedHole,`MLCH-C009`,`Mislocated Hole Case Solution`,[],success,
  [ bridgeType                                 :rolled,
    errorMemberType                            :capBeam,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :splice,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :true,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `The splice plate holes were drilled in both ends of the abutment beam.
Request to use the beam as is was denied. The beam was cut to be used at another location.
A new beam was fabricated to correct the abutment beam with the mislocated holes.`,
`Case #MP147:
Description of Error: Splice plate holes were drilled in both ends of abutment beam. 
The fabricator requested to go ahead and use beam as it is.
Solution Recommended: Note that this is an unusual type of fabrication error since the beams are usually drilled or reamed while assembled, 
in which case the fabricator could not drill a splice in the abutment end when there is no beam for the other half of the splice.
1) If the abutment was an integral design, the use of the beam should have been allowed. 
2) For the actual case, the request to go ahead and use the beam was denied. Beam was then cut from 73'3 7/8" to 43'11 ", 
and used at other place. 
New piece was furnished in place of the misdrilled beam.`
).

% Solution 10

caseSolution(mislocatedHole_10,mislocatedHole,`MLCH-C010`,`Mislocated Hole Case Solution`,[jj142],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :capBeam,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :tensionFlange,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `The girder to steel capBeam connection must be completed prior to placing and bolting the top flange splice plate.
When the erection procedure was followed the top flange plates were placed and misfit occurred between bolt holes.
1) A shim plate between the girder and capBeam may be used, 
or 2) the top flange splice plate holes may be reamed.
If the holes were reamed then install hardened washers over the oversized holes in the outer ply and tighten the bolts.`,
  `Case #JJ142:
Description of Error: In order to assure that a full contact friction/moment connection is made between the girders and steel capbeam, 
without introducing residual stresses into the joint, 
the girder to steel capbeam connection must be completed prior to placing and bolting the top flange splice plate. 
The erection procedure was followed at the two locations mentioned. When the top flange splice plates were placed, 
misfit occurred between the bolt holes of the top flange splice plates, steel capbeam, and girders. 
Solution Recommended: These misfits may be resolved by one of the following methods:
1. Provide a shim plate between one of the girders and the steel capbeam.
2. "fit-up" the top flange splice plate to the steel capbeam.  
Then, ream the top flange splice plate to girder holes. 
Install hardened washers over the oversized holes in the outer ply and tighten the bolts. 
No bolt holes shall exceed 1 1/16" in diameter.
3. Provide a new top flange splice plate.
In all cases, the girder to steel capbeam connection must be finalized prior to placing and inserting bolts in the top flange splice plate.
Angle A varies from 90 00'00.0" to 8951'58.5" depending on girder.`
).

% Solution 11

caseSolution(mislocatedHole_11,mislocatedHole,`MLCH-C011`,`Mislocated Hole Case Solution`,[],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :bearingStiffener,
    attachMemberType                           :plateGirder,
    errorMemberLocation                        :bearing,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsNumberWithErrors                :1,
    holeDetailsNumberInGrouping                :1,
    holeDetailsActualHoleDiameter              :2.5,
    holeDetailsSpecifiedHoleDiameter           :2.5,
    mislocatedHoleDistanceCorrectLocation      :2.75,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Hole for earthquake restrainer was drilled wrong for all stiffeners at the abutment at the right end of the bridge.Leave the member as is.`,
  `Case #DL123:
   Description of Error: Dimension from top down to center of 2 1/2" dia. hole for earthquake restrainer should have been 2'-3. 
It was drilled at 2'-1 1/4" for all stiffeners at the abutment at the right end of the bridge.
   Solution Recommended: It's OK, if we send a letter to the contractor and they forward the letter to the state.`
).

% Solution 12

caseSolution(mislocatedHole_12,mislocatedHole,`MLCH-C012`,`Mislocated Hole Case Solution`,[],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :intermediateStiffener,
    attachMemberType                           :plateGirder,
    errorMemberLocation                        :boltedConnection,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    mislocatedHoleDistanceCorrectLocation      :0.125,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:true,
    mislocatedHoleIntersectionNewPosition      :false],
  `The of holes on the intermediate stiffeners were mispunched.
The plates need to be replaced.Some of the plates were saved by reaming oversized holes.`,
  `Case #DL125:
Description of Error: 240 plates were punched with the rows of holes approximately 1/8" out of line.
Solution Recommended: Most State DOTs allow oversize holes in stiffeners and/or diaphragm. 
If mislocation distance is small enough, ream oversize holes. 
If mislocation distance is too large or if oversize holes are not allowed, make new plates. 
In actual case 140 plates were reamed and used while 100 plates were remade.`
).

% Solution 13

caseSolution(mislocatedHole_13,mislocatedHole,`MLCH-C013`,`Mislocated Hole Case Solution`,[mg101],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :boxGirder,
    attachMemberType                           :boxGirder,
    errorMemberLocation                        :compressionFlange,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDetailsNumberWithErrors                :6,
    holeDetailsNumberInGrouping                :16,
    holeDetailsActualHoleDiameter              :1.25,
    holeDetailsPartDrilled                     :false,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :true,
    mislocatedHoleSpecifiedHolePatternCorrect  :false,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `Holes were misdrilled in the bottom flange of the box girder.
Three of the holes are to be filled with weld material per section 3.7.7.2 of AWS D1.1-88.
The other holes may be filled with bolts.`,
  `Case #MG101:
Description of Error: The 1 1/4" holes are supposed to be at the abutment end of bottom flange plate, 
but were drilled at field splice by mistake. The 1" holes (E, F) are also extraneous. 
The 8 smaller holes at the splice attach temp. 
field erection channels and are later filled with 7/8" bolts.
Solution Recommended: 1.) Fill A, B & C with weld material in compliance with section 3.7.7 (2) of AWS D1.1-88. 
A repair welding procedure specification is to be generated and submitted for review before commencing the repair. 
The commentary to AWS Section 3.7.7 may be of help in establishing an acceptable repair procedure. 
2) Fill D, E, F, G, & H with bolts. 
3) Remainder use as intended for erection aid devices and fill with 7/8" bolts. 
(see case 'MLCH-C005' for following error on same member)`
).

% Solution 14

caseSolution(mislocatedHole_14,mislocatedHole,`MLCH-C014`,`Mislocated Hole Case Solution`,[fb161],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    attachMemberType                           :intermediateStiffener,
    errorMemberLocation                        :stiffenerAttachment,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    holeDistanceFromIntersectingMember         :1,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :false,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :true,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleIntersectionNewPosition      :false],
  `The top flange plate holes were drilled too close to the stiffener.
There is interference between the stiffener and the hole for the splice plate.
Clip the top of the stiffener to allow room for access to the bolt.`,
  `Case #FB161:
Description of Error: Due to a detailing error, three girders have top flange splice plate holes drilled too close 
to the stiffener bar at extension dimension 5'-6 1/2" to allow bolt access. 
The stiffener is located at 5'-6 1/2" and the hole for the splice plate is at 5'-7 1/2" 
which results in a 1/4" interference.
Solution Recommended: To clip the stiffener bars.`
).

% Solution 15

caseSolution(mislocatedHole_15,mislocatedHole,`MLCH-C015`,`Mislocated Hole Case Solution`,[],success,
  [ bridgeType                                 :plateGirder,
    errorMemberType                            :plateGirder,
    attachMemberType                           :splicePlate,
    errorMemberLocation                        :tensionFlange,
    errorMemberClass                           :primary,
    attachMemberClass                          :primary,
    holeDetailsType                            :circular,
    mislocatedHoleIncorrectFlange              :false,
    mislocatedHoleReinforcingSteelHole         :false,
    mislocatedHoleAdditionalRowHolesDrilled    :true,
    mislocatedHoleEdgeEndDistanceSpecification :true,
    mislocatedHoleIntersectionCurrentPosition  :false,
    mislocatedHoleSpecifiedHolePatternCorrect  :true,
    mislocatedHoleInterfereWithSpecifiedPattern:false,
    mislocatedHoleIntersectionNewPosition      :false],
  `An additional row of holes were drilled in the top splice plate connection.Fill the extra holes with bolts to correct the problem.`,
`Description of Error: The fabricator drilled an extra row of holes. (18 are required and 19 were drilled)
Solution Recommended: Bolts can be used to fill the holes to correct the problem.`
).

