/*----------------------------------------------------------*/
/*  KNBCNAGS.PL - Nicks & Gouges Case Knowledge             */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Weights                                         */
/*                                                          */
/*----------------------------------------------------------*/
feature_weights(nicksGouges,
  [
    bridgeType                      :0.5,
    errorMemberType                 :0.6,
    attachMemberType                :0.5,
    errorMemberLocation             :0.6,
    errorMemberClass                :0.3,
    attachMemberClass               :0.3,
    nickGougeType                   :1.0,
    nickGougeDepth                  :0.5*continuous_feature_eval(1),
    nickGougeLength                 :0.5*continuous_feature_eval(5),
    errorMemberActualThickness      :0.5*continuous_feature_eval(3),
    stressErrorMemberType           :0.6,
    stressErrorMemberLevel          :0.8,
    errorMemberActualEdgeType       :0.4,
    nickGougeReductionOfArea        :0.8,
    nickGougeNumberNearLocation     :0.5,
    nickGougePerpendicularToBoltHole:1.0,
    errorMemberActualWidth          :0.4*continuous_feature_eval(20),
    errorMemberDesignWidth          :0.4*continuous_feature_eval(20),
    errorMemberActualLength         :0.4*continuous_feature_eval(1000),
    errorMemberDesignLength         :0.4*continuous_feature_eval(1000)
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Feature Units (lists features needing units conversion) */
/*                                                          */
/*----------------------------------------------------------*/
feature_units(nicksGouges,
  [
    nickGougeDepth,
    nickGougeLength,
    errorMemberActualThickness,
    errorMemberActualWidth,
    errorMemberDesignWidth,
    errorMemberActualLength,
    errorMemberDesignLength
  ]
).


/*----------------------------------------------------------*/
/*                                                          */
/*  Cases                                                   */
/*                                                          */
/*----------------------------------------------------------*/

% Solution 1
caseSolution(nicksGouges_1,nicksGouges,`NAGS-C001`,`Nicks & Gouges Case Solution`,[mg1631],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :splicePlate,
    attachMemberType                :plateGirder,
    errorMemberLocation             :boltedConnection,
    errorMemberClass                :primary,
    attachMemberClass               :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.125,
    nickGougePerpendicularToBoltHole:true
  ],
  `The inside of the hole was gouged in two places.
The gouges in the bolt hole may be removed by drilling out the hole in the plate as well as in web.
Use a larger bolt to fill the hole.
Be sure to check new edge and end distance.`,
`Case #MG163:
Description of Error: A flange gouge at a bolt hole on the outside row 6th from the bottom on the end plate of a girder. 
The inside of the hole was gouged in two places approximately 1/8" deep. The girder end plate connects to a box girder web.
Solution Recommended: The gouges in the 6th bolt hole in the girder  may be removed by drilling out the hole to 1 1/16" 
as well as the corresponding box web hole. A 1" bolt will be used to fill it. 
`
).

% Solution 2
caseSolution(nicksGouges_2,nicksGouges,`NAGS-C002`,`Nicks & Gouges Case Solution`,[mg1632],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :splicePlate,
    attachMemberType                :plateGirder,
    errorMemberLocation             :gussetPlate,
    errorMemberClass                :primary,
    attachMemberClass               :primary,
    nickGougeType                   :surface,
    nickGougeDepth                  :0.25,
    nickGougeReductionOfArea        :small,
    nickGougeNumberNearLocation     :2,
    nickGougePerpendicularToBoltHole:false
  ],
  `There are flame gouges on the plate.
The gouges may be removed by grinding out the gouges filling with weld material grinding the
weld smooth and then UT testing the area.`,
`Case #MG163:
Description of Error: A flange gouge at a bolt hole on the outside row 6th from the bottom on the end plate of a girder. 
The inside of the hole was gouged in two places approximately 1/8" deep. The girder end plate connects to a box girder web.
Solution Recommended: The " deep gouge near the 6th bolt hole may be removed by grinding, welding, 
grinding the weld and UTing the area. 
`
).

% Solution 3
caseSolution(nicksGouges_3,nicksGouges,`NAGS-C003`,`Nicks & Gouges Case Solution`,[fb157],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :web,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeLength                 :2.625,
    errorMemberActualThickness      :0.4375,
    nickGougeReductionOfArea        :moderate
  ],
  `There are burn gouges at the top and bottom of web from cutting copes.
Grind 60 degree bevel 1/4 in. deep on web repair area.
Attach run off bars by tacking in weld groove.
Preheat and weld first side per approved weld procedure.
Back gouge second side to sound weld metal.
Weld second side per approved procedure.
Remove run off bars by air-arc gouge and grind 1 in. radius per shop drawings.
RT weld repair area per contract spec.`,
`Case #FB157:
Description of Error: Burn gouges in top and bottom web from cutting copes.
Solution Recommended: 1) Grind 60 degree bevel, 1/4" deep on web repair area's. 
2) Attach run off bars by tacking in weld grove (do not tack to parent material). 
3) Preheat and weld 1st side per approved weld procudure. 
4) Back gouge 2nd side to sound weld metal. 
5) Weld 2nd side per approved weld procudure. 
6) Remove run off bars by air-arc gouge and grind 1" radius per shop drawings. 
7) RT weld repair area's per contract spec.
`
).

% Solution 4
caseSolution(nicksGouges_4,nicksGouges,`NAGS-C004`,`Nicks & Gouges Case Solution`,[fb156],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :tensionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.375,
    stressErrorMemberType           :tension,
    nickGougeReductionOfArea        :moderate,
    nickGougeNumberNearLocation     :2,
    errorMemberActualWidth          :12.25,
    errorMemberDesignWidth          :12.25
  ],
  `The bottom flange has burn gouges on both edges across from each other.
Grind the defect area to remove any slag or dross remaining from the cutting operation.
Preheat gouged area to applicable temperature.
Weld gouged area with approved weld procedure with electrodes no great that 5/32 in. diameter.
Grind weld flush with base metal.
Finished and ground repair - shall be UT inspected.`,
`Case #FB156:
Description of Error: The bottom flange for a girder has burn gouges on the edges 4'-8" from the right end. 
The gouges are on both edges and across from each other.
Solution Recommended: 1) Grind defect area to remove any slag or dross remaining from the cutting operation. 
2) Preheat gouged area to applicable temperature. 
3) Weld gouged area with approved weld procedure with electrodes no greater than 5/32" diameter. 
4) Grind weld flush with base metal. 5) Finished and ground repair shall be UT inspected.
`
).

% Solution 5
caseSolution(nicksGouges_5,nicksGouges,`NAGS-C005`,`Nicks & Gouges Case Solution`,[],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :tensionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.5,
    stressErrorMemberType           :tension,
    stressErrorMemberLevel          :high,
    nickGougeReductionOfArea        :moderate
  ],
  `The bottom tension flange has a deep burn gouge.
Because the gouge is deep and the tension flange is in a highly stressed area of the bridge the girder is rejected.`,
`Case #JJ149:
Description of Error: Plate is the bottom tension flange of the girder and has a 1/2" deep burn gouge in the edge.
Solution Recommended: Since girder is in a highly stressed area of the bridge, 
plate must be replaced. This case arose on a job where the quantity of burn gouges was exccessive.
`
).

% Solution 6
caseSolution(nicksGouges_6,nicksGouges,`NAGS-C006`,`Nicks & Gouges Case Solution`,[jj141],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :compressionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.625,
    nickGougeReductionOfArea        :moderate,
    nickGougeNumberNearLocation     :2,
    errorMemberActualWidth          :12.1875,
    errorMemberDesignWidth          :12.1875
  ],
  `The top flanges have burn gouges on both edges of the flange across from each other.
Cut the plate past the burn gouges.
Reverse the ends and 100% butt weld the plate.
The butt weld is to be radiographed 100%.`,
`Case #JJ141:
Description of Error: Top flanges for 3 girders K, L and M have gouges on their edges at extension dimension 8'-5. 
The gouges are on both edges of the flanges and across from each other.
Solution Recommended: Allow a cut, reverse the ends, butt pieces together and reweld, 
then 100% radio graph butt weld. There is sufficient material fit. 
Trim off gouge material at end of piece when final welding is complete.
`
).

% Solution 7
caseSolution(nicksGouges_7,nicksGouges,`NAGS-C007`,`Nicks & Gouges Case Solution`,[jj1412],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :web,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.5,
    nickGougeLength                 :4,
    errorMemberActualThickness      :0.375,
    nickGougeReductionOfArea        :moderate,
    nickGougeNumberNearLocation     :4
  ],
  `The web has four burn gouges on the bottom edge.
Make two cuts one on each side of the four gouges.
Weld in new material in its place.`,
`Case #JJ141: 
Description of Error: Girder  web plate has 4 burn gouges on the bottom edge. These gouges range from " to " deep.
Solution Recommended: Since this is a web, there is no extra width. Make two cuts and add new material. Radiograph butt welds 100%.
`
).

% Solution 8
caseSolution(nicksGouges_8,nicksGouges,`NAGS-C008`,`Nicks & Gouges Case Solution`,[mg106],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :compressionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeDepth                  :0.125,
    nickGougeReductionOfArea        :verySmall,
    nickGougeNumberNearLocation     :4,
    errorMemberActualWidth          :18.125,
    errorMemberDesignWidth          :18
  ],
  `Burn gouges appear along the edge of the top flange.
The plate is actually wider than it is specified to be.
By grinding the plate down to its specified width the gouges will be taken care of.`,
`Case # MG106:
Description of Error: Girder top flange, 20'-10 from right end, has an area of burn gouges 11 inches long and up to 3/8 inches deep.   
Solution Recommended: Grind the 18 1/8" wide plate to the design width of 18" in the area of the burn gouges. 
The remainder of the gouges shall be repaired by welding according to Fabrication Correction Procedure: Repair of Flame Cut Edges. 
The welds shall be ground smooth and the repairs ultrasonic tested.
`
).

% Solution 9
caseSolution(nicksGouges_9,nicksGouges,`NAGS-C009`,`Nicks & Gouges Case Solution`,[tf212],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :web,
    errorMemberClass                :primary,
    nickGougeType                   :surface,
    nickGougeDepth                  :0.2,
    nickGougeLength                 :4,
    nickGougeReductionOfArea        :small,
    nickGougeNumberNearLocation     :1
  ],
  `The web was damaged in handling while at fabricating plant.
Grind the gouge suitable for MT.
MT repair cavity to assure no defect exists. Preheat.
Using electrode purchased for Fracture Critical Members, repair using approved weld procedure SMAW flat.
Postheat.
Grind repair area and visually inspect.`,
`Case #TF212:
Description of Error: Girder web plate was damaged in handling while at fabricating plant. 
Cavity (gouge) area is located approximately 88 inches from girder end and 3  inches down from top flange.
Solution Recommended: 1) Grind cavity (gouge) suitable for MT. 
2) MT repair cavity to assure no defect exists. 
3) Preheat without interruption until the repair is complete. 
(Preheat / interpass 250 degrees F- 450 degrees F). 
4) Using electrode purchased for Fracture Critical Members, repair using approved weld procedure (SMAW flat). 
5) Postheat for 15 minutes (400 degrees F -500 degrees F). 6) Grind repair area and visually inspect.
`
).

% Solution 10
caseSolution(nicksGouges_10,nicksGouges,`NAGS-C010`,`Nicks & Gouges Case Solution`,[tf215],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :compressionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :surface,
    nickGougeDepth                  :0.25,
    nickGougeReductionOfArea        :small,
    nickGougeNumberNearLocation     :2
  ],
  `The flanges were damaged while contractor was removing an unacceptable section of deck that had been poured.
The damaged areas on the flanges must be ground out smoothly.
The maximum slope for the grinding is to 10 to 1.
The grinding is to be done in the direction of the major stress.
When the repair is complete the areas that have been ground shall be inspected by a DOT materials inspector.
The repair then shall be painted with organic zinc-vinyl paint.`,
`Case #TF215:
Description of Error: The flanges were damaged by the Contractor while he was removing an unacceptable section of deck that had been poured. 
Solution Recommended: 1) The damaged areas on the flanges must be ground out smoothly. 
The maximum slope for the grinding is to be 1" vertical to 10" horizontal. The grinding is to be done in the direction of the major stress 
(i.e.- longitudinally along the girder). A circular grinder may be used if the repair is finished with a belt grinder in the direction of the major stress. 
Notches deeper than " may not be repaired with this procedure without further approval. 
2) When the repair is complete the areas that have been ground shall be inspected by a DOT materials inspector.
After the repair has been approved the ground areas shall be painted with organic zinc-vinyl paint.
`
).

% Solution 11
caseSolution(nicksGouges_11,nicksGouges,`NAGS-C011`,`Nicks & Gouges Case Solution`,[nc506],success,
  [
    bridgeType                      :rolled,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :tensionFlange,
    errorMemberClass                :primary,
    nickGougeType                   :surface,
    nickGougeDepth                  :0.25,
    stressErrorMemberLevel          :high,
    nickGougeReductionOfArea        :excessive
  ],
  `When removing the concrete slab the cover plate had been cut with a saw.
After reviewing design calculations to was determined that the cover plate was not necessary for the 
composite section to carry the design loads.
Because there is potential for fatigue cracks to develop at the cut, the cut needs to be ground at a 16 to 1 transition.
Careful attention needs to be taken not to grind below the cut.`,
`Case #NC506:
Description of Error: A cover plate had been cut with a saw during the removal of the concrete slab. 
Another cut was discovered at a second location during inspection of the cover plates for weld cracking. 
The saw cuts were measured in the field.
Solution Recommended: Grind a 16:1 transition at both locations. 
Do not grind below saw cut depth. It is also recommended that future routine bridge inspection include observation of each saw cut location.
`
).

% Solution 12
caseSolution(nicksGouges_12,nicksGouges,`NAGS-C012`,`Nicks & Gouges Case Solution`,[],success,
  [
    errorMemberType                 :plateGirder,
    errorMemberLocation             :web,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeLength                 :25,
    stressErrorMemberLevel          :medium,
    nickGougeReductionOfArea        :moderate
  ],
  `The web cutter mis-tracked causing torch to cut into web top.
Remove the web area that was gouged.
Remove all slag by grinding.
Use the area that was cut out as a template for a web slug.
Weld the web slug into the cut out area.
When web slug is welded into position grind all weld flush.
Torch cut the web slug about 1/4 in. above the top of the web.
Remove the balance of the web slug to flush with the top of web plate by grinding.
100 percent RT examine.`,
`Case # (no original case found)
Description of Error: The web cutter mis-tracked causing torch to cut into web top.
Solution Recommended: 1) Remove the web area that was gouged. 
2) Remove all slag by grinding.
3) Use the area that was cut out as a template for a web slug.
4) Weld the web slug into the cut out area.
5) When web slug is welded into position grind all weld flush.
6) Torch cut the web slug about 1/4 in. above the top of the web.
7) Remove the balance of the web slug to flush with the top of web plate by grinding.
8) 100 percent RT examine.
`
).

% Solution 13
caseSolution(nicksGouges_13,nicksGouges,`NAGS-C013`,`Nicks & Gouges Case Solution`,[nc511],success,
  [
    bridgeType                      :plateGirder,
    errorMemberType                 :plateGirder,
    errorMemberLocation             :web,
    errorMemberClass                :primary,
    nickGougeType                   :edge,
    nickGougeLength                 :1.75,
    errorMemberActualThickness      :0.5,
    nickGougeReductionOfArea        :small
  ],
  `The web burning machine jumped its track and burned into the webs.
Weld and grind the gouges and ultrasonic test the areas for soundness.`,
`Case #NC511:
Description of Error: A fabrication error occurred when web burning machine jumped its track and burned into the webs. 
The webs affected are for girders A2 and B2. 
Solution Recommended: Weld and grind the gouges and ultrasonic test the areas for soundness.
`
).

