/*----------------------------------------------------------*/
/*  KNBRMCTM.PL - Miscut Member Rule Knowledge              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/

:- op(1100,fx,(if)),
   op(950,xfx,then),
   op(925,xfy,and),
   op(925,xfy,or).


/*----------------------------------------------------------*/
/*  Production Rules                                        */
/*----------------------------------------------------------*/

:- dynamic ruleSolution/1.

% Rule: 1.1
if errorMemberClass(fractureCritical)
  then ruleSolution(miscutMember_1).

% Rule: 1.2
if attachMemberClass(fractureCritical)
  then ruleSolution(miscutMember_1).

% Rule: 2.1
if unitsType(english)
  and errorMemberType(capBeam)
  and errorMemberLocation(compressionFlange)
  and errorMemberDesignWidth(ErrorMemberDesignWidth)
  and errorMemberActualWidth(ErrorMemberActualWidth)
  and ErrorMemberDesignWidth - ErrorMemberActualWidth =< 0.375
  then ruleSolution(miscutMember_2).

% Rule: 2.1m
if unitsType(metric)
  and errorMemberType(capBeam)
  and errorMemberLocation(compressionFlange)
  and errorMemberDesignWidth(ErrorMemberDesignWidth)
  and errorMemberActualWidth(ErrorMemberActualWidth)
  and ErrorMemberDesignWidth - ErrorMemberActualWidth =< 10
  then ruleSolution(miscutMember_2).

% Rule: 3.1
if unitsType(english)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength - ErrorMemberActualLength < 0.5
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_3).

% Rule: 3.1m
if unitsType(metric)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength - ErrorMemberActualLength < 13
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_3).

% Rule: 4.1
if unitsType(english)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength - ErrorMemberActualLength >= 0.5
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_4).

% Rule: 4.1m
if unitsType(metric)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength - ErrorMemberActualLength >= 13
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_4).

% Rule: 5.1
if unitsType(english)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberActualLength - ErrorMemberDesignLength < 0.5
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_5).

% Rule: 5.1m
if unitsType(metric)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberActualLength - ErrorMemberDesignLength < 13
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_5).

% Rule: 6.1
if unitsType(english)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberActualLength - ErrorMemberDesignLength >= 0.5
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_6).

% Rule: 6.1m
if unitsType(metric)
  and errorMemberType(intermediateStiffener)
  and attachMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberActualLength - ErrorMemberDesignLength >= 13
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_6).

% Rule: 7.1
if errorMemberType(plateGirder)
  and errorMemberLocation(tensionFlange)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_7).

% Rule: 7.2
if errorMemberType(plateGirder)
  and errorMemberLocation(compressionFlange)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and errorStageErrorMemberAttached(true)
  then ruleSolution(miscutMember_7).

% Rule: 8.1
if errorMemberType(plateGirder)
  and errorMemberLocation(tensionFlange)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and errorStageErrorMemberAttached(false)
  then ruleSolution(miscutMember_8).

% Rule: 8.2
if errorMemberType(plateGirder)
  and errorMemberLocation(compressionFlange)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and errorStageErrorMemberAttached(false)
  then ruleSolution(miscutMember_8).

% Rule: 9.1
if errorMemberType(plateGirder)
  and errorMemberLocation(tensionFlange)
  and miscutMemberErrorOccursAt(end)
  and miscutMemberActualClipped(true)
  and miscutMemberSpecifiedClipped(false)
  then ruleSolution(miscutMember_9).

% Rule: 9.2
if errorMemberType(plateGirder)
  and errorMemberLocation(compressionFlange)
  and miscutMemberErrorOccursAt(end)
  and miscutMemberActualClipped(true)
  and  miscutMemberSpecifiedClipped(false)
  then ruleSolution(miscutMember_9).

% Rule: 10.1
if unitsType(english)
  and errorMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and ErrorMemberDesignLength - ErrorMemberActualLength < 1.5
  then ruleSolution(miscutMember_10).

% Rule: 10.1m
if unitsType(metric)
  and errorMemberType(plateGirder)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  and ErrorMemberDesignLength - ErrorMemberActualLength < 38
  then ruleSolution(miscutMember_10).

% Rule: 11.1
if errorMemberType(intermediateStiffener)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  then ruleSolution(miscutMember_11).

% Rule: 11.2
if errorMemberType(bearingStiffener)
  and errorMemberDesignLength(ErrorMemberDesignLength)
  and errorMemberActualLength(ErrorMemberActualLength)
  and ErrorMemberDesignLength =\= ErrorMemberActualLength
  then ruleSolution(miscutMember_11).

% Rule: 12.1
if errorMemberType(intermediateStiffener)
  and miscutMemberSpecifiedClipped(true)
  and miscutMemberClippedDimensionsCorrect(false)
  then ruleSolution(miscutMember_12).

% Rule: 12.2
if errorMemberType(bearingStiffener)
  and miscutMemberSpecifiedClipped(true)
  and miscutMemberClippedDimensionsCorrect(false)
  then ruleSolution(miscutMember_12).

% Rule: 13.1
if unitsType(english)
  and errorMemberType(plateGirder)
  and miscutMemberSpecifiedSweep(MiscutMemberSpecifiedSweep)
  and miscutMemberActualSweep(MiscutMemberActualSweep)
  and MiscutMemberSpecifiedSweep =\= MiscutMemberActualSweep
  and MiscutMemberSpecifiedSweep - MiscutMemberActualSweep =< 6
  then ruleSolution(miscutMember_13).

% Rule: 13.1m
if unitsType(metric)
  and errorMemberType(plateGirder)
  and miscutMemberSpecifiedSweep(MiscutMemberSpecifiedSweep)
  and miscutMemberActualSweep(MiscutMemberActualSweep)
  and MiscutMemberSpecifiedSweep =\= MiscutMemberActualSweep
  and MiscutMemberSpecifiedSweep - MiscutMemberActualSweep =< 150
  then ruleSolution(miscutMember_13).

% Rule: 14.1
if errorMemberType(diaphragmBrace)
  and miscutMemberErrorOccursAt(end)
  then ruleSolution(miscutMember_14).

% Rule: 15.1
if errorMemberType(plateGirder)
  and errorMemberLocation(compressionFlange)
  and errorStageErrorMemberAttached(true)
  and miscutMemberErrorOccursAt(end)
  and miscutMemberSpecifiedClipped(true)
  and miscutMemberActualClipped(true)
  and miscutMemberClippedDimensionsCorrect(false)
  then ruleSolution(miscutMember_15).

% Rule: 15.2
if errorMemberType(plateGirder)
  and errorMemberLocation(tensionFlange)
  and errorStageErrorMemberAttached(true)
  and miscutMemberErrorOccursAt(end)
  and miscutMemberSpecifiedClipped(true)
  and miscutMemberActualClipped(true)
  and miscutMemberClippedDimensionsCorrect(false)
  then ruleSolution(miscutMember_15).

% Rule: 16.1
if errorMemberType(plateGirder)
  and attachMemberType(splicePlate)
  and errorMemberLocation(web)
  and errorMemberDesignWidth(ErrorMemberDesignWidth)
  and errorMemberActualWidth(ErrorMemberActualWidth)
  and ErrorMemberDesignWidth > ErrorMemberActualWidth
  then ruleSolution(miscutMember_16).

% Rule: 17.1
if errorMemberType(rocker)
  and attachMemberType(plateGirder)
  then ruleSolution(miscutMember_17).


/*----------------------------------------------------------*/
/*  Solutions                                               */
/*----------------------------------------------------------*/

% Solution 1
ruleSolution(miscutMember_1,miscutMember,`MCTM-R001`,`Miscut Member Rule Solution`,[],
`Miscut member error has occurred.

REPAIR:

Member or attached member is classified as fracture critical member. Replacement of member may be necessary.
Rerun program listing members as primary to obtain standard repair ruleSolution.
`).

% Solution 2
ruleSolution(miscutMember_2,miscutMember,`MCTM-R002`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Member type specified will allow a reduction of width. Attach flange plate flush with attached member on one end.
At flush mounting attach with single bevel full penetration weld. Use backing bar at weld site.
`).

% Solution 3
ruleSolution(miscutMember_3,miscutMember,`MCTM-R003`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has already been attached. Member dimensions is short of specified dimension.
Build up short member with weld grind. Perform ultrasonic test on member.
`).

% Solution 4
ruleSolution(miscutMember_4,miscutMember,`MCTM-R004`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has already been attached. Member dimensions is short of specified dimension.
Remove member from attached member by air-arc and grind smooth. Fabricate new member and attach per design specifications.
`).

% Solution 5
ruleSolution(miscutMember_5,miscutMember,`MCTM-R005`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has already been attached. Miscut member is longer than design specifications. Cut member to design dimensions.
`).

% Solution 6
ruleSolution(miscutMember_6,miscutMember,`MCTM-R006`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has already been attached. Miscut member is longer than design specifications.
Remove member from attached member by air-arc and grind smooth. Fabricate new member and attach per design specifications.
`).

% Solution 7
ruleSolution(miscutMember_7,miscutMember,`MCTM-R007`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has already been attached. Remove error member from attached member. Correct dimensions of member by
removing material or splice additional material on if short. NDT testing required by radiograph.
`).

% Solution 8
ruleSolution(miscutMember_8,miscutMember,`MCTM-R008`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has not been attached. Check with Design for allowable repair.
Check to see if error will be allowable in flange splice. If so, get splice repair of weldment out of splice.

Other possible repair:
Correct dimensions of member by removing material or splice additional material on if short.

NDT testing required by radiograph on any splice.
`).

% Solution 9
ruleSolution(miscutMember_9,miscutMember,`MCTM-R009`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Cut off plate a minimum of 6" (150mm) beyond last splice hole (if splice holes exist) or beyond edge of miscut area.
Weld new plate on in place of removed piece. Use full penetration butt weld. NDT testing required by radiograph.
`).

% Solution 10
ruleSolution(miscutMember_10,miscutMember,`MCTM-R010`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Error occurs on plate girder. Check to see if attached girder can be lengthened to allow compensation for shortness
of error member. If allowable leave member as is. Otherwise replace member with short dimensions.

Rather than replacing complete member check to see if cutting member at non critical location will allow splice of member.

Check all welds on member with NDT testing. Radiograph or ultrasonic.
`).

% Solution 11
ruleSolution(miscutMember_11,miscutMember,`MCTM-R011`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Miscut member has occurred. Fabricate new member and attach per design specifications.

If miscut member is stiffener: Alternative repair may be allowed of:

1.  building up with weld material
2.  trimming stiffener to correct dimensions
3.  use full penetration weld to fill gap

Check with designer to see if ruleSolution is allowable. Solution dependent on attached or not attached after error found.
`).

% Solution 12
ruleSolution(miscutMember_12,miscutMember,`MCTM-R012`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred during fabrication.

REPAIR:

Stiffeners have been clipped to incorrect dimensions.

If actual dimensions are within 1/2" (13mm) of specified dimensions then leave as fabricated.

If actual dimensions are not within 1/2" (13mm) of specified dimensions then replace stiffeners with new stiffeners.
`).

% Solution 13
ruleSolution(miscutMember_13,miscutMember,`MCTM-R013`,`Miscut Member Rule Solution`,[],
`Girder sweep does not meet specifications. Due to width limitations specified sweep could not be burned
into member.

REPAIR:

Follow procedure outlined in KDOT Special Provisions Section 702 for heat curved rolled beams and welded plate girders.
Locate the heats working from center line of girder and heat at 60" (1500mm) increments along length of member.
`).

% Solution 14
ruleSolution(miscutMember_14,miscutMember,`MCTM-R014`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred on diaphragm or brace.

REPAIR:

If member was stripped on wrong side: cut correct side and attach tabs cut off to side that was incorrectly cut.
Check all welds with Magnetic Particle test per AWS specifications.

If full member was cut short: replace member.
`).

% Solution 15
ruleSolution(miscutMember_15,miscutMember,`MCTM-R015`,`Miscut Member Rule Solution`,[],
`Miscut member has occurred on flange. Flange was clipped on incorrect side. Flange has been attached to web.

REPAIR:

If member was clipped on wrong side: cut correct side. Leave member as is.

If both sides have been clipped when specifications only called for one side: leave as is.
`).

% Solution 16
ruleSolution(miscutMember_16,miscutMember,`MCTM-R016`,`Miscut Member Rule Solution`,[],
`Miscut Member has occurred during fabrication.

REPAIR:

Miscut member has been cut narrow. If allowable leave member as is.  If not, consider use of fill plates to make
up connections. Otherwise replace member.
`).

% Solution 17
ruleSolution(miscutMember_17,miscutMember,`MCTM-R017`,`Miscut Member Rule Solution`,[],
`Miscut Member has occurred during fabrication.

REPAIR:

Miscut member has not been attached. Check with design for allowable repair.
Check to see if altering length or thickness of rocker plates is acceptable to the design.
`).

