/********************************************************
 * File for supplied ProWeb overlay file (PROWEB.OVL).  *
 * This file forms part of the Supplied ProWeb Overlay. *
 * This file defines ProWeb's main goal and post goal.  *
 ********************************************************/

/********************************************************
 * To make the overlay, execute the following:          *
 * ?- ensure_loaded(system(proweb)).                    *
 * ?- ensure_loaded('c:\inetpub\proweb\system\proweb'). *
 * ?- procgi_make('c:\inetpub\proweb\proweb.ovl').      *
 ********************************************************/

:-      multifile( proweb_page         / 2 ).
:-      multifile( proweb_form         / 2 ).
:-      multifile( proweb_question     / 2 ).
:-      multifile( proweb_friends      / 2 ).

proweb_startup :-
  proweb_dynamic( ovl_flag/1 ),
  proweb_setting( main_goal,  ovl_main  ),
  proweb_setting( post_goal,  ovl_post  ),
  proweb_setting( path_temp,  temp      ),
  proweb_setting( alias_data, '/proweb' ),
  create_temp_directory.

create_temp_directory :-
  absolute_file_name( prolog('temp'), TempDir ),
  dir( TempDir, 16'00000010, Answer ),
  (  Answer = []
  -> mkdir(TempDir)
  ;  true
  ).

ovl_main :-
  sysops,
  proweb_operators,
  html_operators,
  absolute_file_name( examples('pw_demo.pl'), File ),
  file( File, -1, Status ),
  (  Status = 1
  -> ensure_loaded( examples('pw_demo.pl') ),
     main_goal
  ;  proweb_send_form( ovl_error_form(File) )
  ).

ovl_post :-
  sysops,
  proweb_operators,
  html_operators,
  absolute_file_name( examples('pw_demo.pl'), File ),
  file( File, -1, Status ),
  (  Status = 1
  -> ensure_loaded( examples('pw_demo.pl') ),
     ( def(post_goal,0,_),
       post_goal
     ; assert_diagnosis_flags,
       (  proweb_call(ovl_flag(_))
       -> proweb_resend_form(ovl_diagnosis_form)
       ;  true
       )
     )
  ;  proweb_send_form( ovl_error_form(File) )
  ).

assert_diagnosis_flags :-
  (  proweb_returned_input(ovl_console,on)
  -> proweb_assert( ovl_flag(console) )
  ;  true
  ),
  (  proweb_returned_input(ovl_listing,on)
  -> proweb_assert( ovl_flag(listing) )
  ;  true
  ),
  (  proweb_returned_input(ovl_statistics,on)
  -> proweb_assert( ovl_flag(statistics) )
  ;  true
  ),
  (  proweb_returned_input(ovl_proweb_settings,on)
  -> proweb_assert( ovl_flag(proweb_settings) )
  ;  true
  ).

proweb_page( ovl_error_form(_), [] ).

proweb_form( ovl_diagnosis_form,
             [ hr,
               unencoded @ Console,
               unencoded @ Listing,
               unencoded @ ProWebSettings,
               unencoded @ Statistics
             ]
           ) :-
  (  proweb_call(ovl_flag(console))
  -> wtext((1,1),Contents),
     ( html_print(h2),
       write(`Console`),
       html_print(/h2),
       html_print(pre),
       write(Contents),
       html_print(/pre)
     ) ~> Console
  ;  Console = ``
  ),
  (  proweb_call( ovl_flag(listing) )
  -> ( html_print(h2),
       write(`Listing`),
       html_print(/h2),
       html_print(pre),
       listing,
       html_print(/pre)
     ) ~> Listing
  ;  Listing = ``
  ),
  (  proweb_call( ovl_flag(proweb_settings) )
  -> ( html_print(h2),
       write(`ProWeb Settings`),
       html_print(/h2),
       html_print(ul),
       ovl_proweb_settings,
       html_print(/ul)
     ) ~> ProWebSettings
  ;  ProWebSettings = ``
  ),
  (  proweb_call( ovl_flag(statistics) )
  -> ( html_print(h2),
       write(`Statistics`),
       html_print(/h2),
       html_print(pre),
       statistics,
       html_print(/pre)
     ) ~> Statistics
  ;  Statistics = ``
  ).

ovl_proweb_settings :-
  findall( (Setting = Value),
           proweb_setting( Setting, Value ),
           Settings
         ),
  forall( member(X, Settings),
          ( html_print(li),
            write(X)
          )
        ).

proweb_form( ovl_error_form(File),
             [ h1,
               img(src='images/error.gif'),
               ` ProWeb Error`,
               /h1,
               h2,
               `Sorry, ProWeb is unable to find the following file:`,
               br,
               i,
               File,
               /i,
               /h2 
             ]
           ).

proweb_friends( _, ovl_diagnosis_form ).

