/********************************************************
 * To make the overlay, execute the following:          *
 * ?- ensure_loaded(system(proweb)).                    *
 * ?- ensure_loaded('c:\inetpub\proweb\system\proweb'). *
 * ?- procgi_make('c:\inetpub\proweb\proweb.ovl').      *
/*
   Proweb Input/Output Example - Written by Rebecca Shalfield
   Note: As written, it is intended to be used in ProWeb's test mode
   -----------------------------------------------------------------

   This example shows how ProWeb handles the input and output of the
   Prolog data types: atoms, LPA strings, integers, floats and lists.

   It is documented in chapter 3 of the ProWeb user guide.
*/
:-      multifile( proweb_page         / 2 ).
:-      multifile( proweb_form         / 2 ).
:-      multifile( proweb_question     / 2 ).

main_goal :-
   proweb_send_form( input_form ),
   proweb_returned_answer( atom_input, AtomInput ),
   type( AtomInput, 3 ),
   proweb_returned_answer( string_input, StringInput ),
   type( StringInput, 4 ),
/*   proweb_returned_answer( integer_input, IntegerInput ),
   type( IntegerInput, 1 ),
   proweb_returned_answer( float_input, FloatInput ),
   type( FloatInput, 2 ),
*/   proweb_returned_answer( atom_list_input, AtomListInput ),
   ( type(AtomListInput,5); type(AtomListInput,6) ),
   proweb_send_form( output_form ).

proweb_page( [ Form|_],
             [ include('head.htm'),
               Title,
               include('body.htm'),
               proweb(Form),
               include('foot.htm')
             ]
           ) :- form_title_file( Form, Title, _ ).

proweb_form( Form, [include(File),Footer] ) :-
  form_title_file( Form, _, File ),
  form_footer( Form, Footer ).




form_title_file( input_form,   `input_form`,    'white.htm' ).
form_title_file( output_form,   `input_form`,    'white.htm' ).
 

form_footer( input_form,
             [  script(language='javascript'),
               unencoded @ '<!-- ',
                           `function validateField(field) {`,
               unencoded @ `  if (field.value=="bbb") {`,
               unencoded @ `    alert("\nMust input all values!");`,
                           `    field.focus(); return( false ) ; } else { return( true ); `,
                           `  }`,
                           `}`,
                           `function validateForm(frm){`,
               unencoded @ `return ( validateField(frm.Q0001) && validateField(frm.Q0002) ) ; }`, 
               unencoded @ ' <!-- End Script -->',
               /script,
              `Please enter an atom: `,
               ?atom_input,
               p,
               `Please enter a string: `,
               ?string_input,
               p,
/*               `Please enter an integer: `,
               ?integer_input,
               p,
               `Please enter a float: `,
               ?float_input,
               p,
*/               `Please select an atom list: `,
               ?atom_list_input,
               p,
               input(type=submit)
             ]
           ).

form_footer( output_form,
             [ `Atom: `,
               AtomOutput,
               p,
               `String: `,
               StringOutput,
               p,
/*               `Integer: `,
               IntegerOutput,
               p,
               `Float: `,
               FloatOutput,
               p,
 */              `Atom List: `,
               verbatim @ AtomListOutput
             ]
           ) :-
  proweb_returned_answer( atom_input,       AtomOutput      ),
  proweb_returned_answer( string_input,     StringOutput    ),
  proweb_returned_answer( integer_input,    IntegerOutput   ),
  proweb_returned_answer( float_input,      FloatOutput     ),
  proweb_returned_answer( atom_list_input,  AtomListOutput  ).

proweb_question( atom_input,
                 [ method  = input,
                   type    = atom,
                   prefill = MyAtom
                 ]
               ) :-
  MyAtom = foo,
  atom( MyAtom ).

proweb_question( string_input,
                 [ method  = input,
                   type    = string,
                   prefill = MyString,
                   cols    = 30
                 ]
               ) :-
  MyString = `Logic Programming Associates`,
  string( MyString).

proweb_question( integer_input,
                 [ method  = input,
                   type    = integer,
                   prefill = MyInteger
                 ]
               ) :-
  MyInteger = 123,
  integer( MyInteger ).

proweb_question( float_input,
                 [ method  = input,
                   type    = number,
                   prefill = MyFloat
                 ]
               ) :-
  MyFloat = 3.6,
  float( MyFloat ).

proweb_question( atom_list_input,
                 [ method  = multibox,
                   type    = atom,
                   select  = MyAtomList,
                   rows    = 5
                 ]
               ) :-
  MyAtomList = [a,b,c,d,e],
  list( MyAtomList ).
