/* ProWeb/ProData Example
   Written by Rebecca Shalfield - 6th April 2000

   This example assumes you have an empty data source
   named 'test'. 
   ---------------------------------------------*/
% procgi_make('c:\inetpub\proweb\proweb.ovl').


:-ensure_loaded(system(proweb)).

:- multifile proweb_page/2.
:- multifile proweb_form/2.
:- multifile proweb_shutdown/0.

delete_trace_log :-
  file( 'c:\inetpub\proweb\temp\trace.log', -1, Status ),
  (  Status = 1
  -> del( 'c:\inetpub\proweb\temp\trace.log' )
  ;  true
  ).

:- delete_trace_log.

main_goal :-
  load_prodata_toolkit,
  check_loading_of_prodata_toolkit,
  initialise_prodata_toolkit,
  % You may replace the data source 'test' with one of your own
  load_datasource( test ),
  create_table( 'Customers', 'DEPTNO NUMBER,DNAME CHAR(14),LOC CHAR(13)' ),
  attach_to_table( customers, `Customers` ),
  db_add_record( customers, [1,'Fred','London'] ),
  db_add_record( customers, [2,'Bill','Paris' ] ),
  db_add_record( customers, [3,'Jack','Rome'  ] ),
  db_tuple( customers, R ),
  proweb_send_unique_form( record_form(R) ).

main_goal :-
  proweb_returned_form( record_form(_) ),
  proweb_send_form( error_form(`Sorry, there are no more records.`) ).

load_prodata_toolkit :-
  ensure_loaded( system(dblink) ),
  !,
  proweb_trace( `COMPLETED: load_prodata_toolkit` ).

load_prodata_toolkit :-
  proweb_trace( `FAILED: load_prodata_toolkit` ).

check_loading_of_prodata_toolkit :-
  (  source_file( db_connect(_), _ )
  -> true
  ;  proweb_send_form(error_form('db_connect/2 not defined'))
  ),
  !,
  proweb_trace( `COMPLETED: check_loading_of_prodata_toolkit` ).

initialise_prodata_toolkit :-
  db_flag( show_db_error, _, off )
  -> proweb_trace( `COMPLETED: initialise_prodata_toolkit` ).

load_datasource( DataSource ) :-
  (  db_connect(DataSource,HDBC)
  -> asserta(hdbc(HDBC))
  ;  ( write(DataSource),
       write(` DATA SOURCE NOT AVAILABLE.<BR>The following data sources are available: `),
       db_get_schema(sources,DataSources),        
       write(DataSources),
       write(`<BR>Try clicking on the 'Repair...' button in the ODBC Administrator.`)
     ) ~> String,
     proweb_send_form(error_form(String))
  ).

create_table( TABLE, SCHEMA ) :-
  (  db_get_schema( user, Tables )
  -> true
  ;  Tables = []
  ), 
  (  member(TABLE,Tables)
  -> true
  ;  db_create_table( TABLE, SCHEMA )
  ).

attach_to_table( PrologName, Table ) :-
  db_get_schema( user, Tables ),
  (  db_external(_,PrologName,Table,_,_)
  -> proweb_trace( `COMPLETED: attach_to_table` )
  ;  (  db_attach( PrologName, Table )
     -> proweb_trace( `COMPLETED: attach_to_table` )
     ;  ( write(Table),
          write(` TABLE NOT AVAILABLE.<BR>The following tables are available: `),
          write(Tables)
        ) ~> String,
        proweb_send_form(error_form(String))
     )
  ).

proweb_page( _, [] ).

proweb_form( record_form(R), [R, input(type=submit)] ).

proweb_form( error_form(Text), unencoded @ Text ). 

proweb_shutdown :-
  db_halt.
