/*----------------------------------------------------------*/
/*  FIXS Dialog Handling Code.pl                            */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/
  
/*----------------------------------------------------------*/
/*                                                          */
/*  Browse Solutions Dialog Functions                       */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Create Browse Solutions LB String                       */
/*----------------------------------------------------------*/
fixsCreateBrowseSolutionsLBString(Id,Type,Desc,Str) :-
  fwrite(s,-10,-1,Id) ~> IdStr,                                 % Create Id string
  fwrite(s,-25,-1,Type) ~> TypeStr,                             % Create Type string
  fwrite(s,-50,-1,Desc) ~> DescStr,                             % Create Description string
  cat([IdStr,` `,TypeStr,` `,DescStr],Str,_).                   % Combine strings to form one string or item


/*----------------------------------------------------------*/
/*  Add Browse Solutions LB Rule Item                       */
/*----------------------------------------------------------*/


 fixsAddBrowseSolutionsLBRuleItem(Solution) :-
  rule_type(Solution,TypeAtom),                                 % Get solution type
  rule_id(Solution,IdStr),                                      % Get solution id
  rule_desc(Solution,DescStr),                                  % Get solution description
  fixsKnowledge(TypeAtom,_,TypeStr),                            % Convert type atom to a type string
  fixsCreateBrowseSolutionsLBString(IdStr,TypeStr,DescStr,Str), % Format listbox string
 atom_string(C,Str),
 assert(browseListStore(C)).



/*----------------------------------------------------------*/
/*  Add Browse Solutions LB Case Item                       */
/*----------------------------------------------------------*/
fixsAddBrowseSolutionsLBCaseItem(Solution) :-
  case_type(Solution,TypeAtom),                                 % Get solution type
  case_id(Solution,IdStr),                                      % Get solution id
  case_desc(Solution,DescStr),                                  % Get solution description
  fixsKnowledge(TypeAtom,_,TypeStr),                            % Convert type atom to a type string
  fixsCreateBrowseSolutionsLBString(IdStr,TypeStr,DescStr,Str), % Format listbox string
 atom_string(C,Str),
 assert(browseListStore(C)).

/*----------------------------------------------------------*/
/*  Set Browse Solutions Solution                           */
/*----------------------------------------------------------*/

/*----------------------------------------------------------*/
/*  Get Browse Solutions LB Item                            */
/*----------------------------------------------------------*/
fixsGetBrowseSolutionsLBItem(BrowseErrorType) :-
 proweb_trace( `Start fixsGetBrowseSolutionsLBItem`),
%  fixsAppPath(Path,_,_),                                        % Get application path
  abortedBDetailStore,
  atom_string(BrowseErrorType,FirstSel),                                      % Convert atom to string
  proweb_trace( FirstSel),
  fixsStringToList(FirstSel,SelList),                           % Convert selection to a list of "words"
  member(Item,SelList,1),                                       % Get selection id from list of "words"
  atom_string(Item,IdStr),                                      % Convert atom to string
  proweb_trace( IdStr),
  ((rule_repair(IdStr,SolutionText),                            % Get rule solution text...
  ActualText=`No actual case description for rulebase !`)
     ;                              
    (case_repair(IdStr,SolutionText),                             % Or get case solution text
      case_actualCaseDescription(IdStr,ActualText))                            % Or get case solution text
   ),
  (rule_details(IdStr,DetailList);                              % Get rule details list...
   case_details(IdStr,DetailList)),                             % Or get case details list
  (DetailList == []                                             % Determine if detail list is empty
    -> Detail = 'fixs-na'                                       % Use default detail
    ; member(Detail,DetailList,1)                               % Use first detail in list
  ),
%  cat([Path,'BMP\',Detail],FileDetail,_),                     % Create file path
%  atom_string(FileDetail,DetailStr),                                % Convert detail name to a string
  proweb_trace( ActualText),
  atom_string(Detail,DetailStr),                                % Convert detail name to a string
  proweb_trace( DetailStr),
  proweb_assert(fixsBrowseDetailItems(IdStr,SolutionText,ActualText,DetailStr)).


/*----------------------------------------------------------*/
/*  Initialize Browse Solutions Dialog                      */
/*----------------------------------------------------------*/
fixsInitBrowseSolutions(ErrorType) :-
 proweb_trace( `Start fixsInitBrowseSolutions`),
  fixsKnowledgeAbolish,                                         % Abolish any previously used knowledge files
  fixsKnowledgeLoad(ErrorType),                                 % Load knowledge file(s)
  abortedBLStore,
  % Generate a list of all rule solutions for error type
  setof(RuleSolution,rule_type(RuleSolution,ErrorType),RuleSolutionsList),
  % Add each rule solution to listbox
  forall(member(NextRuleSolution,RuleSolutionsList),fixsAddBrowseSolutionsLBRuleItem(NextRuleSolution)),
  % Generate a list of all case solutions for error type
  setof(CaseSolution,Status^(case_type(CaseSolution,ErrorType),case_status(CaseSolution,Status), Status \= input),CaseSolutionsList),
  % Add each case solution to listbox
  forall(member(NextCaseSolution,CaseSolutionsList),fixsAddBrowseSolutionsLBCaseItem(NextCaseSolution)),
  setof(BRL,browseListStore(BRL),BRList),                  % Add item to listbox
  member(FirstItem,BRList,1),
  proweb_assert(fixsBrowseLB(BRList,FirstItem)).

abortedBLStore:-
 (def(browseListStore,1,_) -> retractall(browseListStore(_))
 ;true),
  (proweb_retract(fixsBrowseLB(_));true).

% (def(fixsBrowseLB,2,_) -> retractall(fixsBrowseLB(_,_))
% ;true). 

abortedBDetailStore:-
  (proweb_retract(fixsBrowseDetailItems(_,_,_,_));true).

% (def(fixsBrowseDetailItems,4,_) -> retractall(fixsBrowseDetailItems(_,_,_,_))
% ;true). 

/*----------------------------------------------------------*/
/*  Open Browse Solutions Dialog                            */
/*----------------------------------------------------------*/
fixsOpenBrowseSolutions :-
  fixsGetErrorTypeDlg(ErrorType),                               % Call error type dialog to get error type to browse
  (ErrorType \== null                                           % Determine if an error type was returned
    -> (fixsInitBrowseSolutionsDlg(ErrorType),                  % Initialize browse solutions dialog data
        call_dialog(browseSolutionsDlg,_)                       % Open browse solutions dialog
       )
    ; true                                                      % Not error type selected, do nothing
  ).


/*----------------------------------------------------------*/
/*  Knowledge File(s) Management                            */
/*----------------------------------------------------------*/
% Abolish knowledge file(s)
fixsKnowledgeAbolish :-
  (def(loadedKnowledgeFiles,1,_)                                % Determine if loaded knowledge predicate has been asserted
    -> (forall(loadedKnowledgeFiles(FullPath),abolish_files(FullPath)),
        retractall(loadedKnowledgeFiles(_))                     % Remove all loaded knowledge predicates from memory
       )
    ; true                                                      % Do nothing
  ).

% Load knowledge file
fixsKnowledgeLoadFile(Path,File,Ext) :-
  cat([Path,File,Ext],FullPath,_),                              % Create full file path
 proweb_trace(FullPath),
  (load_files(FullPath)                                         % Load knowledge file
    -> assert(loadedKnowledgeFiles(FullPath))                   % Assert loaded file path
    ; msgbox(`File Not Found!`,FullPath,16'00000030,_)          % Show error message
  ).

% Load knowledge file(s) knowing error type
fixsKnowledgeLoad(ErrorType) :-
 proweb_trace( `Before fixsKnowledgeLoad(ErrorType)`),
 proweb_trace(ErrorType),
  fixsKnowledge(ErrorType,FileList,_),                          % Get listing of files to load
  !, % Performance
  fixsAppPath(Path,_,_),                                        % Get components of current application path
  cat([Path,'knb\'],KnbPath,_),                                 % Combine components to form knowledge file path
  % Load each file in list
  forall(member(File,FileList),(fixsKnowledgeLoadFile(KnbPath,File,'.pl'))).


% Load knowledge file(s) knowing errorClassification(_)
fixsKnowledgeLoad :-
  exists_confirmation(errorClassification(ErrorType)),          % Get confirmed value for error type
  fixsKnowledgeLoad(ErrorType).                                 % Load file(s) knowing error type





/*----------------------------------------------------------*/
/*                                                          */
/*  Solution Detail Dialog Functions                        */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Format Confirmations Functions                          */
/*----------------------------------------------------------*/
/*
fixsFormatConfirmation(Pred,InternalValue) :-
  ((var(InternalValue) ; number(InternalValue))
    -> ExternalValue = InternalValue
    ; (string(InternalValue)
        -> atom_string(ExternalValue,InternalValue)
        ; (fixsPredicateValue(Pred(InternalValue),ExternalString)
            -> atom_string(ExternalValue,ExternalString)
            ; ExternalValue = InternalValue
          )
      )
  ),
  predicate_description(Pred(ExternalValue),PredDescAtomList),
  !,
  fixsListToString(PredDescAtomList,PredDescStr),
  nl,write(PredDescStr).

fixsFormatConfirmations :-
  setof(Pred-Value,exists_confirmation(Pred(Value)),ConfirmationsList),
  nl,write(`Confirmed Input Values:`),nl,
  forall(member(Pred-Value,ConfirmationsList),fixsReportConfirmation(Pred,Value)).
*/

/*----------------------------------------------------------*/
/*  Set Solution Detail Dialog Items                        */
/*----------------------------------------------------------*/


/*----------------------------------------------------------*/
/*  Call Solution Detail Dialog                             */
/*----------------------------------------------------------*/
fixsCallSolutionDetailDlg(IdStr) :-
  fixsSetSolutionDetailItems(IdStr),                            % Set dialog items
  (def(findSolutionActive,1,_)                                  % Determine if find solution active flag is defined
    -> (findSolutionActive(true)
         -> HowStatus = 1                                       % Enable How button
         ; HowStatus = 0                                        % Disable How button
       )
    ; HowStatus = 0                                             % Disable How button
  ),
  !, % Performance
  wenable((solutionDetailDlg,102),HowStatus),                   % Enable/Disable How button
  call_dialog(solutionDetailDlg,_).                             % Display solution detail dialog



/*----------------------------------------------------------*/
/*  String To List Function                                 */
/*----------------------------------------------------------*/
%
% Parses a string of words to a list of words (adapted from LPA example)
%
fixsStringToList(String,List) :-
  cat([String,`.`],Str,_),
  fixs_GetStringList(List) <~ Str.

fixs_GetStringList(List) :-
  get0(Char),
  fixs_GetRest(Char,List).

fixs_GetRest(46,[]) :- !.

fixs_GetRest(32,List) :-
  !,
  fixs_GetStringList(List).

fixs_GetRest(Char,[String|List]) :-
  fixs_GetStrings(Char,Chars,NextChar),
  name(String,Chars),
  fixs_GetRest(NextChar,List).

fixs_GetStrings(46,[],46) :- !.

fixs_GetStrings(32,[],32) :- !.

fixs_GetStrings(Char,[Char|Chars],NextChar) :-
  get0(Ch),
  fixs_GetStrings(Ch,Chars,NextChar).


/*----------------------------------------------------------*/
/*  List To String Function                                 */
/*----------------------------------------------------------*/
fixsListToString(List,String) :-
  fixsListToString(List) ~> String.

fixsListToString(List) :-
  (atomic(List)                                                 % Determine if list is actually a list
    -> write(List)                                              % Write single item
    ; forall(member(Item,List),write(Item))                     % Write multiple items
  ).

/*----------------------------------------------------------*/
/*  Knowledge File(s) Management                            */
/*----------------------------------------------------------*/
% Abolish knowledge file(s)
fixsKnowledgeAbolish :-
  (def(loadedKnowledgeFiles,1,_)                                % Determine if loaded knowledge predicate has been asserted
    -> (forall(loadedKnowledgeFiles(FullPath),abolish_files(FullPath)),
        retractall(loadedKnowledgeFiles(_))                     % Remove all loaded knowledge predicates from memory
       )
    ; true                                                      % Do nothing
  ).

% Load knowledge file
fixsKnowledgeLoadFile(Path,File,Ext) :-
  cat([Path,File,Ext],FullPath,_),                              % Create full file path
  (load_files(FullPath)                                         % Load knowledge file
    -> assert(loadedKnowledgeFiles(FullPath))                   % Assert loaded file path
    ; msgbox(`File Not Found!`,FullPath,16'00000030,_)          % Show error message
  ).

% Load knowledge file(s) knowing error type
fixsKnowledgeLoad(ErrorType) :-
  fixsKnowledge(ErrorType,FileList,_),                          % Get listing of files to load
  !, % Performance
  fixsAppPath(Path,_,_),                                        % Get components of current application path
  cat([Path,'knb\'],KnbPath,_),                                 % Combine components to form knowledge file path
  % Load each file in list
  forall(member(File,FileList),(fixsKnowledgeLoadFile(KnbPath,File,'.pl'))).

% Load knowledge file(s) knowing errorClassification(_)
fixsKnowledgeLoad :-
  exists_confirmation(errorClassification(ErrorType)),          % Get confirmed value for error type
  fixsKnowledgeLoad(ErrorType).                                 % Load file(s) knowing error type

