
/*----------------------------------------------------------*/
/*                                                          */
/*  Find Solution Results Dialog Functions                  */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Create Find Solution Results LB String                  */
/*----------------------------------------------------------*/
fixsCreateFindSolutionResultsLBString(Sim,Id,Type,Desc,Str) :-
  SimPercent is Sim * 100.0,                                    % Convert similarity to a percent
  fixsFloatToInt(SimPercent,SimInt),                            % Convert floating point to integer
  fwrite(i,3,0,SimInt) ~> SimStr,                               % Create similarity string
  fwrite(s,-10,-1,Id) ~> IdStr,                                 % Create id string
  fwrite(s,-25,-1,Type) ~> TypeStr,                             % Create type string
  fwrite(s,-50,-1,Desc) ~> DescStr,                             % Create description string
  cat([SimStr,`%  `,IdStr,` `,TypeStr,` `,DescStr],Str,_).      % Combine strings to form one string or item


/*----------------------------------------------------------*/
/*  Add Find Solution Results LB Rule Item                  */
/*----------------------------------------------------------*/
fixsAddFindSolutionResultsLBRuleItem(Sim,Solution) :-
  rule_type(Solution,TypeAtom),                                 % Get solution type
  rule_id(Solution,IdStr),                                      % Get solution id
  rule_desc(Solution,DescStr),                                  % Get solution description
  fixsKnowledge(TypeAtom,_,TypeStr),                            % Convert type atom to a type string
  % Format listbox string
  fixsCreateFindSolutionResultsLBString(Sim,IdStr,TypeStr,DescStr,Str),
 atom_string(C,Str),
 assert(findListStore(C)).
%  wlbxadd((findSolutionResultsDlg,400),-1,Str).                 % Add item to listbox


/*----------------------------------------------------------*/
/*  Add Find Solution Results LB Case Item                  */
/*----------------------------------------------------------*/
fixsAddFindSolutionResultsLBCaseItem(Sim,Solution) :-
  case_type(Solution,TypeAtom),                                 % Get solution type
  case_id(Solution,IdStr),                                      % Get solution id
  case_desc(Solution,DescStr),                                  % Get solution description
  fixsKnowledge(TypeAtom,_,TypeStr),                            % Convert type atom to a type string
  % Format listbox string
  fixsCreateFindSolutionResultsLBString(Sim,IdStr,TypeStr,DescStr,Str),
 atom_string(C,Str),
 assert(findListStore(C)).
%  wlbxadd((findSolutionResultsDlg,400),-1,Str).                 % Add item to listbox


/*----------------------------------------------------------*/
/*  Set Find Solution Results Solution                      */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Get Find Solution Results LB Item                       */
/*----------------------------------------------------------*/
fixsGetFindSolutionResultsLBItem(FslutionErrorType) :-
 proweb_trace( `Start fixsGetBrowseSolutionsLBItem`),
%  fixsAppPath(Path,_,_),                                        % Get application path
  abortedFDetailStore,
  atom_string(FslutionErrorType,FirstSel),                                      % Convert atom to string
  proweb_trace( FirstSel),
  fixsStringToList(FirstSel,SelList),                           % Convert selection to a list of "words"
  member(Item,SelList,2),                                       % Get selection id from list of "words"
  atom_string(Item,IdStr),                                      % Convert atom to string
  proweb_trace( IdStr),
  ((rule_repair(IdStr,SolutionText),                            % Get rule solution text...
  ActualText=`No actual case description for rulebase !`)
     ;                              
    (case_repair(IdStr,SolutionText),                             % Or get case solution text
      case_actualCaseDescription(IdStr,ActualText))                            % Or get case solution text
   ),
  (rule_details(IdStr,DetailList);                              % Get rule details list...
   case_details(IdStr,DetailList)),                             % Or get case details list
  (DetailList == []                                             % Determine if detail list is empty
    -> Detail = 'fixs-na'                                       % Use default detail
    ; member(Detail,DetailList,1)                               % Use first detail in list
  ),
%  cat([Path,'BMP\',Detail],FileDetail,_),                     % Create file path
%  atom_string(FileDetail,DetailStr),                                % Convert detail name to a string
  proweb_trace( ActualText),
  atom_string(Detail,DetailStr),                                % Convert detail name to a string
  proweb_trace( DetailStr),
  assert(fixsFindDetailItems(IdStr,SolutionText,ActualText,DetailStr)).

abortedFDStore:-
 (def(findListStore,1,_) -> retractall(findListStore(_))
 ;true),
  (proweb_retract(fixsFindLB(_));true).

% (def(fixsFindLB,2,_) -> retractall(fixsFindLB(_,_))
% ;true). 

abortedFDetailStore:-
%  (proweb_retract(fixsFindDetailItems(_,_,_,_));true).

 (def(fixsFindDetailItems,4,_) -> retractall(fixsFindDetailItems(_,_,_,_))
 ;true). 

/*----------------------------------------------------------*/
/*  Open Find Solution Results Dialog                       */
/*----------------------------------------------------------*/
fixsOpenFindSolutionResultsDlg(RuleSolutionList,CaseSolutionList) :-
%  fixsDeletaAllLBxItems((findSolutionResultsDlg,400)),          % Remove all current items from listbox
  proweb_trace(`fixsOpenFindSolutionResultsDlg(RuleSolutionList,CaseSolutionList)`),
  abortedFDStore,
  % Place each rule solution in solution listbox
  forall(member(RuleSim-RuleSolution,RuleSolutionList),fixsAddFindSolutionResultsLBRuleItem(RuleSim,RuleSolution)),
  % Place each case solution in solution listbox
  forall(member(CaseSim-CaseSolution,CaseSolutionList),fixsAddFindSolutionResultsLBCaseItem(CaseSim,CaseSolution)),
  setof(BRL,findListStore(BRL),BRList),                  % Add item to listbox
  member(FirstItem,BRList,1),
  proweb_trace(`End fixsFindLB(BRList,FirstItem)`),
  proweb_assert(fixsFindLB(BRList,FirstItem)).

%  call_dialog(findSolutionResultsDlg,_).                        % Open find solution results dialog

fixsShowResults :-
 proweb_trace(`fixsShowResults`),
  proweb_send_form(findbrowseSolutions_form),proweb_returned_form(findbrowseSolutions_form),
  proweb_returned_answer( find_errortype,FslutionErrorType),
  proweb_trace(FslutionErrorType),
 proweb_trace(`Why_input`),
 (proweb_returned_input(askwhy,Why_input) -> proweb_trace(Why_input);true),
 (Why_input == whywhy ->proweb_trace(`Yes yi yi`),
  (whatIsActive(ActiveProcess), proweb_trace(ActiveProcess),                                 % Determine active process
  findSolutionDlgWhy(ActiveProcess))
%  findSolutionDlgWhy(scbr))
  ;proweb_trace(`No yi yi`),true),                          % Process Why event
  fixsGetFindSolutionResultsLBItem(FslutionErrorType),
  fixsFindDetailItems(_,_,_,FigureName),
  ( write(`<IMG SRC=../FIXS/Fixsimages/`),
        write(FigureName),
        write(`.gif>`)
      ) ~> GraphicalName,
  proweb_trace( 'Bsolution ax='),
  proweb_trace( GraphicalName),
  proweb_post_reply( find_image,unencoded @ GraphicalName),
  proweb_send_form(findbrowseDetail_form),proweb_returned_form(findbrowseDetail_form),
 proweb_trace(`Why_input`),
  (findSolutionDlgWhy(mess);true),
 (proweb_returned_input(askwhy,Why_input) -> proweb_trace(Why_input);true),
 (Why_input == whywhy ->proweb_trace(`Yes yi yi`),
  (whatIsActive(ActiveProcess), proweb_trace(ActiveProcess),                                 % Determine active process
  findSolutionDlgWhy(ActiveProcess))
%  findSolutionDlgWhy(mess))
  ;proweb_trace(`No yi yi`),true).                          % Process Why event









