/*----------------------------------------------------------*/
/*  Setup Control Group                                      */
/*----------------------------------------------------------*/
findSolutionDlgControlsSet(ControlGroup,HighlightIndex) :-
 write(ControlGroup) ~> ControlGroupStr,                       % Convert control group name to a string
 proweb_trace(`Begin findSolutionDlgControlsSet--`),
 proweb_trace(ControlGroupStr),
 write(HighlightIndex) ~> HighlightIndexStr, 
  proweb_trace(`HighlightIndexStr`),proweb_trace(HighlightIndexStr),
  (findSolutionDlgControlsInit(ControlGroup)                    % Initialize control data
    -> proweb_trace( `OK ! findSolutionDlgControlsInit(ControlGroup)`)
    ; true,proweb_trace( `NOT ! findSolutionDlgControlsInit(ControlGroup)`)
  ),
  (findSolutionDlgUnitsSet(ControlGroup)                        % Set unit labels
    -> proweb_trace( `OK ! findSolutionDlgUnitsSet(ControlGroup)`)
    ; true,proweb_trace( `NOT ! findSolutionDlgUnitsSet(ControlGroup)`)
  ),
  (nonvar(HighlightIndex)                                       % Determine if highlight index is a variable
    ->  (findSolutionDlgHighlightsSet(ControlGroup,HighlightIndex)
         -> true,proweb_trace( `OK ! findSolutionDlgHighlightsSet(ControlGroup,HighlightIndex)`)
         ; true,(write(HighlightIndex) ~> HighlightIndexStr, 
   proweb_trace( `NOT ! findSolutionDlgHighlightsSet(ControlGroup,HighlightIndex)`),proweb_trace(HighlightIndexStr)
  ))
 ;true
 ),
 (whatIsActive(ActiveProcess), proweb_trace(ActiveProcess),                                 % Determine active process
  findSolutionDlgWhy(ActiveProcess)),
 groupform1(Gform1),groupform2(Gform2),groupform3(Gform3),
 (member(ControlGroup,Gform1) ->
 proweb_send_form(finds_form1(ControlGroup)),proweb_returned_form(finds_form1(ControlGroup));
  (member(ControlGroup,Gform2) ->
 proweb_send_form(finds_form2(ControlGroup)),proweb_returned_form(finds_form2(ControlGroup));
  (member(ControlGroup,Gform3) ->
 proweb_send_form(finds_form3(ControlGroup)),proweb_returned_form(finds_form3(ControlGroup));true))),
 proweb_trace(`Why_input`),
% (proweb_returned_input(askwhy,Why_input) -> proweb_trace(Why_input);true),
% (Why_input == whywhy ->proweb_trace(`^^^^^^^^^^^^Yes yi yi`),
%  ;proweb_trace(`No yi yi`),true),                          % Process Why event
  retractall(findSolutionControlGroup(_)),                      % Remove all control group handling predicates from memory
  assert(findSolutionControlGroup(ControlGroup)),               % Assert currently active control group id
 write(ControlGroup) ~> AControlGroupStr,                       % Convert control group name to a string
 proweb_trace(`After findSolutionDlgControlsSet--`),
 proweb_trace(AControlGroupStr),
  proweb_trace( `Before findSolutionDlgEvent(next) `),
  findSolutionDlgEvent(next),                                 % Call appropriate event handler
  !. % Performance



/*----------------------------------------------------------*/
/*  Setup Highlights                                        */
/*----------------------------------------------------------*/
%--------------------------------------------------------------------------------------------------
% HighlightIndex can either be an integer or a list of the form: [Index/Status,...]
%--------------------------------------------------------------------------------------------------
findSolutionDlgHighlightsSet(ControlGroup,HighlightIndex) :-
 proweb_trace(`Begin HighlightsSet--`),
 write(ControlGroup) ~> ControlGroupStr,                       % Convert control group name to a string
% proweb_trace(ControlGroupStr),
 write(HighlightIndex) ~> HighlightIndexStr, 
%  proweb_trace(`HighlightIndexStr`),proweb_trace(HighlightIndexStr),
  allhighlights(ControlGroup,MaxIndex),
 write(MaxIndex) ~>MaxIndexStr, 
%  proweb_trace(`MaxIndexStr`),proweb_trace(MaxIndexStr),
  (integer(HighlightIndex)                                      % Determine if HighlightIndex is an integer or list
    -> 
   proweb_trace(`integer`),
    (
     (MaxIndex =< HighlightIndex)
         -> 
           findSolutionDlgHighlightShow(ControlGroup,1,HighlightIndex)
         ;
           getnewHighlightIndexInteger(HighlightIndex,MaxIndex,NoIndexlist),
           findSolutionDlgHighlightShowByList(ControlGroup,NoIndexlist),
           findSolutionDlgHighlightShowByList(ControlGroup,HighlightIndex) 
    )
   ; 
   proweb_trace(`list`),
   getnewHighlightIndexList(HighlightIndex,MaxIndex,NoIndexlist),
   findSolutionDlgHighlightShowByList(ControlGroup,NoIndexlist),
   findSolutionDlgHighlightShowByList(ControlGroup,HighlightIndex)
  ).


  getnewHighlightIndexInteger(OldIndex,MaxIndex,NoIndexlist) :-
  numberIndexlist(Alist),
  setof(X/0,(member(X,Alist),X =\= OldIndex,X =< MaxIndex),NoIndexlist).
 
  getnewHighlightIndexList(OldIndexlist,MaxIndex,NoIndexlist) :-
  numberIndexlist(Alist),
  write(Alist) ~>AlistStr, 
%  proweb_trace(`AlistStr`),proweb_trace(AlistStr),
  setof(Y/0,(member(Y,Alist),Y =< MaxIndex),NoIndexlist).

/*----------------------------------------------------------*/
/*                                                          */
/*  General Dialog/Control Handling Code                    */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Show/Hide Controls                                      */
/*----------------------------------------------------------*/

% Set show/hide status of highlight (0 - hide, 1 - show)
findSolutionDlgHighlightShow(ControlGroup,Status,Index) :-
 proweb_trace(`Begin findSolutionDlgHighlightShow`),
 write(Index) ~> IndexStr,proweb_trace(IndexStr),
 write(Status) ~> StatusStr,proweb_trace(StatusStr),
 number_atom(Index,ATIndex),
 cat([ControlGroup,ATIndex],Hilight,_),
 (proweb_retract(fixshighlight(Hilight,_));true),
  (Status == 1 -> proweb_assert(fixshighlight(Hilight,`==>`))
                  ;true,proweb_assert(fixshighlight(Hilight,`---`))
  ),
  write(Hilight) ~> HilightStr,proweb_trace(HilightStr).                       
 
% Set show/hide status of highlights based on a list of the form: [Index/Status,...]
findSolutionDlgHighlightShowByList(ControlGroup,IndexStatusList) :-
  forall(member(Index/Status,IndexStatusList),findSolutionDlgHighlightShow(ControlGroup,Status,Index)).



/*----------------------------------------------------------*/
/*  Unit Label Definitions                                  */
/*----------------------------------------------------------*/
fixsUnitLabel(english,`inches`).                                % English units
fixsUnitLabel(metric,`mm`).                                     % Metric units


/*----------------------------------------------------------*/
/*                                                          */
/*  Control Group Setup Handling Code                       */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Set Unit Control Labels                                 */
/*----------------------------------------------------------*/
% Set units of controls
findSolutionDlgUnitsSet(ControlGroup) :-
  (exists_confirmation(unitsType(Units))                        % Get confirmed units value
    -> fixsUnitLabel(Units,Label)                               % Get string value for units
    ; Label = `---`                                                % Set units string to a blank string
  ),
  findSolutionDlgUnitIds(ControlGroup,IndexList),               % Get index list of unit text controls
  % Set units string for each control
  forall(member(Index,IndexList),findSolutionDlgUnitsShow(ControlGroup,Index,Label)).

findSolutionDlgUnitsShow(ControlGroup,Index,Label):-
 proweb_trace(`Begin UnitsShow`),
 write(Index) ~> IndexStr,proweb_trace(IndexStr),
 write(Label) ~> StatusStr,proweb_trace(StatusStr),
  number_atom(Index,ATIndex),cat([ControlGroup,'_',ATIndex],NewUnits,_), 
  write(NewUnits) ~> NewUnitsStr,proweb_trace(NewUnitsStr), 
  atom(NewUnits) -> 
  (proweb_retract(fixsunits(NewUnits,_));true),
  proweb_assert(fixsunits(NewUnits,Label))
                   ;true.
