/*----------------------------------------------------------*/
/*  FIXS Find Solution Code.pl                              */
/*  Fabrication Indexed eXamples and Solutions (FIXS)       */
/*  The University of Kansas                                */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Startup                                                 */
/*----------------------------------------------------------*/
findSolutionStartup :-
  clear_confirmations,
  retractall(findSolutionControlGroup(_)),                      % Remove any control group control predicates
  retractall(findSolutionDlgGoalsUsed(_)),                      % Remove any GoalsUsed control predicates
  retractall(findSolutionRuleSolutions(_)),                     % Remove previous rule solutions
  retractall(findSolutionCaseSolutions(_)),                     % Remove previous case solutions
  fixsSetFlag(whatIsActive,start),                              % Set START as the active process
  fixsKnowledgeAbolish,                                         % Abolish any open knowledge files
  findSolutionDestroyInputCases,                                % Destroy any input case data
  fixsSetFlag(findSolutionActive,true),                         % Set find solution active flag
  !. % Performance


/*----------------------------------------------------------*/
/*  Cleanup                                                 */
/*----------------------------------------------------------*/
findSolutionCleanup :-
  retractall(findSolutionControlGroup(_)),                      % Remove any control group control predicates
  retractall(findSolutionDlgGoalsUsed(_)),                      % Remove any GoalsUsed control predicates
  retractall(findSolutionRuleSolutions(_)),                     % Remove previous rule solutions
  retractall(findSolutionCaseSolutions(_)),                     % Remove previous case solutions
  fixsSetFlag(whatIsActive,none),                               % Set active process flag to no process
  fixsSetFlag(findSolutionActive,false),                        % Set find solution not active flag
  !. % Performance


/*----------------------------------------------------------*/
/*  Abort                                                   */
/*----------------------------------------------------------*/
findSolutionAbort :-
  abort.                                                        % Restart main program loop


/*----------------------------------------------------------*/
/*                                                          */
/*  Process Control                                         */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  START Process Control                                   */
/*----------------------------------------------------------*/
findSolutionContinueProcess(start) :-
 proweb_trace(`Start findSolutionContinueProcess(start)`),
  findSolutionControlGroup(ControlGroup),                       % Determine active control group
  atom_string(ControlGroup,StControlGroup),
 proweb_trace(StControlGroup),
 proweb_trace(`Before findSolutionDlgControlsNext(ControlGroup,ControlGroupNext)`),
  (findSolutionDlgControlsNext(ControlGroup,ControlGroupNext),   % Determine if a control group is specified to follow active control group
  atom_string(ControlGroupNext,StControlGroupNext),
   proweb_trace(StControlGroupNext)
    -> findSolutionDlgControlsSet(ControlGroupNext,_)           % Setup next control group
    ; findSolutionContinueProcess(mess)                         % Otherwise, pass control to MESS
  ),
  !. % Performance


/*----------------------------------------------------------*/
/*  MESS Process Control                                    */
/*----------------------------------------------------------*/
findSolutionContinueProcess(mess) :-
 proweb_trace(`Start findSolutionContinueProcess(mess)`),
  findSolutionControlGroup(ControlGroup),                       % Determine active control group
  atom_string(ControlGroup,StControlGroup),
 proweb_trace(StControlGroup),
  (whatIsActive(mess)                                           % Determine if MESS is active process
    -> true,proweb_trace( `true whatIsActive(mess)`)                                                     % Do nothing and let MESS handle next action
    ; ( findSolutionDlgInvokeMESS,                              % MESS not already the active process, invoke it
        findSolutionContinueProcess(scbr)                       % Pass control to SCBR when MESS is done
      )
  ),
  !. % Performance


/*----------------------------------------------------------*/
/*  SCBR Process Control                                    */
/*----------------------------------------------------------*/
findSolutionContinueProcess(scbr) :-
 proweb_trace(`Start findSolutionContinueProcess(scbr)`),
  findSolutionControlGroup(ControlGroup),                       % Determine active control group
  atom_string(ControlGroup,StControlGroup),
 proweb_trace(StControlGroup),
  (whatIsActive(scbr)                                           % Determine if SCBR is active process
    -> true,proweb_trace( `true whatIsActive(scbr)`) % Do nothing and let SCBR handle next action
    ; ( proweb_trace( `Before findSolutionDlgInvokeSCBR`),findSolutionDlgInvokeSCBR,                              % SCBR not already the active process, invoke it
        proweb_trace( `findSolutionContinueProcess(finish)`),findSolutionContinueProcess(finish)                     % Pass control back to FIXS when SCBR is done
      ,proweb_trace( `After findSolutionContinueProcess(finish)`))
  ),proweb_trace( `final findSolutionContinueProcess(finish)`),
  !. % Performance

/*----------------------------------------------------------*/
/*  FINISH Process Control                                  */
/*----------------------------------------------------------*/
findSolutionContinueProcess(finish) :-
  proweb_trace( `Real Start findSolutionContinueProcess(finish)`),
  findSolutionRuleSolutions(RuleSolutions),                     % Get rule solution list
  findSolutionCaseSolutions(CaseSolutions),                     % Get case solution list
  proweb_trace( `2---Real Start findSolutionContinueProcess(finish)`),
  !, % Performance
  proweb_trace( `2.5---Real Start findSolutionContinueProcess(finish)`),
  append(RuleSolutions,CaseSolutions,AllSolutions),             % Combine rule and case solutions to determine solution count
  length(AllSolutions,SolutionCount),                           % Determine the number of solutions found
  proweb_trace( `3---Real Start findSolutionContinueProcess(finish)`),
  (SolutionCount > 0
    -> fixsOpenFindSolutionResultsDlg(RuleSolutions,CaseSolutions),fixsShowResults
    ; msgbox(`No Solutions`,`Unable to locate any feasible solutions with the given input data.`,16'00000040,_)
  ),
  findSolutionCleanup.                                          % Cleanup


/*----------------------------------------------------------*/
/*                                                          */
/*  Event Handling Code                                     */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Next Button Event Handler                               */
/*----------------------------------------------------------*/
findSolutionDlgEvent(next) :-
  proweb_trace( `Start findSolutionDlgEvent`),
 findSolutionControlGroup(ControlGroup),                       % Determine active control group id
  (findSolutionAssertData(ControlGroup)                         % Assert control data of active control group
    -> true                                                     % Data asserted correctly
    ; (write(ControlGroup) ~> ControlGroupStr,                  % Convert control group name to a string
  proweb_trace( `Error 1000 ControlGroup=`),proweb_trace(ControlGroupStr)
      )
  ),
 proweb_trace( `Before whatIsActive`),
  whatIsActive(ActiveProcess),                                  % Determine what process is active
  atom_string(ActiveProcess,StActiveProcess),
 proweb_trace(StActiveProcess),
 proweb_trace( `Before findSolutionContinueProcess`),
  findSolutionContinueProcess(ActiveProcess).                   % Allow active process to continue


/*----------------------------------------------------------*/
/*  Cancel Button Event Handler                             */
/*----------------------------------------------------------*/
findSolutionDlgEvent(cancel) :-
  findSolutionControlGroup(ControlGroup),                       % Determine active control group id
  wshow(findSolutionDlg,0),                                     % Hide find solution dialog
  (findSolutionDlgCloseGroup(ControlGroup)                      % Close/Remove control group control definitions
    -> true
    ; (write(ControlGroup) ~> ControlGroupStr,                  % Convert control group name to a string
       fixsInternalErrorHandler(1001,[`~M~JControl Group: `,ControlGroupStr])
      )
  ),
  findSolutionCleanup,                                          % Cleanup find solution session
  findSolutionAbort.                                            % Abort current process


/*----------------------------------------------------------*/
/*                                                          */
/*  MESS Process Handlers                                   */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Invoke MESS                                             */
/*----------------------------------------------------------*/
findSolutionDlgInvokeMESS :-
  fixsSetFlag(whatIsActive,mess),                               % Set MESS as the active process
  (mess_basic_query(ruleSolution(BareRuleSolution))             % Invoke MESS to locate a rule solution
    -> RuleSolutions = [1-BareRuleSolution]                     % Add similarity value to rule solution (100%)
    ; RuleSolutions = []                                        % Otherwise, no rule solution
  ),
  retractall(findSolutionRuleSolutions(_)),                     % Remove previous rule solution
  assert(findSolutionRuleSolutions(RuleSolutions)).             % Assert rule solutions


/*----------------------------------------------------------*/
/*  MESS Predicate Input Handler                            */
/*----------------------------------------------------------*/
%--------------------------------------------------------------------------------------------------
% This handler is called by MESS through the special syntax of the predicate input definitions.
% Its purpose is to setup the next control group and store data concerning the Why button in the
% find solution dialog.
%--------------------------------------------------------------------------------------------------
findSolutionDlgHandler(ControlGroup,Goal,GoalsUsed,HighlightIndex) :-
  retractall(findSolutionDlgGoal(_)),                           % Remove all previous Goal data
  assert(findSolutionDlgGoal(Goal)),                            % Assert Goal data
  retractall(findSolutionDlgGoalsUsed(_)),                      % Remove all previous GoalsUsed data
  assert(findSolutionDlgGoalsUsed(GoalsUsed)),                  % Assert GoalsUsed data
  findSolutionDlgControlsSet(ControlGroup,HighlightIndex).      % Setup control group


/*----------------------------------------------------------*/
/*                                                          */
/*  SCBR Process Handlers                                   */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Invoke SCBR                                             */
/*----------------------------------------------------------*/
findSolutionDlgInvokeSCBR :-
  fixsSetFlag(whatIsActive,scbr),                               % Set SCBR as the active process
  userPrefsCaseFlag(FindCases),                                 % Get value of find cases flag
  (FindCases =:= 1                                              % Determine if cases are to be located
    ->  findSolutionFindCases(CaseSolutions)                    % Locate case solutions
    ;  CaseSolutions = []                                       % Skip case location (no cases)
  ),
  retractall(findSolutionCaseSolutions(_)),                     % Remove previous case solutions
  assert(findSolutionCaseSolutions(CaseSolutions)).             % Assert case solutions


/*----------------------------------------------------------*/
/*  Modify Feature Units  (metric to english conversion)    */
/*----------------------------------------------------------*/
findSolutionModifyFeatureUnits(ErrorType,Pred,OldValue,NewValue) :-
  (exists_confirmation(unitsType(english))                      % Determine type of units
    -> NewValue = OldValue                                      % No conversion required (units are english)
    ; (feature_units(ErrorType,PredList),                       % Get list of predicates needing conversion
        (member(Pred,PredList)                                  % Determine if predicate needs conversion
          -> NewValue is OldValue / 25.4                        % Convert metric units to english units
          ; NewValue = OldValue                                 % No conversion required for predicate
        )
      )
  ).


/*----------------------------------------------------------*/
/*  Build Input Case                                        */
/*----------------------------------------------------------*/
findSolutionBuildInputCase(ErrorType,InputCaseName) :-
  fixsGetCasePredicateList(ErrorType,PredList),                 % Get a listing of predicates for error type
  % Get value for each predicate and build input feature list
  findall(Pred:NewValue,(member(Pred,PredList),
                         exists_confirmation(Pred(OldValue)),
                         findSolutionModifyFeatureUnits(ErrorType,Pred,OldValue,NewValue)
                        ),FeatureList),
  findSolutionDestroyInputCases,                                % Make sure only one input case is defined
  % Assert input case
  assert(caseInput(InputCaseName,ErrorType,`InputCase`,`Input Case`,input,FeatureList)).


/*----------------------------------------------------------*/
/*  Destroy Input Case                                      */
/*----------------------------------------------------------*/
findSolutionDestroyInputCases :-
  retractall(caseInput(_,_,_,_,_,_)).
/*----------------------------------------------------------*/
/*  Get Case Data                                           */
/*----------------------------------------------------------*/
findSolutionGetCaseData(ErrorType) :-
  proweb_trace(`Start findSolutionGetCaseData(ErrorType)`),
 proweb_trace(ErrorType),
  fixsGetCasePredicateList(ErrorType,PredList),                 % Get a listing of predicates for error type
  forall(member(AStall,PredList),(atom_string(AStall,St),proweb_trace(St))),
  proweb_trace(`End -------------PredList`),
  % Get predicate information for each predicate
  findall(ControlGroup-Pred-HighlightIndex,
    ( member(Pred,PredList),
      fixsGetPredControlInfo(Pred,ControlGroup,HighlightIndex),
      nonvar(HighlightIndex)
    ),
    PredInfoList
    ),
   assert(testproblem(ControlGroup-Pred-HighlightIndex,PredInfoList)),
  proweb_trace(`End -------------PredInfoList`),
  % Get a listing of control groups
  setof(ControlGroup,
    Pred^HighlightIndex^member(ControlGroup-Pred-HighlightIndex,PredInfoList),
    ControlGroupList
    ),
  forall(member(CStall,ControlGroupList),(atom_string(CStall,CSt),proweb_trace(CSt))),
  proweb_trace(`End -------------ControlGroupList`),
  % Get a list of lists of highlight indexes corresponding to each control group in the control group listing
  findall(HighlightIndexList,
    ( member(ControlGroup,ControlGroupList),
      setof(HighlightIndex/1,
        Pred^( member(ControlGroup,ControlGroupList),
               member(ControlGroup-Pred-HighlightIndex,PredInfoList)
             ),
        HighlightIndexList
    )),
    HighlightIndexListings
    ),
   assert(testAproblem(ControlGroupList,HighlightIndexListings)),
  % Call each control group to get data
  forall(member(ControlGroup,ControlGroupList,Pos),
    (
      member(HighlightIndexList,HighlightIndexListings,Pos),
      retractall(findSolutionDlgGoalsUsed(_)),
      assert(findSolutionDlgGoalsUsed(caseLocation)),
      proweb_trace(`End ---------AAA`),
      findSolutionDlgControlsSet(ControlGroup,HighlightIndexList)
    )), proweb_trace(`End -------------`).

/*----------------------------------------------------------*/
/*  Find Cases                                              */
/*----------------------------------------------------------*/
findSolutionFindCases(CaseSolutions) :-
  % Tell user cases are to be found now
  proweb_trace(`Message-Possible rule solutions have been located. Information for case solutions will be input next.`),
  exists_confirmation(errorClassification(ErrorType)),          % Get confirmed value for error type
  proweb_trace(`After exists_confirmation(errorClassification(ErrorType))`),
  (findSolutionGetCaseData(ErrorType)                           % Query user for any remaining case data not already input
    -> true,proweb_trace(`True findSolutionGetCaseData(ErrorType)`)
    ; proweb_trace(`ErrorHandler(1002) % Process error`)
  ),
  (findSolutionBuildInputCase(ErrorType,inputCase)              % Build an input case for error type
    -> true,proweb_trace(`True findSolutionBuildInputCase(ErrorType,inputCase)`)
    ; proweb_trace(`ErrorHandler(1003)  Process error`)
  ),
  userPrefsMinSim(MinSimPercent),                               % Get minimum similarity (%) value to return
  MinSim is MinSimPercent / 100.0,                              % Calculate decimal value for minimum similarity
  userPrefsMaxCases(MaxCases),                                  % Get maximum number of cases to return
  % Find the cases
  (find_similar_cases(inputCase,MinSim,MaxCases,CaseSolutions)
    -> true                                                     % Case(s) found
    ; CaseSolutions = []                                        % No cases found
  ),  findSolutionControlGroup(ControlGroup),                       % Determine active control group
  atom_string(ControlGroup,StControlGroup),
 proweb_trace(StControlGroup),proweb_trace(`END findSolutionFindCases(CaseSolutions)`).


/*----------------------------------------------------------*/
/*                                                          */
/*  Control Initialization Handling Code                    */
/*                                                          */
/*----------------------------------------------------------*/
  findSwtext((findSolutionDlg,ControlId),Text):-
  proweb_trace(`findSwtext`),
  findSTextIDList(FIDList),
  findSTextNameList(FNList),
  member(ControlId,FIDList,Itemnuber),
  member(MyName,FNList,Itemnuber),
  atom_string(MyName,StMyName),proweb_trace(StMyName),
%  (def(MyName,1,_) -> retractall(MyName(_));true),
  (proweb_retractall(MyName(_));true),
  proweb_assert(MyName(Text)),
  proweb_trace(`Itemnuber=`),
  number_string(Itemnuber,StItemnuber), proweb_trace(StItemnuber).

  fsReturnwtext((findSolutionDlg,ControlId),Text):-
  proweb_trace(`fsReturnwtext`),
  findSTextIDList(FIDList),
  findSTextNameList(FNList),
  member(ControlId,FIDList,Itemnuber),
  member(MyName,FNList,Itemnuber),
  atom_string(MyName,StMyName),proweb_trace(StMyName),
  proweb_returned_answer(MyName,Text),
  atom_string(MyName,StMyName),proweb_trace(StMyName),proweb_trace(Text),
% (def(MyName,1,_) -> retractall(MyName(_));true),
% assert(MyName(Text)),
  (proweb_retractall(MyName(_));true),
%  proweb_assert(MyName(Text)),
 proweb_trace(`Itemnuber=`),
 number_string(Itemnuber,StItemnuber), proweb_trace(StItemnuber).



  fixsAddAllStringsItem(Stringall) :-
  atom_string(X,Stringall),
  assert(addAllStrings(X)).


  findSwcombox(ControlId,AllStrings,AllValues,Value,Strings):-
  proweb_trace(`findSwcombox`),
  (def(addAllStrings,1,_) -> retractall(addAllStrings(_));true),
  forall(member(Stringall,AllStrings),fixsAddAllStringsItem(Stringall)),
  setof(BRL,addAllStrings(BRL),NewAllStrings),                  % Add item to listbox
  atom_string(NewStrings,Strings),
  findSTextIDList(FIDList),
  findSTextNameList(FNList),
  member(ControlId,FIDList,Itemnuber),
  member(MyName,FNList,Itemnuber),
  atom_string(MyName,StMyName),proweb_trace(StMyName),
%  (def(MyName,4,_) -> retractall(MyName(_,_,_,_));true),
%  assert(MyName(NewAllStrings,AllValues,NewStrings,Value)),
  (proweb_retractall(MyName(_,_,_,_));true),
  proweb_assert(MyName(NewAllStrings,AllValues,NewStrings,Value)),
  proweb_trace(`Itemnuber=`),
  number_string(Itemnuber,StItemnuber), proweb_trace(StItemnuber),
  atom_string(Value,StValue),
  proweb_trace(StValue),proweb_trace(`all the strings`),proweb_trace(Strings),
  forall(member(Stall,AllStrings),(proweb_trace(Stall))).

  fsReturncombox((findSolutionDlg,ControlId),Text):-
  proweb_trace(`fsReturncombox`),
  number_string(ControlId,StControlId),
  proweb_trace(StControlId),
  findSTextIDList(FIDList),
  findSTextNameList(FNList),
  member(ControlId,FIDList,Itemnuber),
  member(MyName,FNList,Itemnuber),
  proweb_trace(`Itemnuber=`),
  number_string(Itemnuber,StItemnuber), proweb_trace(StItemnuber),
  atom_string(MyName,StMyName),proweb_trace(StMyName),
  proweb_returned_answer(MyName,Text),
  (proweb_retractall(MyName(_,_,_,_));true),
  atom_string(Text,StText),
 proweb_trace(StText).

/*----------------------------------------------------------*/
/*  Text Control Initialization                             */
/*----------------------------------------------------------*/
% Initialize unused text item (string)
findSolutionDlgInitTextNew(ControlId,Text,string) :-
  findSwtext((findSolutionDlg,ControlId),Text).                      % Set text string

%--------------------------------------------------------------------------------------------------
% Empty text strings are passed to this predicate when the text item is to be initialized blank
% even though the type of data is designated as numerical.
% The type of data for the text item must still be set to "number" for proper operation when the
% the text item is not going to be initialized blank.
% Therefore, the following check is made to determine if the provided value is actually a
% empty text string rather than a number.
%--------------------------------------------------------------------------------------------------
% Initialize unused text item (number)
findSolutionDlgInitTextNew(ControlId,Value,number) :-
  (Value \== ``                                                 % Determine if value is actually an empty text string
    -> number_string(Value,Text), proweb_trace(Text)                               % Convert value from a number to a text string
    ; Text = Value                                              % Value is already a text string
  ),proweb_trace(Text),
  findSwtext((findSolutionDlg,ControlId),Text).                      % Set text string

% Initialize used text item (string)
findSolutionDlgInitTextUsed(ControlId,Goal(X),string) :-
  exists_confirmation(Goal(X)),                                 % Get confirmed value for goal
  findSwtext((findSolutionDlg,ControlId),X).                         % Set text to asserted value
%  wenable((findSolutionDlg,ControlId),0).                       % Disable text item

% Initialize used text item (number)
findSolutionDlgInitTextUsed(ControlId,Goal(X),number) :-
  exists_confirmation(Goal(X)),                                 % Get confirmed value for goal
  number_string(X,Text),                                        % Convert number to a text string
  findSwtext((findSolutionDlg,ControlId),Text).                      % Set text to asserted value
%  wenable((findSolutionDlg,ControlId),0).                       % Disable text item

% Initialize text item
findSolutionDlgInitTextItem(ControlId,Goal,Type,Value) :-
  (was_confirmed(Goal,_)                                        % Determine if text data has been asserted
    -> findSolutionDlgInitTextUsed(ControlId,Goal,Type)         % Initialize a used text item
    ; findSolutionDlgInitTextNew(ControlId,Value,Type)          % Initialize an unused text item
  ).

% Initialize text item with state data
findSolutionDlgInitTextItem(ControlId,Goal,Type,_,StatePred(Value)) :-
  number_string(ControlId,StControlId),
 proweb_trace( `Before findSolutionDlgInitTextItem and ControlId=`),
 proweb_trace(StControlId),
 findSolutionDlgInitTextNew(ControlId,Value,Type),proweb_trace( `Initizlize an unused text item`),    % Initizlize an unused text item
 proweb_trace(`Do nothing`).

/*----------------------------------------------------------*/
/*  Combobox Control Initialization                         */
/*----------------------------------------------------------*/
% Initialize unused combobox item

findSolutionDlgInitComboBoxNew(ControlId,Goal,Value) :-
%  wlbxadd((findSolutionDlg,ControlId),0,``),                    % Add a blank value to combobox
 proweb_trace( `Before findSolutionDlgInitComboBoxNew(C`),
  number_string(ControlId,StControlId),
  proweb_trace(StControlId),
  fixsPredicateAllValues(Goal,AllValues),
%  forall(member(Stall,AllValues),(atom_string(Stall,St),proweb_trace(St))),
  fixsPredicateAllStrings(Goal,AllStrings),                     % Determine all possible string values
%  forall(member(Str1,AllStrings),proweb_trace(Str1)),
  member(Value,AllValues,Itemnuber),
  member(Strings,AllStrings,Itemnuber),
  proweb_trace(Strings),
  % Add all possible string values to combobox
  findSwcombox(ControlId,AllStrings,AllValues,Value,Strings).
%  forall(member(String,AllStrings),wlbxadd((findSolutionDlg,ControlId),-1,String)),


% Initialize combobox item
findSolutionDlgInitComboBoxItem(ControlId,Goal) :-
  number_string(ControlId,StControlId),
  proweb_trace(StControlId),
 proweb_trace( `Before findSolutionDlgInitComboBoxItem(ControlId,Goal)`),
  fixsPredicateAllValues(Goal,AllValues),
  member(Value,AllValues,1),
  atom_string(Value,StValue), 
  proweb_trace(StValue),
 findSolutionDlgInitComboBoxNew(ControlId,Goal,Value).            % Initialize an unused combobox item

% Initialize combobox item with state data
findSolutionDlgInitComboBoxItem(ControlId,Goal,StatePred(Value)) :-
  number_string(ControlId,StControlId),
  proweb_trace(StControlId),
 proweb_trace( `findSolutionDlgInitComboBoxItem(ControlId,Goal,StatePred(Value))`),
  atom_string(Value,StValue), 
  proweb_trace(StValue),
 findSolutionDlgInitComboBoxNew(ControlId,Goal,Value).            % Initialize an unused combobox item

 
/*----------------------------------------------------------*/
/*                                                          */
/*  Control Data Assertion Handling Code                    */
/*                                                          */
/*----------------------------------------------------------*/
/*----------------------------------------------------------*/
/*  Text Control Assert Data                                */
/*----------------------------------------------------------*/
% Assert text item data (string)
findSolutionDlgAssertTextItem(ControlId,Goal(X),string) :-
  fsReturnwtext((findSolutionDlg,ControlId),Text),                      % Get text string from control
  (Text \== ``                                                  % Make sure something was typed
    -> conditional_assert_confirmation_and_denial(X,[Text],[Text],Goal(X))
    ; true                                                      % Nothing typed, do nothing
  ).

% Assert text item data (number)
findSolutionDlgAssertTextItem(ControlId,Goal(X),number) :-
  fsReturnwtext((findSolutionDlg,ControlId),Text),                      % Get text string from control
  (Text \== ``                                                  % Make sure something was typed
    -> (number_string(Number,Text),                             % Convert text string to a number
        conditional_assert_confirmation_and_denial(X,[Number],[Number],Goal(X))
       )
    ; true                                                      % Nothing typed, do nothing
  ).

% Assert text item with state data (string)
findSolutionDlgAssertTextItem(ControlId,Goal(X),string,StatePred(Text)) :-
 proweb_trace( `Before findSolutionDlgAssertTextItem and ControlId=`),
 proweb_trace( StControlId),
  fsReturnwtext((findSolutionDlg,ControlId),Text),                      % Get text string from control
  (Text \== ``                                                 % Make sure something was typed
    -> (conditional_assert_confirmation_and_denial(X,[Text],[Text],Goal(X)),
        retractall(StatePred(_)),                               % Remove all state data predicates
        assert(StatePred(Text)),proweb_trace(Text)                                 % Save state data predicate
       )
    ; true, proweb_trace(`Do nothing`)                           % Nothing typed, do nothing
  ).

% Assert text item with state data (number)
findSolutionDlgAssertTextItem(ControlId,Goal(X),number,StatePred(Number)) :-
 proweb_trace( `Before findSolutionDlgAssertTextItem and ControlId=`),
 proweb_trace( StControlId),
  fsReturnwtext((findSolutionDlg,ControlId),Text),                      % Get text string from control
  (Text \== ``                                                  % Make sure something was typed
    -> (number_string(Number,Text),                             % Convert text string to a number
        conditional_assert_confirmation_and_denial(X,[Number],[Number],Goal(X)),
        retractall(StatePred(_)),                               % Remove all state data predicates
        assert(StatePred(Number)),proweb_trace(Text)                               % Save state data predicate
       )
    ; true, proweb_trace(`Do nothing`)                           % Nothing typed, do nothing
  ).


/*----------------------------------------------------------*/
/*  Combobox Control Assert Data                            */
/*----------------------------------------------------------*/
% Assert combobox item data
findSolutionDlgAssertComboBoxItem(ControlId,Goal(X)) :-
fsReturncombox((findSolutionDlg,ControlId),Text),  % Get selected text string
  (nonvar(Text)                                                 % Make sure something was selected
    -> (atom_string(Text,String),
       fixsPredicateValue(Goal(Value),String),                   % Convert text string to value
        fixsPredicateAllValues(Goal(_),AllValues),              % Get all possible values for goal
        conditional_assert_confirmation_and_denial(X,AllValues,[Value],Goal(X))
       )
    ; true                                                      % Nothing selected, do nothing
  ).

% Assert combobox item with state data
findSolutionDlgAssertComboBoxItem(ControlId,Goal(X),StatePred(_)) :-
  fsReturncombox((findSolutionDlg,ControlId),Text),  % Get selected text string
  (nonvar(Text)                                                 % Make sure something was selected
    -> (atom_string(Text,String),
       fixsPredicateValue(Goal(Value),String),                   % Convert text string to value
        fixsPredicateAllValues(Goal(_),AllValues),              % Get all possible values for goal
        conditional_assert_confirmation_and_denial(X,AllValues,[Value],Goal(X)),
        retractall(StatePred(_)),                               % Remove all state data predicates
        assert(StatePred(Value))                                % Save state data predicate
       )
    ; true                                                      % Nothing selected, do nothing
  ).

/*----------------------------------------------------------*/
/*                                                          */
/*  Control Data Required Data Handling Code                */
/*                                                          */
/*----------------------------------------------------------*/
% Check for text item required data
findSolutionDlgReqTextData(ControlId) :-
  wtext((findSolutionDlg,ControlId),Text),                      % Get selected text string
  Text \== ``.                                                  % Determine if something was typed


/*----------------------------------------------------------*/
/*  Combobox Control Required Data                          */
/*----------------------------------------------------------*/
% Check for combobox item required data
findSolutionDlgReqComboBoxData(ControlId) :-
  wtext((findSolutionDlg,ControlId),Text),                      % Get selected text string
  Text \== ``.                                                  % Determine if something was selected
