fixsAssertAppPath :-                                              % Assert the current application path to memory
(def(fixsAppPath,3,_) -> retractall(fixsAppPath(_,_,_))
;true),
%  env('',Env),                                                  % Get path to current .EXE file
%  Env = [ExeFile],                                              % Extract file name from list
%  atom_string(ExeFile,`C:\InetPub\FIXS\PROWEB.EXE`),
%  fname(ExeFile,Path,Name,Ext),                                 % Parse file name into components
%  assert(fixsAppPath(Path,Name,Ext)).                           % Assert application path
  assert(fixsAppPath('C:\InetPub\FIXS\','FIXS','EXE')).                           % Assert application path
 
/*----------------------------------------------------------*/
/*  Load Knowledge Utilites File                            */
/*----------------------------------------------------------*/
fixsLoadKnowledgeUtils :-
  fixsAppPath(Path,_,_),                                        % Get application path
  cat([Path,'KNB\knbutils.pc'],FilePath,_),                     % Create file path
  load_files(FilePath).                                         % Consult file

/*----------------------------------------------------------*/
/*  Set Flag                                                */
/*----------------------------------------------------------*/
%--------------------------------------------------------------------------------------------------
% Sets a flag to a specified value.  Works only with predicates with an arity of 1.
%--------------------------------------------------------------------------------------------------
fixsSetFlag(Predicate,Value) :-
  retractall(Predicate(_)),                                     % Remove any asserted flags
  assert(Predicate(Value)).                                     % Assert new flag value
/*----------------------------------------------------------*/
/*  Save/Restore User Preferences                           */
/*----------------------------------------------------------*/
% Restore user preferences
fixsRestoreUserPrefs(File) :-                                   % File is an .INI file
  /* - */
  profile(File,`UserPrefs`,`Company`,UserCoString),             % User company
% proweb_post_reply(cx,UserCoString),
% proweb_send_form(notes_form),
  retractall(userPrefsCompany(_)),
  assert(userPrefsCompany(UserCoString)),
  /* - */
  profile(File,`UserPrefs`,`CaseFlag`,CaseFlagString),          % Use CBR flag
  number_string(CaseFlag,CaseFlagString),
  retractall(userPrefsCaseFlag(_)),
  assert(userPrefsCaseFlag(CaseFlag)),
  /* - */
  profile(File,`UserPrefs`,`MaxCases`,MaxCasesString),          % Maximum number of CBR cases to return
  number_string(MaxCases,MaxCasesString),
  retractall(userPrefsMaxCases(_)),
  assert(userPrefsMaxCases(MaxCases)),
  /* - */
  profile(File,`UserPrefs`,`MinSim`,MinSimString),              % Minimum similarity for CBR cases to return
  number_string(MinSim,MinSimString),
  retractall(userPrefsMinSim(_)),
  assert(userPrefsMinSim(MinSim)).

% Save user preferences
fixsSaveUserPrefs(File) :-                                      % File is and .INI file
  /* - */
  userPrefsCompany(UserCo),                                     % User company
  profile(File,`UserPrefs`,`Company`,UserCo),
  /* - */
  userPrefsCaseFlag(CaseFlag),                                  % Use CBR flag
  number_string(CaseFlag,CaseFlagString),
  profile(File,`UserPrefs`,`CaseFlag`,CaseFlagString),
  /* - */
  userPrefsMaxCases(MaxCases),                                  % Maximum number of CBR cases to return
  number_string(MaxCases,MaxCasesString),
  profile(File,`UserPrefs`,`MaxCases`,MaxCasesString),
  /* - */
  userPrefsMinSim(MinSim),                                      % Minimum similarity for CBR cases to return
  number_string(MinSim,MinSimString),
  profile(File,`UserPrefs`,`MinSim`,MinSimString).

/*----------------------------------------------------------*/
/*  Get .WEB File                                           */
/*----------------------------------------------------------*/
fixsGetWEBFile(File) :-                                         % Returns INI path in File
  fixsAppPath(Path,Name,_),                                     % Get components of current application path
  cat([Path,Name,'.WEB'],File,_).                               % Combine components to form .INI file path

/*----------------------------------------------------------*/
/*  Get .INI File                                           */
/*----------------------------------------------------------*/
fixsGetINIFile(File) :-                                         % Returns INI path in File
  fixsAppPath(Path,Name,_),                                     % Get components of current application path
  cat([Path,Name,'.INI'],File,_).                               % Combine components to form .INI file path




/*----------------------------------------------------------*/
/*  Get List Box Selection(s)                               */
/*----------------------------------------------------------*/
% get the next item after 0 (the first item) in the given listbox,
% start checking the items in the listbox starting at the first item,
% giving the next item and the empty list as the list of selections so
% far and return the result  (adapted from LPA example)

fixsGetLBxSelection(LBx,Selections) :-
  wlbxfnd(LBx,0,``,NextItem),
  fixsGetLBxSelection(LBx,0,NextItem,[],Selections).


% check the selection state of the given item in the given listbox
% if it is selected add it to the list of selections found so far.
% depending on the value of the next item either finish or find the item
% following and continue checking from the next item.

fixsGetLBxSelection(LBx,Item,0,SoFar,Sels) :-
  wlbxsel(LBx,Item,Sel),
  fixsGetSelected(Sel,LBx,Item,SoFar,Sels).


% if the next item is not 0 check the selection of the current item
% find the item after next and continue checking from the next item

fixsGetLBxSelection(LBx,Item,NextItem,SoFar,Sels) :-
  wlbxsel(LBx,Item,Sel),
  fixsGetSelected(Sel,LBx,Item,SoFar,NS),
  wlbxfnd(LBx,NextItem,``,AfterNextItem),
  fixsGetLBxSelection(LBx,NextItem,AfterNextItem,NS,Sels).


% if the selection state is 0, the item is not selected
% so the list of selected items remains unchanged.

fixsGetSelected(0,_,_,SoFar,SoFar).


% if the selection state is 1, the item is selected
% so add the item's string to the list of selected items

fixsGetSelected(1,LBx,Item,SoFar,[ItemStr|SoFar]) :-
  wlbxget(LBx,Item,ItemStr).


/*----------------------------------------------------------*/
/*  Delete All List Box Items                               */
/*----------------------------------------------------------*/
fixsDeletaAllLBxItems(LBx) :-
  wlbxdel(LBx,0),                                               % Delete first item
  fixsDeletaAllLBxItems(LBx).                                   % Recurse to delete next item

fixsDeletaAllLBxItems(_).                                       % Guarantee success


/*----------------------------------------------------------*/
/*  Floating Point to Integer Function (rounds correctly)   */
/*----------------------------------------------------------*/
/* Works only if Int is a variable and float is instantiated */
fixsFloatToInt(Float,Int) :-
  fwrite(f,0,0,Float) ~> NumStr,
  string_chars(NumStr,NumChars),
  append(NoDecimal,[46],NumChars),
  number_chars(Int,NoDecimal).



/*----------------------------------------------------------*/
/*  Case Predicates Management                              */
/*----------------------------------------------------------*/
% Get a listing of all predicates for error type
fixsGetCasePredicateList(ErrorType,PredList) :-
  feature_weights(ErrorType,FeatureList),                       % Get feature list for error type
  findall(Pred,member(Pred:_,FeatureList),PredList).            % Extract all predicates from feature list


/*----------------------------------------------------------*/
/*  Predicate Information Managment                         */
/*----------------------------------------------------------*/
% Get predicate control information
fixsGetPredControlInfo(Pred,ControlGroup,HighlightIndex) :-
  pinput(Pred(_),special(_,findSolutionDlgHandler(ControlGroup,_,_,HighlightIndex)),_,_,_,_).


/*----------------------------------------------------------*/
/*  Predicate Values Management                             */
/*----------------------------------------------------------*/
% Get all possible atom values for a goal
fixsPredicateAllValues(Goal(Value),AllValues) :-
  findall(Value,fixsPredicateValue(Goal(Value),_),AllValues).

% Get all possible string values for a goal
fixsPredicateAllStrings(Goal(_),AllStrings) :-
  findall(String,fixsPredicateValue(Goal(_),String),AllStrings).



